@@ -2,12 +2,12 @@
 
   Author: Greg Landrum (Landrum@RationalDiscovery.com)
   Created:       February 2004
-  $LastChangedDate: 2006-07-09 23:16:46 +0200 (Sun, 09 Jul 2006) $
+  $LastChangedDate: 2009-02-01 20:02:14 +0100 (Sun, 01 Feb 2009) $
   License:  PyMol
   Requires:
             - a python xmlrpclib distribution containing the SimpleXMLRPCServer
               module (1.0 or greater should be fine)
-  RD Version: $Rev: 2687 $            
+  RD Version: $Rev: 3570 $            
 """
 import xmlrpclib
 
