@@ -1,3 +1,5 @@
+
+
 /* 
 A* -------------------------------------------------------------------
 B* This file contains source code for the PyMOL computer program
@@ -35,7 +37,6 @@ Z* -------------------------------------------------------------------
 #define PI 3.14159265358979323846
 #endif
 
-
 #ifndef uchar
 #define uchar unsigned char
 #endif
@@ -44,8 +45,7 @@ Z* -------------------------------------------------------------------
 #define uint unsigned int
 #endif
 
-#define MAX_VDW 2.5F  /* this has to go */
-
+#define MAX_VDW 2.5F            /* this has to go */
 
 #ifndef MAXFLOAT
 #define MAXFLOAT FLT_MAX
@@ -59,14 +59,14 @@ Z* -------------------------------------------------------------------
 #define R_SMALL8 0.00000001F
 #endif
 
-typedef struct { 
-  int index; /* atom index.
-                NOTE: that first record contains the list count...not pick info */
-  int bond; /* bond index, 
-               >=0 for bond
-               -1 for atom
-               -2 for label
-               -3 for gadget */
+typedef struct {
+  int index;                    /* atom index.
+                                   NOTE: that first record contains the list count...not pick info */
+  int bond;                     /* bond index, 
+                                   >=0 for bond
+                                   -1 for atom
+                                   -2 for label
+                                   -3 for gadget */
 } Pickable;
 
 #define cPickableAtom -1
@@ -88,7 +88,7 @@ typedef struct {
 typedef struct {
   void *object;
   int state;
-  /*  int instance; */  /* to come... */
+  /*  int instance; *//* to come... */
 } PickContext;
 
 typedef struct {
@@ -98,7 +98,7 @@ typedef struct {
 
 typedef struct {
   int mode;
-  int x,y,w,h;
+  int x, y, w, h;
   Picking *picked;
 } Multipick;
 
@@ -108,15 +108,22 @@ typedef struct {
   float offset[3];
 } LabPosType;
 
+typedef struct {
+  float coord[3];
+  int specified;
+} RefPosType;
+
+
 /* not a global, but CRay widely used and Ray.h definitely isn't a
  * lightweight include... */
 
-typedef struct _CRay               CRay;
+typedef struct _CRay CRay;
+
 
 /* likewise */
 
 #ifndef CGO_DEFINED
-typedef struct _CGO                CGO;
+typedef struct _CGO CGO;
 #define CGO_DEFINED
 #endif
 
@@ -131,10 +138,13 @@ typedef struct {
   float fog_start, fog_end;
   float view_normal[3];
   float width_scale;
-  float vertex_scale; /* how large is a screen pixel in model space at the origin */
+  float vertex_scale;           /* how large is a screen pixel in model space at the origin */
   float *pmv_matrix;
-  int sampling; /* are we supersampling? */
-  int ortho; /* orthoscopic projection? */
+  int sampling;                 /* are we supersampling? */
+  int ortho;                    /* orthoscopic projection? */
+  int line_lighting;            /* line lighting */
+  int dynamic_width;
+  float dynamic_width_factor, dynamic_width_min, dynamic_width_max;
 } RenderInfo;
 
 #define MAXLINELEN 1024
