@@ -1,3 +1,5 @@
+
+
 /* 
 A* -------------------------------------------------------------------
 B* This file contains source code for the PyMOL computer program
@@ -23,16 +25,19 @@ typedef struct {
   PyMOLGlobals *G;
   float **smat;
   float **mat;
+  float **da, **db;
+  int na, nb;
   int *pair;
-  
-  int na,nb;
+  float score;                  /* result */
+  int n_pair;
 } CMatch;
 
-CMatch *MatchNew(PyMOLGlobals *G,unsigned int na,unsigned int nb);
-int MatchResidueToCode(CMatch *I,int *vla,int n);
-int MatchMatrixFromFile(CMatch *I,char *fname,int quiet);
-int MatchPreScore(CMatch *I,int *vla1,int n1,int *vla2,int n2,int quiet);
-void MatchFree(CMatch *I);
-float MatchAlign(CMatch *I,float gap_penalty,float ext_penalty,int max_gap,int quiet);
+CMatch *MatchNew(PyMOLGlobals * G, unsigned int na, unsigned int nb, int dist_mats);
+int MatchResidueToCode(CMatch * I, int *vla, int n);
+int MatchMatrixFromFile(CMatch * I, char *fname, int quiet);
+int MatchPreScore(CMatch * I, int *vla1, int n1, int *vla2, int n2, int quiet);
+void MatchFree(CMatch * I);
+int MatchAlign(CMatch * I, float gap_penalty, float ext_penalty,
+               int max_gap, int max_skip, int quiet, int window, float ante);
 
 #endif
