@@ -1,3 +1,5 @@
+
+
 /* 
 A* -------------------------------------------------------------------
 B* This file contains source code for the PyMOL computer program
@@ -19,10 +21,15 @@ Z* -------------------------------------------------------------------
 #include"Err.h"
 #include"MemoryDebug.h"
 
-#define OOAlloc(type) \
+#define OOAlloc(G,type) \
 type *I;\
 I = (type*)mmalloc(sizeof(type));\
-ErrChkPtr(I);
+ErrChkPtr(G,I);
+
+#define OOCalloc(G,type) \
+type *I;\
+  I = (type*)mcalloc(sizeof(type),1);            \
+ErrChkPtr(G,I);
 
 #define OOFreeP(ptr) \
 {if(ptr) {mfree(ptr);ptr=NULL;}}
