@@ -1,3 +1,5 @@
+
+
 /* 
 A* -------------------------------------------------------------------
 B* This file contains source code for the PyMOL computer program
@@ -28,13 +30,13 @@ Z* -------------------------------------------------------------------
 #define F4(field,P1,P2,P3,P4) Ffloat4(field,P1,P2,P3,P4)
 #define F4Ptr(field,P1,P2,P3,P4) Ffloat4p(field,P1,P2,P3,P4)
 
-int	TetsurfVolume(PyMOLGlobals *G,Isofield *field,float level,int **num,
-                    float **vert,int *range,int mode,
-                    MapType *voxelmap, float *a_vert,
-                    float carvebuffer,int side);
-void TetsurfGetRange(PyMOLGlobals *G,Isofield *field,CCrystal *cryst,float *mn,float *mx,int *range);
+int TetsurfVolume(PyMOLGlobals * G, Isofield * field, float level, int **num,
+                  float **vert, int *range, int mode,
+                  MapType * voxelmap, float *a_vert, float carvebuffer, int side);
+void TetsurfGetRange(PyMOLGlobals * G, Isofield * field, CCrystal * cryst, float *mn,
+                     float *mx, int *range);
 
-int	TetsurfInit(PyMOLGlobals *G);
-void  TetsurfFree(PyMOLGlobals *G);
+int TetsurfInit(PyMOLGlobals * G);
+void TetsurfFree(PyMOLGlobals * G);
 
 #endif
