@@ -1,3 +1,5 @@
+
+
 /* 
 A* -------------------------------------------------------------------
 B* This file contains source code for the PyMOL computer program
@@ -19,8 +21,10 @@ Z* -------------------------------------------------------------------
 #include"Vector.h"
 #include"PyMOLGlobals.h"
 
-int *TrianglePointsToSurface(PyMOLGlobals *G,float *v,float *vn,int n,float cutoff,int *nTriPtr,int **stripPtr,float *extent);
+int *TrianglePointsToSurface(PyMOLGlobals * G, float *v, float *vn, int n,
+                             float cutoff, int *nTriPtr, int **stripPtr, float *extent,
+                             int cavity_mode);
 
-int TriangleDegenerate(float *v1,float *n1,float *v2,float *n2,float *v3,float *n3);
+int TriangleDegenerate(float *v1, float *n1, float *v2, float *n2, float *v3, float *n3);
 
 #endif
