@@ -1,3 +1,5 @@
+
+
 /* 
 A* -------------------------------------------------------------------
 B* This file contains source code for the PyMOL computer program
@@ -16,15 +18,20 @@ Z* -------------------------------------------------------------------
 #ifndef _H_os_time
 #define _H_os_time
 
-#ifndef WIN32
+#include "os_predef.h"
+
+#ifndef _WIN32
 #include<sys/time.h>
 #include<unistd.h>
 #else
+
+
+/* BEGIN PROPRIETARY CODE SEGMENT (see disclaimer in "os_proprietary.h") */
 #include <sys/timeb.h>
 #include <time.h>
 #endif
 
+
+/* END PROPRIETARY CODE SEGMENT */
+
 #endif
-
-
-
