@@ -1,3 +1,4 @@
+
 /* 
 A* -------------------------------------------------------------------
 B* This file contains source code for the PyMOL computer program
@@ -19,7 +20,9 @@ Z* -------------------------------------------------------------------
 #include"Ortho.h"
 #include"Word.h"
 
-#define cButModeRotXYZ   0 
+#define cButModeNothing -1
+
+#define cButModeRotXYZ   0
 #define cButModeTransXY  1
 #define cButModeTransZ   2
 #define cButModeClipNF   3
@@ -27,8 +30,8 @@ Z* -------------------------------------------------------------------
 #define cButModeClipN    5
 #define cButModeClipF    6
 #define cButModeLB       7
-#define cButModeMB       8  
-#define cButModeRB       9  
+#define cButModeMB       8
+#define cButModeRB       9
 #define cButModeAddToLB 10
 #define cButModeAddToMB 11
 #define cButModeAddToRB 12
@@ -52,14 +55,16 @@ Z* -------------------------------------------------------------------
 
 #define cButModeSeleSet  30
 #define cButModeSeleToggle 31
-#define cButModeSeleAdd  32
-#define cButModeSeleSub  33
+#define cButModeSeleAddBox  32
+#define cButModeSeleSubBox  33
 #define cButModeMoveSlabAndZoom 34
 
+
 /* simple click action for JyMOL -- no selections involved */
 
 #define cButModeSimpleClick 35
 
+
 /* new drag actions */
 
 #define cButModeRotDrag 36
@@ -78,8 +83,17 @@ Z* -------------------------------------------------------------------
 #define cButModeMovViewZ 47
 
 #define cButModePotentialClick 48
+#define cButModeDragObj 49
+
+#define cButModeInvMoveSlabAndZoom 50
+#define cButModeInvTransZ 51
+
+#define cButModeSeleSetBox  52
+
+#define cButModeInvRotZ  53
+
+#define cButModeCount       54
 
-#define cButModeCount    49
 
 /* remainder only used in scene... */
 
@@ -92,6 +106,7 @@ Z* -------------------------------------------------------------------
 #define cButModeZoomForward 107
 #define cButModeZoomBackward 108
 
+
 /* conversion */
 
 #define cButModeLeftNone   0
@@ -196,15 +211,17 @@ Z* -------------------------------------------------------------------
 
 typedef char CodeType[10];
 
-int ButModeInit(PyMOLGlobals *G);
-void ButModeFree(PyMOLGlobals *G);
-Block *ButModeGetBlock(PyMOLGlobals *G);
-void ButModeSetRate(PyMOLGlobals *G,float renderTime);
-void ButModeResetRate(PyMOLGlobals *G);
-int ButModeGet(PyMOLGlobals *G,int button);
-void ButModeSet(PyMOLGlobals *G,int button,int action);
-void ButModeCaption(PyMOLGlobals *G,char *text);
-void ButModeCaptionReset(PyMOLGlobals *G);
-int ButModeTranslate(PyMOLGlobals *G,int button,int mod);
+int ButModeInit(PyMOLGlobals * G);
+void ButModeFree(PyMOLGlobals * G);
+Block *ButModeGetBlock(PyMOLGlobals * G);
+void ButModeSetRate(PyMOLGlobals * G, float renderTime);
+void ButModeResetRate(PyMOLGlobals * G);
+int ButModeGet(PyMOLGlobals * G, int button);
+void ButModeSet(PyMOLGlobals * G, int button, int action);
+void ButModeCaption(PyMOLGlobals * G, char *text);
+void ButModeCaptionReset(PyMOLGlobals * G);
+int ButModeTranslate(PyMOLGlobals * G, int button, int mod);
+int ButModeCheckPossibleSingleClick(PyMOLGlobals * G, int button, int mod);
+int ButModeGetHeight(PyMOLGlobals * G);
 
 #endif
