@@ -1,3 +1,4 @@
+
 /* 
 A* -------------------------------------------------------------------
 B* This file contains source code for the PyMOL computer program
@@ -16,10 +17,8 @@ Z* -------------------------------------------------------------------
 #ifndef _H_TestPyMOL
 #define _H_TestPyMOL
 
-typedef struct {
-  int i;
-} CTestPyMOL;
+#include"PyMOLGlobals.h"
 
-int TestPyMOLRun(CTestPyMOL *I,int group,int test);
+int TestPyMOLRun(PyMOLGlobals * G, int group, int test);
 
 #endif
