@@ -29,13 +29,14 @@ class Setting:
         
         while not self.cmd.ready(): # make sure PyMOL is ready for action...
             time.sleep(0.1)
-            
+
+
         self.ray_trace_frames = IntVar()
         self.ray_trace_frames.set(int(self.cmd.get_setting_legacy('ray_trace_frames')))
 
         self.draw_frames = IntVar()
         self.draw_frames.set(int(self.cmd.get_setting_legacy('draw_frames')))
-       
+
         self.cache_frames = IntVar()
         self.cache_frames.set(int(self.cmd.get_setting_legacy('cache_frames')))
 
@@ -147,11 +148,23 @@ class Setting:
         self.virtual_trackball = IntVar()
         self.virtual_trackball.set(int(self.cmd.get_setting_legacy('virtual_trackball')))
 
+        self.movie_panel = IntVar()
+        self.movie_panel.set(int(self.cmd.get_setting_legacy('movie_panel')))
+
+        self.movie_loop = IntVar()
+        self.movie_loop.set(int(self.cmd.get_setting_legacy('movie_loop')))
+
+        self.movie_auto_interpolate = IntVar()
+        self.movie_auto_interpolate.set(int(self.cmd.get_setting_legacy('movie_auto_interpolate')))
+
         self.stereo = IntVar()
-        
+
+        self.surface_solvent = IntVar()
+        self.surface_solvent.set(int(self.cmd.get_setting_legacy('surface_solvent')))
+
         self.seq_view = IntVar()
         self.seq_view.set(int(self.cmd.get_setting_legacy('seq_view')))
-        
+
         self.texture_fonts = IntVar()
         self.texture_fonts.set(int(self.cmd.get_setting_legacy('texture_fonts')))
 
@@ -170,6 +183,10 @@ class Setting:
         self.mouse_grid = IntVar()
         self.mouse_grid.set(int(self.cmd.get_setting_legacy('mouse_grid')))
 
+        self.scene_buttons = IntVar()
+        self.scene_buttons.set(int(self.cmd.get_setting_legacy('scene_buttons')))
+        self.show_frame_rate = IntVar()
+        self.show_frame_rate.set(int(self.cmd.get_setting_legacy('show_frame_rate')))
 
         self.F=[ None,
                     IntVar(),
@@ -291,6 +308,17 @@ class Setting:
             'virtual_trackball'         :
             (lambda s,a: (self.cmd.set(a,("%1.0f" % s.virtual_trackball.get()),log=1))),
             
+            'movie_panel'         :
+            (lambda s,a: (self.cmd.set(a,("%d" % s.movie_panel.get()),log=1))),
+
+            'movie_loop'         :
+            (lambda s,a: (self.cmd.set(a,("%d" % s.movie_loop.get()),log=1))),
+
+            'movie_auto_interpolate'         :
+            (lambda s,a: (self.cmd.set(a,("%d" % s.movie_auto_interpolate.get()),log=1))),
+
+            'surface_solvent'         :
+            (lambda s,a: (self.cmd.set(a,("%d" % s.surface_solvent.get()),log=1))),
             'seq_view'         :
             (lambda s,a: (self.cmd.set(a,("%d" % s.seq_view.get()),log=1))),
             'texture_fonts'         :
@@ -308,6 +336,10 @@ class Setting:
             (lambda s,a: (self.cmd.set(a,("%d" % s.auto_copy_images.get()),log=1))),
             'mouse_grid'         :
             (lambda s,a: (self.cmd.set(a,("%d" % s.mouse_grid.get()),log=1))),
+            'scene_buttons'         :
+            (lambda s,a: (self.cmd.set(a,("%d" % s.scene_buttons.get()),log=1))),
+            'show_frame_rate'         :
+            (lambda s,a: (self.cmd.set(a,("%d" % s.show_frame_rate.get()),log=1))),
 
             }
 
@@ -392,6 +424,16 @@ class Setting:
             (lambda s,t: (s.use_display_lists.set(t[1][0]!=0))),
             'virtual_trackball':
             (lambda s,t: (s.virtual_trackball.set(t[1][0]!=0))),
+
+            'movie_panel':
+            (lambda s,t: (s.movie_panel.set(t[1][0]!=0))),
+            'movie_loop':
+            (lambda s,t: (s.movie_loop.set(t[1][0]!=0))),
+            'movie_auto_interpolate':
+            (lambda s,t: (s.movie_auto_interpolate.set(t[1][0]!=0))),
+
+            'surface_solvent':
+            (lambda s,t: (s.surface_solvent.set(t[1][0]!=0))),
             'seq_view':
             (lambda s,t: (s.seq_view.set(t[1][0]!=0))),
             'texture_fonts':
@@ -408,6 +450,10 @@ class Setting:
             (lambda s,t: (s.auto_copy_images.set(int(t[1][0])))),
             'mouse_grid':
             (lambda s,t: (s.mouse_grid.set(int(t[1][0])))),
+            'scene_buttons':
+            (lambda s,t: (s.scene_buttons.set(int(t[1][0])))),
+            'show_frame_rate':
+            (lambda s,t: (s.show_frame_rate.set(int(t[1][0])))),
             }
         self.active_list = [
             self.pymol.setting._get_index("ray_trace_frames"),
@@ -450,6 +496,10 @@ class Setting:
             self.pymol.setting._get_index("scenes_changed"),
             self.pymol.setting._get_index("use_display_lists"),
             self.pymol.setting._get_index("virtual_trackball"),
+            self.pymol.setting._get_index("movie_panel"),
+            self.pymol.setting._get_index("movie_loop"),
+            self.pymol.setting._get_index("movie_auto_interpolate"),
+            self.pymol.setting._get_index("surface_solvent"),
             self.pymol.setting._get_index("seq_view"),
             self.pymol.setting._get_index("texture_fonts"),
             self.pymol.setting._get_index("stereo"),
@@ -458,6 +508,8 @@ class Setting:
             self.pymol.setting._get_index("show_alpha_checker"),
             self.pymol.setting._get_index("auto_copy_images"),
             self.pymol.setting._get_index("mouse_grid"),
+            self.pymol.setting._get_index("scene_buttons"),
+            self.pymol.setting._get_index("show_frame_rate"),            
             ]
 
         self.active_dict = {}
