@@ -29,7 +29,7 @@
 # message.  This is not a bug in PyMOL, as it can be produced with a
 # trivial tcl/tk program.  (Tentatively WORKED AROUND in 0.99beta18!)
 
-from copy import deepcopy
+import copy
 import __main__
 if __name__!='__main__':
     import invocation
@@ -37,8 +37,8 @@ if __name__!='__main__':
 # Global variable "__main__.pymol_launch" tracks how we're launching PyMOL:
 #
 # 0: old way, now obsolete (e.g. "python launch_pymol.py")
-# 1: new way, spawn thread on import: (e.g. from "import pymol")
-# 2: new way, consume main thread: (e.g. from "python pymol/__init__.py")
+# 1: new way, consume main thread: (e.g. from "python pymol/__init__.py")
+# 2: new way, spawn own thread: (e.g."import pymol; pymol.finish_launching()")
 # 3: dry run -- just get PyMOL environment information
 # 4: monolithic (embedded) PyMOL.  Prime, but don't start.
 # 5: Python embedded launch from within the PyMOL API
@@ -91,7 +91,7 @@ def _init_internals(_pymol):
     _pymol._view_dict_sc = None
 
     # stored scenes
-    
+
     _pymol._scene_dict = {}
     _pymol._scene_dict_sc = None
     _pymol._scene_order = []
@@ -99,9 +99,9 @@ def _init_internals(_pymol):
     _pymol._scene_quit_on_action = ''
 
     # get us a private invocation pseudo-module
-    
+
     _pymol._invocation = Scratch_Storage()
-    _pymol._invocation.options = deepcopy(invocation.options)
+    _pymol._invocation.options = copy.deepcopy(invocation.options)
     _pymol._invocation.get_user_config = invocation.get_user_config
     _pymol._invocation.parse_args = invocation.parse_args
 
@@ -117,8 +117,8 @@ def _init_internals(_pymol):
 if hasattr(__main__,'pymol_launch'):
     pymol_launch = __main__.pymol_launch
 else:
-    pymol_launch = 2 
-    
+    pymol_launch = 2 # default is standard threaded launch (unless overridden)
+
 if pymol_launch != 3: # if this isn't a dry run
 
     import thread 
@@ -166,7 +166,8 @@ if pymol_launch != 3: # if this isn't a dry run
             __main__.pymol_argv = sys.argv
 
         pymol_launch = -1 # non-threaded launch import flag
-
+        # NOTE: overrides current value (if any)
+        
         try_again = 0
 
         try:
@@ -174,7 +175,7 @@ if pymol_launch != 3: # if this isn't a dry run
         except ImportError:
             try_again = 1
 
-        if try_again:
+        if try_again: # insert directory with this file into search path
             try:
                 sys.exc_clear()
                 sys.path.insert(0,os.path.dirname(os.path.dirname(__file__)))
@@ -182,16 +183,16 @@ if pymol_launch != 3: # if this isn't a dry run
                 pass
             import pymol
         
-        pymol_launch = 1
+        pymol_launch = 1 # consume main thread for use by PyMOL
     
-    elif pymol_launch==-1:
+    elif pymol_launch == -1: # just passing through
 
         if hasattr(__main__,"pymol_argv"):
             pymol_argv = __main__.pymol_argv
         else:
             pymol_argv = [ "pymol", "-q" ]
 
-    elif pymol_launch==2:
+    elif pymol_launch == 2: # standard threaded launch
 
         if hasattr(__main__,"pymol_argv"):
             pymol_argv = __main__.pymol_argv
@@ -245,10 +246,24 @@ if pymol_launch != 3: # if this isn't a dry run
 
         if '' not in sys.path: # make sure cwd is in path like normal Python
             sys.path.insert(0,'') 
-    
+
         sys.setcheckinterval(1) # maximize responsiveness
 
+        # auto-detect bundled FREEMOL (if present)
         
+        if not os.environ.has_key("FREEMOL"):
+            test_path = os.path.join(os.environ['PYMOL_PATH'],"freemol")
+            if os.path.isdir(test_path):
+                os.environ['FREEMOL'] = test_path
+                
+        # include FREEMOL's libpy in sys.path (if present)
+        
+        if os.environ.has_key("FREEMOL"):
+            freemol_libpy = os.path.join(os.environ['FREEMOL'],"libpy")
+            if os.path.isdir(freemol_libpy):
+                if freemol_libpy not in sys.path:
+                    sys.path.append(freemol_libpy)
+                
         def exec_str(self,st):
             try:
                 exec st in self.__dict__, self.__dict__
@@ -257,6 +272,7 @@ if pymol_launch != 3: # if this isn't a dry run
             return None
 
         def exec_deferred(self):
+            import socket
             cmd=self.cmd
             if self.invocation.options.read_stdin:
                 try:
@@ -266,6 +282,7 @@ if pymol_launch != 3: # if this isn't a dry run
                 except:
                     traceback.print_exc()
             try:
+                socket_error = 0
                 if cmd.ready():
                     cmd.config_mouse(quiet=1)
                     for a in self.invocation.options.deferred:
@@ -283,9 +300,19 @@ if pymol_launch != 3: # if this isn't a dry run
                             cmd.load(a,quiet=0)
             except CmdException:
                 traceback.print_exc()
-                print "Error: Argument processing aborted due to exception."
-            except:
-                traceback.print_exc()
+                print "Error: Argument processing aborted due to exception (above)."
+            except socket.error:
+                socket_error = 1
+
+            if socket_error:
+                # this (should) only happen if we're opening a PWG file on startup
+                # and the port is busy.  For now, simply bail...
+                cmd.wizard("message",["Socket.error: ","",
+                                      "\\999Assigned socket in use.","",
+                                      "\\779Is PyMOL already launched?","",
+                                      "\\966Shutting down..."])
+                cmd.refresh()
+                cmd.do("time.sleep(2);cmd.quit()")
 
         def adapt_to_hardware(self):
             cmd=self.cmd
@@ -298,48 +325,53 @@ if pymol_launch != 3: # if this isn't a dry run
                     
             # optimize for (or workaround) specific hardware
             (vendor,renderer,version) = cmd.get_renderer()
-            if vendor[0:6]=='NVIDIA':
-                cmd.set('ribbon_smooth',0,quiet=1)
-                if renderer[0:7]=='GeForce':
-                    if self.invocation.options.show_splash:
-                        print " Adapting to GeForce hardware."
-                    cmd.set('line_width','2',quiet=1)
-                elif renderer=='NVIDIA GPU OpenGL Engine':
-                    if sys.platform=='darwin':
-                        if self.invocation.options.show_splash:
-                            print " Adapting to NVIDIA hardware on Mac."
-                            cmd.set('line_smooth',0,quiet=1)
-                            cmd.set('fog',0.9,quiet=1)
-                elif renderer=='NVIDIA GeForce4 GPU OpenGL Engine':
-                    if sys.platform=='darwin':
-                        if invocation.options.show_splash:
-                            cmd.set('stereo_double_pump_mono',1,quiet=1)
 
-                elif renderer[0:6]=='Quadro':
+            # Quadro cards don't support GL_BACK in stereo contexts
+            if vendor[0:6]=='NVIDIA':
+                if 'Quadro' in renderer:
                     if invocation.options.show_splash:
                         print " Adapting to Quadro hardware."
-                    cmd.set("stereo_double_pump_mono","1",quiet=1)
-                    cmd.set("line_width",1.4,quiet=1)
+                    cmd.set('stereo_double_pump_mono',1)                    
 
             elif vendor[0:4]=='Mesa':
                 if renderer[0:18]=='Mesa GLX Indirect':
-                    cmd.set('ribbon_smooth',0,quiet=1)
+                    pass
 
             elif vendor[0:9]=='Parallels':
                 if renderer[0:8]=='Parallel':
+                    pass
                     # this was critical for older Parallels
                     # but actually slows down current versions
-                    cmd.set('texture_fonts',1) 
+                    # cmd.set('texture_fonts',1) 
 
             elif vendor[0:3]=='ATI':
-                cmd.set('ribbon_smooth',0,quiet=1)
-                if renderer[0:17]=='FireGL2 / FireGL3':
+                if renderer[0:17]=='FireGL2 / FireGL3':  # obsolete ?
                     if invocation.options.show_splash:
                         print " Adapting to FireGL hardware."
                     cmd.set('line_width','2',quiet=1)            
+
                 if sys.platform[0:3]=='win':
                     if sys.getwindowsversion()[0]>5:
-                        cmd.set('ati_bugs',1) # Ugh, VISTA.
+                        # prevent color corruption by calling glFlush etc.
+                        cmd.set('ati_bugs',1) 
+                        
+                if 'Radeon HD' in renderer:
+                    print " Note: Radeon HD cards tend not to run PyMOL well."
+                    print " Use nVidia or Intel instead, if OpenGL glitches occur."
+                    print " Attempting to compensate for known issues..."
+
+                    # use display lists to minimize use of OpenGL
+                    # immediate mode rendering (unreasonably slow on
+                    # Radeon HD cards!)
+                    cmd.set("use_display_lists") 
+
+                    # disable line smooothing to prevent various
+                    # bizarre screen-update and drawing artifacts
+                    cmd.unset("line_smooth")
+
+                    # limit frame rate to 30 fps to avoid ATI "jello"
+                    # where screen updates fall way behind the user.
+                    cmd.set("max_ups",30) 
 
             elif vendor[0:9]=='Microsoft':
                 if renderer[0:17]=='GDI Generic':
@@ -370,7 +402,8 @@ if pymol_launch != 3: # if this isn't a dry run
                                     elif mem<256000000:
                                         cmd.set("hash_max",70)
                 elif sys.platform[0:5]=='linux':
-                    f=os.popen("egrep -c '^processor[^A-Za-z0-9:]*: [0-9]' /proc/cpuinfo")
+                    f=os.popen(
+         "egrep -c '^processor[^A-Za-z0-9:]*: [0-9]' /proc/cpuinfo")
                     l=f.readlines()
                     f.close()
                     ncpu = int(l[0])
@@ -386,8 +419,7 @@ if pymol_launch != 3: # if this isn't a dry run
                           print " Enabled multithreaded rendering."
             except:
                 pass
-
-        # NEED SOME CONTRIBUTIONS HERE!
+            cmd.reinitialize("store") # store our adapted state as default
 
         def launch_gui(self):
             try:
@@ -400,7 +432,8 @@ if pymol_launch != 3: # if this isn't a dry run
                     __import__(self.invocation.options.gui)
                     sys.modules[self.invocation.options.gui].__init__(self,poll,skin)
                 elif self.invocation.options.external_gui==3:
-                    os.environ['DISPLAY']=':0.0'
+                    if not os.environ.has_key('DISPLAY'):
+                        os.environ['DISPLAY']=':0.0'
                     os.environ['TCL_LIBRARY']=os.environ['PYMOL_PATH']+"/ext/lib/tcl8.4"
                     os.environ['TK_LIBRARY']=os.environ['PYMOL_PATH']+"/ext/lib/tk8.4"
                     __import__(self.invocation.options.gui)
@@ -413,6 +446,7 @@ if pymol_launch != 3: # if this isn't a dry run
             # --
             except:
                 traceback.print_exc()
+
     def prime_pymol():
         global glutThread
         try:
@@ -444,8 +478,8 @@ if pymol_launch != 3: # if this isn't a dry run
         from pymol import invocation
         invocation.parse_args(pa)
         start_pymol(1)
-
-    if pymol_launch==1: # standard launch (absorb main thread)
+    
+    if pymol_launch == 1: # standard launch (consume main thread)
         cmd._COb = _cmd._get_global_C_object()
         if __name__=='pymol':
             _COb = cmd._COb
@@ -455,20 +489,15 @@ if pymol_launch != 3: # if this isn't a dry run
         invocation.parse_args(pymol_argv)            
         start_pymol(0)
 
-    elif pymol_launch==2: # threaded launch (create new thread)
+    elif pymol_launch == 2: # threaded launch (create new thread)
         cmd._COb = _cmd._get_global_C_object()
         if __name__=='pymol':
             _COb = cmd._COb
         else:
             pymol._COb = cmd._COb
-        global glutThreadObject
-        cmd.reaper = threading.currentThread()
-        glutThreadObject = threading.Thread(target=thread_launch,
-          args=(pymol_argv+["-K"],)) # keep PyMOL thread alive
-                                              # even w/o GUI
-        glutThreadObject.start()
-
-    elif pymol_launch==4: # monolithic (embedded) launch
+        # don't do anything else yet...wait for finish_launching() call
+        
+    elif pymol_launch == 4: # monolithic (embedded) launch
         cmd._COb = _cmd._get_global_C_object()
         if __name__=='pymol':
             _COb = cmd._COb
@@ -479,10 +508,20 @@ if pymol_launch != 3: # if this isn't a dry run
         prime_pymol()
         # count on host process to actually start PyMOL
 
-    if os.environ.has_key('DISPLAY'):
+    if os.environ.has_key('DISPLAY'): # get X-window support
         from xwin import *
 
-    def finish_launching():
+    def finish_launching(args=None):
+        if args == None:
+            args = pymol_argv+["-K"] # keep PyMOL thread alive
+        else:
+            args = list(args)
+        if pymol_launch == 2: # spawn thread -- 'import pymol'
+            global glutThreadObject
+            cmd.reaper = threading.currentThread()
+            glutThreadObject = threading.Thread(target=thread_launch,
+              args=(args,)) 
+            glutThreadObject.start()
         _COb = _cmd._get_global_C_object()
         e=threading.Event()
         import pymol # wait for import to complete
