@@ -16,6 +16,7 @@ from importing import \
       loadable,           \
       read_mmodstr,       \
       read_molstr,        \
+      read_sdfstr,        \
       read_pdbstr,        \
       read_xplorstr,      \
       fetch,              \
@@ -92,12 +93,17 @@ from querying import \
       get_atom_coords,    \
       get_dihedral,       \
       get_distance,       \
+      get_drag_object_name, \
       get_extent,         \
+      get_idtf,           \
+      get_modal_draw,     \
       get_model,          \
       get_movie_locked,   \
       get_movie_length,   \
       get_names,          \
       get_names_of_type,  \
+      get_legal_name,     \
+      get_unused_name,    \
       get_object_matrix,  \
       get_mtl_obj,        \
       get_phipsi,         \
@@ -132,6 +138,7 @@ from exporting import \
       export_coords,      \
       get_pdbstr,         \
       get_session,        \
+      get_fastastr,       \
       multisave,          \
       png,                \
       save               
@@ -168,6 +175,7 @@ from editing import \
       matrix_reset,       \
       protect,            \
       push_undo,          \
+      reference,          \
       redo,               \
       remove,             \
       remove_picked,      \
@@ -200,6 +208,12 @@ from editing import \
       valence,            \
       vdw_fit 
 
+from editor import \
+      fab
+      
+from computing import \
+      clean              
+
 matrix_transfer = matrix_copy # legacy
 
 #--------------------------------------------------------------------
@@ -235,6 +249,7 @@ from fitting import \
       pair_fit          
 
 #--------------------------------------------------------------------
+# ARE ALL OF THESE UNUSED AND/OR DEPRECATED (?)
 from preset import \
       simple,            \
       technical,         \
@@ -245,6 +260,10 @@ from preset import \
 import moving
 from moving import \
       madd,              \
+      mcopy,             \
+      mdelete,           \
+      mmove,             \
+      minsert,           \
       mset,              \
       mclear,            \
       mdo,               \
@@ -267,6 +286,7 @@ from moving import \
       mray,              \
       frame,             \
       get_movie_playing, \
+      set_frame,         \
       get_state,         \
       get_frame         
 
@@ -294,6 +314,7 @@ from viewing import \
       get_scene_list,     \
       hide,               \
       label,              \
+      label2,             \
       load_png,           \
       meter_reset,        \
       move,               \
@@ -372,10 +393,11 @@ from experimenting import \
 
 import util
 import movie
+import gui
 
 # dang! Python 2.6 will break PyMOL's "as" method. 
 # Proposal:
 #  1. stick with Python <=2.5 for as long as possible
 #  2. convert API method to cmd.show_as() and leave "as" in the scripting langauge
 #  3. allow "show_as" in the scripting language
-as = show_as
+globals()['as'] = show_as
