@@ -7,6 +7,8 @@ import re
 import string
 from cmd import Shortcut
 
+gz_ext_re = re.compile("\.gz$", re.I)
+
 file_ext_re = re.compile(string.join([
     "\.pdb$|\.pdb1$|\.ent$|\.mol$|\.p5m$|",
     r"\.mmod$|\.mmd$|\.dat$|\.out$|\.mol2$|",
@@ -30,7 +32,8 @@ file_ext_re = re.compile(string.join([
     r"\.fld$|", # FLD format (AVS)
     r"\.trj$|\.trr$|\.xtc$|\.gro$|\.g96$|\.dcd$|", # Trajectories
     r"\.o$|\.omap$|\.dsn6$|\.brix$|", # BRIX/O format
-    r"\.grd$", # InsightII Grid format
+    r"\.grd$|", # InsightII Grid format
+    r"\.acnt$", # Tripos / Sybyl ACNT format
     ],''), re.I)
 
 class loadable:
@@ -60,7 +63,7 @@ class loadable:
     pse = 25      # PyMOL session
     xplorstr = 26 # XPLOR map as string
     phi = 27      # Delphi/Grasp
-    fld = 28      # AVS field format (not yet general -- just uniform allowed)
+    fld = 28      # AVS field format (not yet general -- only uniform allowed)
     brix = 29     # BRIX/DSN6/O map format
     grd = 30      # Insight II Grid format
     pqr = 31      # PQR file (modified PDB file for APBS)
@@ -84,7 +87,14 @@ class loadable:
     cube = 48     # cube volume file (via plugin)
     mae = 49      # Schrodinger ".mae" format (proprietary)
     cif1 = 50     # Python-based CIF parser
-    
+    phistr = 51   # electrostatic map as a string
+    pim = 52      # General-purpose programmatic import (powerful, insecure)
+    pwg = 53      # PyMOL web gui launch script
+    aln = 54      # CLUSTALW alignment file
+    fasta = 55    # FASTA sequence file
+    acnt = 56     # Tripos/Sybyl acnt grid file (proposed)
+    dtr = 57      # DESRES / Desmond    
+
 _load2str = { loadable.pdb : loadable.pdbstr,
               loadable.mol : loadable.molstr,
               loadable.xplor : loadable.xplorstr,
@@ -93,7 +103,7 @@ _load2str = { loadable.pdb : loadable.pdbstr,
               loadable.ccp4 : loadable.ccp4str,
               loadable.sdf2 : loadable.sdf2str}
 
-safe_oname_re = re.compile(r"\ |\+|\(|\)|\||\&|\!|\,")  # quash reserved characters
+safe_oname_re = re.compile(r"\ |\(|\)|\||\&|\!|\,")  # quash reserved characters
 sanitize_list_re = re.compile(r"[^0-9\.\-\[\]\,]+")
 sanitize_alpha_list_re = re.compile(r"[^a-zA-Z0-9_\'\"\.\-\[\]\,]+")
 nt_hidden_path_re = re.compile(r"\$[\/\\]")
@@ -101,13 +111,13 @@ quote_alpha_list_re = re.compile(
     r'''([\[\,]\s*)([a-zA-Z_][a-zA-Z0-9_\ ]*[a-zA-Z0-9_]*)(\s*[\,\]])''')
 
 def safe_list_eval(st):
-    return eval(sanitize_list_re.sub('',st))
+    return eval(sanitize_list_re.sub('',st)) 
 
 def safe_alpha_list_eval(st):
     st = sanitize_alpha_list_re.sub('',st)
     st = quote_alpha_list_re.sub(r'\1"\2"\3',st) # need to do this twice
     st = quote_alpha_list_re.sub(r'\1"\2"\3',st)
-    return eval(sanitize_alpha_list_re.sub('',st))
+    return eval(sanitize_alpha_list_re.sub('',st)) 
 
 QuietException = parsing.QuietException
 
@@ -120,9 +130,12 @@ DEFAULT_SUCCESS = None
 toggle_dict = {'on':1,'off':0,'1':1,'0':0,'toggle':-1, '-1':-1}
 toggle_sc = Shortcut(toggle_dict.keys())
 
-stereo_dict = {'on':1,'off':0,'1':1,'0':0,'swap':-1,
-               'crosseye':2,'quadbuffer':3,
-               'walleye':4,'geowall':5,'sidebyside':6}
+stereo_dict = {'on':-2,'off':0,'0':0,'1':-2,'swap':-1,
+               'quadbuffer':1,'crosseye':2,
+               'walleye':3,'geowall':4,'sidebyside':5,
+               'byrow':6, 'bycolumn':7, 'checkerboard':8, 
+               'custom': 9, 'anaglyph' : 10, 
+               'dynamic' : 11, 'clonedynamic': 12 }
 
 stereo_sc = Shortcut(stereo_dict.keys())
 
@@ -265,6 +278,7 @@ palette_sc = Shortcut(palette_dict.keys())
 location_code = {
     'first' : -1,
     'top' : -1,
+    'upper' : -2,
     'current' : 0,
     'bottom' : 1,
     'last' : 1
