@@ -43,10 +43,10 @@ if __name__=='pymol.controlling':
         'shft'  : 1,
         'ctrl'  : 2,
         'ctsh'  : 3,
-	'alt'   : 4,
-	'alsh'  : 5,
-	'ctal'  : 6,
-	'ctas'  : 7,
+    'alt'   : 4,
+    'alsh'  : 5,
+    'ctal'  : 6,
+    'ctas'  : 7,
         }
 
     but_mod_sc = Shortcut(but_mod_code.keys())
@@ -108,26 +108,49 @@ if __name__=='pymol.controlling':
         # 48 for internal use only
         
         'drgo' : 49 ,
+
+        'imsz' : 50 ,
+        'imvz' : 51 ,
+        'box'  : 52 ,
+        'irtz' : 53
         }
     
     but_act_sc = Shortcut(but_act_code.keys())
 
     ring_dict = {
+        'maestro' : [   'three_button_maestro' ],
+        
         'three_button' : [   'three_button_viewing',
-                             'three_button_editing' ],
-        'two_button' : [ 'two_button_viewing',
-                         'two_button_selecting',
-                         ],
+                             'three_button_editing'  ], # LEGACY
 
-        'two_button_editing' : [ 'two_button_viewing',
+        'three_button_viewing' : [   'three_button_viewing',
+                                     'three_button_editing'  ],
+
+        'three_button_editing' : [  'three_button_editing', 
+                                    'three_button_viewing', ],
+
+        'two_button' : [ 'two_button_viewing', # LEGACY
+                         'two_button_selecting' ],
+
+        'two_button_viewing' : [ 'two_button_viewing', 
+                                 'two_button_selecting' ],
+
+        'two_button_editing' : [ 'two_button_editing',
+                                 'two_button_viewing',
                                  'two_button_selecting',
-                                 'two_button_editing',
                                  ],
-        'three_button_motions' : [   'three_button_viewing',
-                                     'three_button_editing',
-                                     'three_button_motions' ],
+
+        'three_button_motions' : [   'three_button_motions',
+                                     'three_button_viewing', ],
+
+        'three_button_all_modes' : [ 'three_button_editing',
+                                     'three_button_motions',
+                                     'three_button_viewing',
+                                      ],
+
         'one_button' : [   'one_button_viewing' ],
         }
+    ring_dict_sc = Shortcut(ring_dict.keys())
 
     def config_mouse(ring='three_button', quiet=1, _self=cmd):
 
@@ -154,20 +177,21 @@ SEE ALSO
 
     mouse, button
     '''
-        
         global mouse_ring
+        ring=ring_dict_sc.auto_err(ring,'mouse cycle')
         if ring_dict.has_key(ring):
+            _self.set("button_mode",0);
             mouse_ring = ring_dict[ring]
             if not quiet:
                 print " config_mouse: %s"%ring
             _self.mouse(quiet=1,_self=_self)
-
         else:
             print " Error: unrecognized mouse ring: '%s'"%ring
 
     mouse_ring = ring_dict['three_button']
 
     mode_name_dict = {
+        'three_button_maestro' : '3-Button Maestro',        
         'three_button_viewing' : '3-Button Viewing',
         'three_button_editing' : '3-Button Editing',
         'three_button_motions':  '3-Button Motions',
@@ -177,210 +201,260 @@ SEE ALSO
         'one_button_viewing'   : '1-Button Viewing',
         }
 
+    mode_name_list = [ 
+        'three_button_viewing',
+        'three_button_editing',
+        'three_button_motions',
+        'three_button_maestro' ,        
+        'two_button_viewing' ,
+        'two_button_selecting' ,
+        'two_button_editing',
+        'one_button_viewing' , 
+        # okay to append new mode name, but don't insert: order & position matter
+        ]
+
     mode_dict = {
-        'three_button_viewing' : [ ('l','none','rota'),
-				   ('m','none','move'),
-				   ('r','none','movz'),
-				   ('l','shft','+Box'),
-				   ('m','shft','-Box'),
-				   ('r','shft','clip'),                 
-				   ('l','ctrl','+/-'),
-				   ('m','ctrl','pkat'),
-				   ('r','ctrl','pk1'),                 
-				   ('l','ctsh','Sele'),
-				   ('m','ctsh','orig'),
-				   ('r','ctsh','clip'),
-				   ('l','alt' ,'none'),
-				   ('m','alt' ,'none'),
-				   ('r','alt' ,'none'),
-				   ('w','none','slab'),
-				   ('w','shft','movs'),
-				   ('w','ctrl','mvsz'),
-				   ('w','ctsh','movz'),
-				   ('double_left','none','menu'),
-				   ('double_middle','none','none'),
-				   ('double_right','none', 'pkat'),
-				   ('single_left','none','+/-'),
-				   ('single_middle','none','cent'),
-				   ('single_right','none', 'menu'),
-				   ],
-        'three_button_editing': [ ('l','none','rota'),
-				  ('m','none','move'),
-				  ('r','none','movz'),
-				  ('l','shft','roto'),
-				  ('m','shft','movo'),
-				  ('r','shft','mvoz') ,                 
-				  ('l','ctrl','torf'),
-				  ('m','ctrl','pkat'),
-				  ('r','ctrl','pktb'),                  
-				  ('l','ctsh','mova'),
-				  ('m','ctsh','orig'),
-				  ('r','ctsh','clip'),
-				  ('l','alt' ,'none'),
-				  ('m','alt' ,'none'),
-				  ('r','alt' ,'none'),
-				  ('w','none','slab'),
-				  ('w','shft','movs'),
-				  ('w','ctrl','mvsz'),
-				  ('w','ctsh','movz'),
-				  ('double_left','none','torf'),
-				  ('double_middle','none','drgm'),
-				  ('double_right','none', 'pktb'),
-				  ('single_left','none','pkat'),
-				  ('single_middle','none','cent'),
-				  ('single_right','none', 'menu'),
-				  ],
-	
-        'three_button_motions': [ ('l','none','rota'),
-				  ('m','none','move'),
-				  ('r','none','movz'),
-				  ('l','shft','rotv'),
-				  ('m','shft','movv'),
-				  ('r','shft','mvvz') ,                 
-				  ('l','ctrl','torf'),
-				  ('m','ctrl','pkat'),
-				  ('r','ctrl','pktb'),                  
-				  ('l','ctsh','mova'),
-				  ('m','ctsh','orig'),
-				  ('r','ctsh','clip'),
-				  ('l','alt' ,'none'),
-				  ('m','alt' ,'none'),
-				  ('r','alt' ,'none'),
-				  ('w','none','slab'),
-				  ('w','shft','movs'),
-				  ('w','ctrl','mvsz'),
-				  ('w','ctsh','movz'),
-				  ('double_left','none','menu'),
-				  ('double_left','none','torf'),
-				  ('double_middle','none','drgm'),
-				  ('double_right','none', 'pktb'),
-				  ('single_left','none','pkat'),
-				  ('single_middle','none','cent'),
-				  ('single_right','none', 'menu'),
-				  ],
-
-        'two_button_viewing' : [ ('l','none','rota'),
-				 ('m','none','none'),
-				 ('r','none','movz'),
-				 ('l','shft','pk1'),
-				 ('m','shft','none'),
-				 ('r','shft','clip'),                 
-				 ('l','ctrl','move'),
-				 ('m','ctrl','none'),
-				 ('r','ctrl','pkat'),                 
-				 ('l','ctsh','sele'),
-				 ('m','ctsh','none'),
-				 ('r','ctsh','cent'),
-				 ('l','alt' ,'none'),
-				 ('m','alt' ,'none'),
-				 ('r','alt' ,'none'),
-				 ('w','none','none'),
-				 ('w','shft','none'),
-				 ('w','ctrl','none'),
-				 ('w','ctsh','none'),
-				 ('double_left','none','menu'),
-				 ('double_middle','none','none'),                               
-				 ('double_right','none','cent'),
-				 ('single_left','none','pkat'),
-				 ('single_middle','none','none'),
-				 ('single_right','none', 'menu'),
-				 ],
-        'two_button_selecting' : [ ('l','none','rota'),
-				   ('m','none','none'),
-				   ('r','none','movz'),
-				   ('l','shft','+Box'),
-				   ('m','shft','none'),
-				   ('r','shft','-Box'),                 
-				   ('l','ctrl','+/-'),
-				   ('m','ctrl','none'),
-				   ('r','ctrl','pkat'),                 
-				   ('l','ctsh','sele'),
-				   ('m','ctsh','none'),
-				   ('r','ctsh','cent'),
-				   ('l','alt' ,'none'),
-				   ('m','alt' ,'none'),
-				   ('r','alt' ,'none'),
-				   ('w','none','none'),
-				   ('w','shft','none'),
-				   ('w','ctrl','none'),
-				   ('w','ctsh','none'),
-				   ('double_left','none','menu'),
-				   ('double_left','none','menu'),
-				   ('double_middle','none','none'),                               
-				   ('double_right','none','cent'),
-				   ('single_left','none','+/-'),
-				   ('single_right','none', 'menu'),
-				   ],
-        'two_button_editing' : [ ('l','none','rota'),
-				 ('m','none','none'),
-				 ('r','none','movz'),
-				 ('l','shft','pkat'),
-				 ('m','shft','none'),
-				 ('r','shft','clip'),                 
-				 ('l','ctrl','torf'),
-				 ('m','ctrl','none'),
-				 ('r','ctrl','pktb'),                 
-				 ('l','ctsh','rotf'),
-				 ('m','ctsh','none'),
-				 ('r','ctsh','movf'),
-				 ('l','alt' ,'none'),
-				 ('m','alt' ,'none'),
-				 ('r','alt' ,'none'),
-				 ('w','none','none'),
-				 ('w','shft','none'),
-				 ('w','ctrl','none'),
-				 ('w','ctsh','none'),
-				 ('double_left','none','menu'),
-				 ('double_middle','none','none'),                               
-				 ('double_right','none','cent'),
-				 ('single_left','none','pkat'),
-				 ('single_middle','none','none'),                               
-				 ('single_right','none','menu'),                               
-				 ],
-         'one_button_viewing' : [ ('l','none','rota'), # approximate the old GLUT behavior on Mac
-				  ('m','none','none'),
-				  ('r','none','none'),
-				  ('l','shft','+Box'),
-				  ('m','shft','none'),
-				  ('r','shft','none'),
-				  ('l','ctrl','movZ'),
-				  ('m','ctrl','none'),
-				  ('r','ctrl','none'),
-				  ('l','ctsh','clip'),
-				  ('m','ctsh','none'),
-				  ('r','ctsh','none'),
-				  ('l','alt' ,'move'),
-				  ('m','alt' ,'none'),
-				  ('r','alt' ,'none'),
-				  ('l','alsh' ,'-Box'),
-				  ('m','alsh' ,'none'),
-				  ('r','alsh' ,'none'),
-				  ('l','ctal' ,'none'),
-				  ('m','ctal' ,'none'),
-				  ('r','ctal' ,'none'),
-				  ('l','ctas' ,'none'),
-				  ('m','ctas' ,'none'),
-				  ('r','ctas' ,'none'),
-				  ('w','none','none'),
-				  ('w','shft','none'),
-				  ('w','ctrl','none'),
-				  ('w','ctsh','none'),
-				  ('double_left','none','menu'),
-				  ('double_middle','none','none'),
-				  ('double_right','none', 'none'),
-				  ('single_left','none','+/-'),
-				  ('single_middle','none','none'),
-				  ('single_right','none', 'none'),
-
-				  ('single_left','shft','none'),
-				  ('single_left','ctrl','menu'),
-				  ('single_left','ctsh','pkat'), 
-				  ('single_left','alt', 'cent'),
-				  ('single_left','alsh','none'),
-				  ('single_left','ctal','none'),
-				  ('single_left','ctas','none'),
-
-				  ],
+        'three_button_maestro' :
+        [ ('l','none','box'),
+          ('m','none','rota'),
+          ('r','none','move'),
+          ('l','shft','+Box'),
+          ('m','shft','-Box'),
+          ('r','shft','clip'),                 
+          ('l','ctrl','+/-'),
+          ('m','ctrl','irtz'),
+          ('r','ctrl','pk1'),                 
+          ('l','ctsh','Sele'),
+          ('m','ctsh','orig'),
+          ('r','ctsh','clip'),
+          ('l','alt' ,'move'),
+          ('m','alt' ,'none'),
+          ('r','alt' ,'none'),
+          ('w','none','imvz'),
+          ('w','shft','movs'),
+          ('w','ctrl','none'), # disable since ctrl-middle is irtz
+          ('w','ctsh','slab'),
+          ('double_left','none','menu'),
+          ('double_middle','none','none'),
+          ('double_right','none', 'pkat'),
+          ('single_left','none','sele'),
+          ('single_middle','none','cent'),
+          ('single_right','none', 'menu'),
+          ('single_left','shft','+/-'),
+          ('single_left','alt', 'cent'),
+          ],
+        'three_button_viewing' :
+        [ ('l','none','rota'),
+          ('m','none','move'),
+          ('r','none','movz'),
+          ('l','shft','+Box'),
+          ('m','shft','-Box'),
+          ('r','shft','clip'),                 
+          ('l','ctrl','+/-'),
+          ('m','ctrl','pkat'),
+          ('r','ctrl','pk1'),                 
+          ('l','ctsh','Sele'),
+          ('m','ctsh','orig'),
+          ('r','ctsh','clip'),
+          ('l','alt' ,'move'),
+          ('m','alt' ,'none'),
+          ('r','alt' ,'none'),
+          ('w','none','slab'),
+          ('w','shft','movs'),
+          ('w','ctrl','mvsz'),
+          ('w','ctsh','movz'),
+          ('double_left','none','menu'),
+          ('double_middle','none','none'),
+          ('double_right','none', 'pkat'),
+          ('single_left','none','+/-'),
+          ('single_middle','none','cent'),
+          ('single_right','none', 'menu'),
+          ('single_left','alt', 'cent'),
+          ],
+        'three_button_editing':
+        [ ('l','none','rota'),
+          ('m','none','move'),
+          ('r','none','movz'),
+          ('l','shft','roto'),
+          ('m','shft','movo'),
+          ('r','shft','mvoz') ,                 
+          ('l','ctrl','torf'),
+          ('m','ctrl','+/-'),
+          ('r','ctrl','pktb'),                  
+          ('l','ctsh','mova'),
+          ('m','ctsh','orig'),
+          ('r','ctsh','clip'),
+          ('l','alt' ,'move'),
+          ('m','alt' ,'none'),
+          ('r','alt' ,'none'),
+          ('w','none','slab'),
+          ('w','shft','movs'),
+          ('w','ctrl','mvsz'),
+          ('w','ctsh','movz'),
+          ('double_left','none','torf'),
+          ('double_middle','none','drgm'),
+          ('double_right','none', 'pktb'),
+          ('single_left','none','pkat'),
+          ('single_middle','none','cent'),
+          ('single_right','none', 'menu'),
+          ('single_left','alt', 'cent'),
+          ],
+        'three_button_motions':
+        [ ('l','none','rota'),
+          ('m','none','move'),
+          ('r','none','movz'),
+          ('l','shft','rotv'),
+          ('m','shft','movv'),
+          ('r','shft','mvvz') ,                 
+          ('l','ctrl','torf'),
+          ('m','ctrl','pkat'),
+          ('r','ctrl','pktb'),                  
+          ('l','ctsh','mova'),
+          ('m','ctsh','orig'),
+          ('r','ctsh','clip'),
+          ('l','alt' ,'move'),
+          ('m','alt' ,'none'),
+          ('r','alt' ,'none'),
+          ('w','none','slab'),
+          ('w','shft','movs'),
+          ('w','ctrl','mvsz'),
+          ('w','ctsh','movz'),
+          ('double_left','none','menu'),
+          ('double_left','none','torf'),
+          ('double_middle','none','drgm'),
+          ('double_right','none', 'pktb'),
+          ('single_left','none','pkat'),
+          ('single_middle','none','cent'),
+          ('single_right','none', 'menu'),
+          ('single_left','alt', 'cent'),
+          ],
+        'two_button_viewing' :
+        [ ('l','none','rota'),
+          ('m','none','none'),
+          ('r','none','movz'),
+          ('l','shft','pk1'),
+          ('m','shft','none'),
+          ('r','shft','clip'),                 
+          ('l','ctrl','move'),
+          ('m','ctrl','none'),
+          ('r','ctrl','pkat'),                 
+          ('l','ctsh','sele'),
+          ('m','ctsh','none'),
+          ('r','ctsh','cent'),
+          ('l','alt' ,'move'),
+          ('m','alt' ,'none'),
+          ('r','alt' ,'none'),
+          ('w','none','none'),
+          ('w','shft','none'),
+          ('w','ctrl','none'),
+          ('w','ctsh','none'),
+          ('double_left','none','menu'),
+          ('double_middle','none','none'),                               
+          ('double_right','none','cent'),
+          ('single_left','none','pkat'),
+          ('single_middle','none','none'),
+          ('single_right','none', 'menu'),
+          ('single_left','alt', 'cent'),
+          ],
+        'two_button_selecting' :
+        [ ('l','none','rota'),
+          ('m','none','none'),
+          ('r','none','movz'),
+          ('l','shft','+Box'),
+          ('m','shft','none'),
+          ('r','shft','-Box'),                 
+          ('l','ctrl','+/-'),
+          ('m','ctrl','none'),
+          ('r','ctrl','pkat'),                 
+          ('l','ctsh','sele'),
+          ('m','ctsh','none'),
+          ('r','ctsh','cent'),
+          ('l','alt' ,'move'),
+          ('m','alt' ,'none'),
+          ('r','alt' ,'none'),
+          ('w','none','none'),
+          ('w','shft','none'),
+          ('w','ctrl','none'),
+          ('w','ctsh','none'),
+          ('double_left','none','menu'),
+          ('double_left','none','menu'),
+          ('double_middle','none','none'),                               
+          ('double_right','none','cent'),
+          ('single_left','none','+/-'),
+          ('single_right','none', 'menu'),
+          ('single_left','alt', 'cent'),
+          ],
+        'two_button_editing' :
+        [ ('l','none','rota'),
+          ('m','none','none'),
+          ('r','none','movz'),
+          ('l','shft','pkat'),
+          ('m','shft','none'),
+          ('r','shft','clip'),                 
+          ('l','ctrl','torf'),
+          ('m','ctrl','none'),
+          ('r','ctrl','pktb'),                 
+          ('l','ctsh','rotf'),
+          ('m','ctsh','none'),
+          ('r','ctsh','movf'),
+          ('l','alt' ,'move'),
+          ('m','alt' ,'none'),
+          ('r','alt' ,'none'),
+          ('w','none','none'),
+          ('w','shft','none'),
+          ('w','ctrl','none'),
+          ('w','ctsh','none'),
+          ('double_left','none','menu'),
+          ('double_middle','none','none'),                               
+          ('double_right','none','cent'),
+          ('single_left','none','pkat'),
+          ('single_middle','none','none'),                               
+          ('single_right','none','menu'),                               
+          ('single_left','alt', 'cent'),
+          ],
+         'one_button_viewing' :
+        [ ('l','none','rota'), # approximate the old GLUT behavior on Mac
+          ('m','none','none'),
+          ('r','none','none'),
+          ('l','shft','+Box'),
+          ('m','shft','none'),
+          ('r','shft','none'),
+          ('l','ctrl','movZ'),
+          ('m','ctrl','none'),
+          ('r','ctrl','none'),
+          ('l','ctsh','clip'),
+          ('m','ctsh','none'),
+          ('r','ctsh','none'),
+          ('l','alt' ,'move'),
+          ('m','alt' ,'none'),
+          ('r','alt' ,'none'),
+          ('l','alsh' ,'-Box'),
+          ('m','alsh' ,'none'),
+          ('r','alsh' ,'none'),
+          ('l','ctal' ,'none'),
+          ('m','ctal' ,'none'),
+          ('r','ctal' ,'none'),
+          ('l','ctas' ,'none'),
+          ('m','ctas' ,'none'),
+          ('r','ctas' ,'none'),
+          ('w','none','slab'),
+          ('w','shft','movs'),
+          ('w','ctrl','mvsz'),
+          ('w','ctsh','movz'),
+          ('double_left','none','menu'),
+          ('double_middle','none','none'),
+          ('double_right','none', 'none'),
+          ('single_left','none','+/-'),
+          ('single_middle','none','none'),
+          ('single_right','none', 'none'),
+          ('single_left','shft','none'),
+          ('single_left','ctrl','menu'),
+          ('single_left','ctsh','pkat'), 
+          ('single_left','alt', 'cent'),
+          ('single_left','alsh','none'),
+          ('single_left','ctal','none'),
+          ('single_left','ctas','none'),
+          ],
         }
 
     def order(names,sort=0,location='current',_self=cmd):
@@ -474,17 +548,28 @@ USAGE
             
             mode_list = None
             if action==None:
-                bm = _cmd.get_setting(_self._COb,"button_mode")
-                bm = int(bm) % len(mouse_ring)
-                mode = mouse_ring[bm]
-                _self.set("button_mode_name",mode_name_dict.get(mode,mode))
-                mode_list = mode_dict[mode]
-            elif action in mode_dict.keys():
+                bm = int(_cmd.get_setting(_self._COb,"button_mode"))
+                if bm>=0:
+                    bm = bm % len(mouse_ring)
+                    mode = mouse_ring[bm]
+                    _self.set("button_mode_name",mode_name_dict.get(mode,mode))
+                    mode_list = mode_dict[mode]
+                else:
+                    bm = (-1-bm) % len(mode_name_list)
+                    mode = mode_name_list[bm]
+                    _self.set("button_mode_name",mode_name_dict.get(mode,mode))
+                    mode_list = mode_dict[mode]                    
+            elif action in mouse_ring:
                 mode = action
                 _self.set("button_mode_name",mode_name_dict.get(mode,mode))
-                if mode in mouse_ring:
-                    bm = mouse_ring.index(mode)
-                    _self.set("button_mode",bm)
+                bm = mouse_ring.index(mode)
+                _self.set("button_mode",bm)
+                mode_list = mode_dict[mode]
+            elif mode_dict.has_key(action):
+                mode = action
+                _self.set("button_mode_name",mode_name_dict.get(mode,mode))
+                bm = -1 - mode_name_list.index(action)
+                _self.set("button_mode",bm)
                 mode_list = mode_dict[mode]
             if mode_list!=None:
                 kw_dict = {'_self':_self}
@@ -684,17 +769,17 @@ SEE ALSO
             action = string.lower(action)
             action = but_act_sc.auto_err(action,'action')
             button_num = button_code[button]
-	    but_mod_num = but_mod_code[modifier]
+            but_mod_num = but_mod_code[modifier]
             if button_num<3: # normal button (L,M,R)
-		if but_mod_num < 4: # none, shft, ctrl, ctsh
-		    but_code = button_num + 3*but_mod_num
-		else: # alt, alsh, alct, alcs
-		    but_code = button_num + 68 + 3*(but_mod_num-4)
+                if but_mod_num < 4: # none, shft, ctrl, ctsh
+                    but_code = button_num + 3*but_mod_num
+                else: # alt, alsh, alct, alcs
+                    but_code = button_num + 68 + 3*(but_mod_num-4)
             elif button_num < 4: # wheel
-		if but_mod_num < 4: # none, shft, ctrl, ctsh
-		    but_code = 12 + but_mod_num
-		else:
-		    but_code = 64 + but_mod_num - 4
+                if but_mod_num < 4: # none, shft, ctrl, ctsh
+                    but_code = 12 + but_mod_num
+                else:
+                    but_code = 64 + but_mod_num - 4
             else: # single and double clicks
                 but_code = (16 + button_num - 4) + but_mod_num * 6
             act_code = but_act_code[action]
