@@ -160,7 +160,7 @@ SEE ALSO
     
     def map_new(name, type='gaussian', grid=None, selection="(all)",
                 buffer=None, box=None, state=0, quiet=1, zoom=0,
-                normalize=-1, clamp=[1.0,-1.0], _self=cmd):
+                normalize=-1, clamp=[1.0,-1.0], resolution=0.0, _self=cmd):
 
         '''
 
@@ -235,7 +235,7 @@ NOTES
             r = _cmd.map_new(_self._COb,str(name),int(type),grid,str(selection),
                              float(buffer),box,int(state)-1,
                              int(box_flag),int(quiet),int(zoom),int(normalize),
-                             float(clamp[0]),float(clamp[1]))
+                             float(clamp[0]),float(clamp[1]),float(resolution))
         finally:
             _self.unlock(r,_self)
         if _self._raising(r,_self): raise pymol.CmdException         
@@ -771,7 +771,7 @@ DESCRIPTION
 
 USAGE
 
-    create name, (selection) [,source_state [,target_state ] ]
+    create name, selection [,source_state [,target_state ] ]
 
 ARGUMENTS
 
@@ -805,9 +805,16 @@ SEE ALSO
         try:
             _self.lock(_self)
             if name==None:
-                sel_cnt = _cmd.get(_self._COb,"sel_counter") + 1.0
-                _cmd.legacy_set(_self._COb,"sel_counter","%1.0f" % sel_cnt)
-                name = "obj%02.0f" % sel_cnt
+                avoid = {}
+                for obj in cmd.get_names("all"):
+                    avoid[obj] = 1
+                sel_cnt = _cmd.get(_self._COb,"sel_counter") 
+                while 1:
+                    sel_cnt = sel_cnt + 1.0
+                    name = "obj%02.0f" % sel_cnt
+                    if not avoid.has_key(name):
+                        _cmd.legacy_set(_self._COb,"sel_counter","%1.0f" % sel_cnt)
+                        break
             r = _cmd.create(_self._COb,str(name),"("+str(selection)+")",
                             int(source_state)-1,int(target_state)-1,
                             int(discrete),int(zoom),int(quiet),int(singletons))
@@ -861,7 +868,7 @@ SEE ALSO
             return s[1:-1]
         return s
     
-    def pseudoatom(object, selection='', name='PS1', resn='PSD', resi='1', chain='P',
+    def pseudoatom(object='', selection='', name='PS1', resn='PSD', resi='1', chain='P',
                    segi='PSDO', elem='PS', vdw=-1.0, hetatm=1, b=0.0, q=0.0, color='',
                    label='', pos=None, state=0, mode='rms', quiet=1,_self=cmd):
         '''
@@ -890,6 +897,9 @@ NOTES
             color = _self.get_color_index(str(color))
         else:
             color = -1 # default
+        object = str(object)
+        if not len(object):
+            object = _self.get_unused_name(prefix="pseudo")
         selection = selector.process(selection)
         mode = pseudoatom_mode_dict[pseudoatom_mode_sc.auto_err(str(mode),'pseudoatom mode')]
         
