@@ -22,7 +22,34 @@ if __name__=='pymol.editing':
           boolean_sc,boolean_dict,safe_list_eval, is_sequence, \
           DEFAULT_ERROR, DEFAULT_SUCCESS, _raising, is_ok, is_error              
     from chempy import cpv
+    
+    ref_action_dict = {
+        'store'     : 1,
+        'recall'    : 2,
+        'validate'  : 3,
+        'swap'      : 4,
+    }
 
+    ref_action_sc = Shortcut(ref_action_dict.keys())
+    
+    def reference(action='validate', selection='(all)',
+                  state=0, quiet=1, _self=cmd):
+        r = DEFAULT_ERROR
+        if is_string(action):
+            action = ref_action_sc.auto_err(action,"action")
+            action = ref_action_dict[action]
+        else:
+            action = int(action)
+        selection = selector.process(selection)           
+        try:
+            _self.lock(_self)
+            r = _cmd.reference( _self._COb, int(action), str(selection),
+                               int(state)-1, int(quiet))
+        finally:
+            _self.unlock(r,_self)
+        if _self._raising(r,_self): raise pymol.CmdException            
+        return r
+    
     def sculpt_purge(_self=cmd):
         '''
 DESCRIPTION
@@ -97,6 +124,9 @@ EXAMPLE
         object = str(object)
         if prefix==None:
             prefix = object+"_"
+            prefix_set = 0
+        else:
+            prefix_set = 1
         first=int(first)
         last=int(last)
         n_state = _self.count_states(object)
@@ -108,7 +138,7 @@ EXAMPLE
             for a in range(first,last+1):
                 try:
                     name = _self.get_title(object,a)
-                    if len(name)==0:
+                    if (len(name)==0) or prefix_set:
                         name = prefix+"%04d"%a
                 except:
                     name = prefix+"%04d"%a
@@ -490,7 +520,7 @@ PYMOL API
             r = _cmd.invert(_self._COb,int(quiet))
         finally:
             _self.unlock(r,_self)
-        if _self._raising(r,_self): raise pymol.CmdException            
+        if _self._raising(r,_self): raise pymol.QuietException            
         return r
 
     def unbond(atom1="(pk1)", atom2="(pk2)", quiet=1, _self=cmd):
@@ -677,7 +707,8 @@ PYMOL API
         return r
 
 
-    def fuse(selection1="(pk1)", selection2="(pk2)", mode=0, recolor=1, move=1, _self=cmd):
+    def fuse(selection1="(pk1)", selection2="(pk2)", 
+             mode=0, recolor=1, move=1, _self=cmd):
         '''
 DESCRIPTION
 
@@ -748,7 +779,7 @@ SEE ALSO
         if _self._raising(r,_self): raise pymol.CmdException            
         return r
 
-    def drag(selection=None, wizard=1, edit=1, quiet=1,_self=cmd):
+    def drag(selection=None, wizard=1, edit=1, quiet=1, mode=-1, _self=cmd):
         '''
 DESCRIPTION
 
@@ -789,7 +820,7 @@ NOTES
         r = DEFAULT_ERROR
         try:
             _self.lock(_self)   
-            r = _cmd.drag(_self._COb,str(selection),int(quiet))
+            r = _cmd.drag(_self._COb,str(selection),int(quiet),int(mode))
         finally:
             _self.unlock(r,_self)
         if not is_error(r):
@@ -1056,7 +1087,7 @@ SEE ALSO
         if _self._raising(r,_self): raise pymol.CmdException            
         return r
 
-    def rename(selection, force=0, _self=cmd):
+    def rename(selection="all", force=0, quiet=1, _self=cmd):
         '''
 DESCRIPTION
 
@@ -1075,9 +1106,10 @@ SEE ALSO
     alter
     '''
         r = DEFAULT_ERROR   
+        selection = "("+selector.process(selection)+")"
         try:
             _self.lock(_self)   
-            r = _cmd.rename(_self._COb,str(selection),int(force))
+            r = _cmd.rename(_self._COb,str(selection),int(force),int(quiet))
         finally:
             _self.unlock(r,_self)
         if _self._raising(r,_self): raise pymol.CmdException            
@@ -1760,10 +1792,11 @@ DESCRIPTION
         if _self._raising(r,_self): raise pymol.CmdException            
         return r
 
-    def matrix_copy(source_name, target_name,
+    def matrix_copy(source_name='', target_name='',
                     source_mode=-1, target_mode=-1,
                     source_state=1, target_state=1,
-                    target_undo=1, log=0, quiet=1,_self=cmd):
+                    target_undo=1, log=0, quiet=1,
+                    _self=cmd):
         '''
 
 DESCRIPTION
@@ -1786,20 +1819,47 @@ SEE ALSO
 '''
         
         r = DEFAULT_ERROR
-        try:
-            _self.lock(_self)
-            r = _cmd.matrix_copy(_self._COb,str(source_name),
-                                             str(target_name),
-                                             int(source_mode),
-                                             int(target_mode),
-                                             int(source_state)-1,
-                                             int(target_state)-1,
-                                             int(target_undo),
-                                             int(log),
-                                             int(quiet))
-        finally:
-            _self.unlock(r,_self)
-        if _self._raising(r,_self): raise pymol.CmdException            
+        if source_name == None:
+            source_name = ''
+        target_name = str(target_name).strip()
+        source_name = str(source_name).strip()
+        if (target_name == '' and source_name != ''): # tentative -- create a new command instead?
+            mat = cmd.get_object_matrix(source_name,source_state)
+            view = cmd.get_view()
+            new_view = (
+                mat[ 0]*view[ 0] + mat[ 4]*view[ 3] + mat[ 8]*view[ 6],
+                mat[ 0]*view[ 1] + mat[ 4]*view[ 4] + mat[ 8]*view[ 7],  
+                mat[ 0]*view[ 2] + mat[ 4]*view[ 5] + mat[ 8]*view[ 8],
+                mat[ 1]*view[ 0] + mat[ 5]*view[ 3] + mat[ 9]*view[ 6],
+                mat[ 1]*view[ 1] + mat[ 5]*view[ 4] + mat[ 9]*view[ 7],  
+                mat[ 1]*view[ 2] + mat[ 5]*view[ 5] + mat[ 9]*view[ 8],
+                mat[ 2]*view[ 0] + mat[ 6]*view[ 3] + mat[10]*view[ 6],
+                mat[ 2]*view[ 1] + mat[ 6]*view[ 4] + mat[10]*view[ 7],  
+                mat[ 2]*view[ 2] + mat[ 6]*view[ 5] + mat[10]*view[ 8],
+                view[ 9] ,         view[10] ,         view[11],
+                mat[ 0]*view[12] + mat[ 1]*view[13] + mat[ 2]*view[14] -
+                mat[ 0]* mat[ 3] - mat[ 4]* mat[ 7] - mat[ 8]* mat[11], 
+                mat[ 4]*view[12] + mat[ 5]*view[13] + mat[ 6]*view[14] -
+                mat[ 1]* mat[ 3] - mat[ 5]* mat[ 7] - mat[ 9]* mat[11],
+                mat[ 8]*view[12] + mat[ 9]*view[13] + mat[10]*view[14] -
+                mat[ 2]* mat[ 3] - mat[ 6]* mat[ 7] - mat[10]* mat[11],
+                view[15] ,         view[16] ,         view[17] )
+            r = cmd.set_view(new_view)
+        else:
+            try:
+                _self.lock(_self)
+                r = _cmd.matrix_copy(_self._COb,str(source_name),
+                                                 str(target_name),
+                                                 int(source_mode),
+                                                 int(target_mode),
+                                                 int(source_state)-1,
+                                                 int(target_state)-1,
+                                                 int(target_undo),
+                                                 int(log),
+                                                 int(quiet))
+            finally:
+                _self.unlock(r,_self)
+            if _self._raising(r,_self): raise pymol.CmdException            
         return r
 
     def matrix_reset(name, state=1, mode=-1, log=0, quiet=1,_self=cmd):
