@@ -27,7 +27,7 @@ if __name__=='pymol.exporting':
     from chempy.sdf import SDF,SDFRec
     from cmd import _feedback,fb_module,fb_mask, \
                      DEFAULT_ERROR, DEFAULT_SUCCESS, _raising, is_ok, is_error, \
-                     is_list, is_dict, is_tuple
+                     is_list, is_dict, is_tuple, loadable
     import traceback
 
     def copy_image(quiet=1,_self=cmd): # incentive feature / proprietary
@@ -144,7 +144,53 @@ PYMOL API
         if _self._raising(r,_self): raise QuietException         
         return r
 
-    def get_pdbstr(selection="all", state=-1, ref='', ref_state=-1, quiet=1,_self=cmd):
+    _resn_to_aa =  {
+            'ALA' : 'A',
+            'CYS' : 'C',
+            'ASP' : 'D',
+            'GLU' : 'E',
+            'PHE' : 'F',
+            'GLY' : 'G',
+            'HIS' : 'H',
+            'ILE' : 'I',
+            'LYS' : 'K',
+            'LEU' : 'L',
+            'MET' : 'M',
+            'ASN' : 'N',
+            'PRO' : 'P',
+            'GLN' : 'Q',
+            'ARG' : 'R',
+            'SER' : 'S',
+            'THR' : 'T',
+            'VAL' : 'V',
+            'TRP' : 'W',
+            'TYR' : 'Y',
+            }
+    
+    def get_fastastr(selection="all", state=-1, quiet=1, _self=cmd):
+        dict = { 'seq' : {} }
+        _self.iterate("("+selection+") and polymer and name ca",
+                    "seq[model]=seq.get(model,[]);seq[model].append(resn)",space=dict)
+        seq = dict['seq']
+        result = []
+        for obj in _self.get_names("objects",selection='('+selection+')'):
+            if seq.has_key(obj):
+                seq = map(lambda x:_resn_to_aa.get(x,'?'),seq[obj])
+                result.append(">%s"%obj)
+                seq = string.join(seq,'')
+                while len(seq):
+                    if len(seq)>=70:
+                        result.append(seq[0:70])
+                        seq=seq[70:]
+                    else:
+                        result.append(seq)
+                        break
+        result = string.join(result,'\n')
+        if len(result):
+            result = result + '\n'
+        return result
+
+    def get_pdbstr(selection="all", state=-1, ref='', ref_state=-1, quiet=1, _self=cmd):
         '''
 DESCRIPTION
 
@@ -168,7 +214,8 @@ NOTES
         r = DEFAULT_ERROR
         try:
             _self.lock(_self)   
-            r = _cmd.get_pdb(_self._COb,str(selection),int(state)-1,0,str(ref),int(ref_state),int(quiet))
+            r = _cmd.get_pdb(_self._COb,str(selection),int(state)-1,0,
+                             str(ref),int(ref_state),int(quiet))
         finally:
             _self.unlock(r,_self)
         if _self._raising(r,_self): raise QuietException         
@@ -235,7 +282,8 @@ NOTES
         return r
         
 
-    def png(filename, width=0, height=0, dpi=-1.0, ray=0, quiet=1, _self=cmd):
+    def png(filename, width=0, height=0, dpi=-1.0, ray=0,
+            quiet=1, prior=0, format=0, _self=cmd):
         '''
 DESCRIPTION
 
@@ -272,14 +320,26 @@ SEE ALSO
     
 PYMOL API
 
-    cmd.png(string filename, int width, int width, float dpi,
+    cmd.png(string filename, int width, int height, float dpi,
             int ray, int quiet)
         '''
         r = DEFAULT_ERROR
-        if thread.get_ident() == pymol.glutThread:
-            r = _self._png(str(filename),int(width),int(height),float(dpi),int(ray),int(quiet),_self)
-        else:
-            r = _self._do("cmd._png('%s',%d,%d,%1.6f,%d,%d)"%(filename,width,height,dpi,ray,quiet),_self=_self)
+        prior = int(prior)
+        if prior: 
+            # fetch the prior image, without doing any work (fast-path / non-GLUT thread-safe)
+            r = _self._png(str(filename),0,0,float(dpi),0,int(quiet),1,
+                           int(format),_self)            
+            if r != 1: # no prior image available -- revert to default behavior
+                if prior < 0: # default is to fall back to actual rendering
+                    prior = 0
+        if not prior:
+            if thread.get_ident() == pymol.glutThread:
+                r = _self._png(str(filename),int(width),int(height),float(dpi),
+                               int(ray),int(quiet),0,int(format),_self)
+            else:
+                r = _self._do("cmd._png('''%s''',%d,%d,%1.6f,%d,%d,%d,%d)"%
+                              (filename,width,height,dpi,
+                               ray,int(quiet),0,int(format)),_self=_self)
         if _self._raising(r,_self): raise QuietException
         return r
 
@@ -293,20 +353,34 @@ PYMOL API
         if _self._raising(r,_self): raise QuietException
         return r
 
-    def multisave(filename, object, state=0, _self=cmd): # experimental -- deprecated
+    def multisave(filename, pattern="all", state=-1,
+                  append=0, format='', quiet=1, _self=cmd): 
         '''
 DESCRIPTION
 
-    "multisave" is an unsupported command that may have something to
-    do with writing multistate coordinate data to fragile version &
-    platform-specific binary (pmo) file.
+    "multisave" is an unsupported command.
     
     '''
-        
         r = DEFAULT_ERROR
+        filename = _self.exp_path(filename)        
+        lc_filename=string.lower(filename)
+        if format=='':
+            # refactor following if/elif cascade 
+            # with a dictionary lookup
+            if re.search("\.pdb$|\.ent$",lc_filename):
+                format = 'pdb'
+            elif re.search("\.pmo$",lc_filename):
+                format = 'pmo'
+        if format == 'pdb':
+            ftype = loadable.pdb
+        elif format == 'pmo':
+            ftype = loadable.pmo
+        else:
+            ftype = loadable.pdb # default
         try:
             _self.lock(_self)
-            r = _cmd.multisave(_self._COb,str(filename),str(object),int(state)-1,0)
+            r = _cmd.multisave(_self._COb, str(filename), str(pattern),
+                               int(state)-1, int(append), int(ftype),int(quiet))
         finally:
             _self.unlock(r,_self)
         if _self._raising(r,_self): raise QuietException
@@ -362,6 +436,8 @@ SEE ALSO
         lc_filename=string.lower(filename)
         if format=='':
             format = 'unknown'
+            # refactor following if/elif cascade 
+            # with a dictionary lookup
             if re.search("\.pdb$|\.ent$",lc_filename):
                 format = 'pdb'
             elif re.search("\.pqr$",lc_filename):
@@ -376,6 +452,10 @@ SEE ALSO
                 format = 'pkla'
             elif re.search("\.mmd$",lc_filename):
                 format = 'mmod'
+            elif re.search("\.out$",lc_filename):
+                format = 'mmod'
+            elif re.search("\.dat$",lc_filename):
+                format = 'mmod'
             elif re.search("\.mmod$",lc_filename):
                 format = 'mmod'
             elif re.search("\.pmo$",lc_filename):
@@ -388,12 +468,16 @@ SEE ALSO
                 format = 'pse'
             elif re.search("\.aln$",lc_filename):
                 format = 'aln'
+            elif re.search("\.fasta$",lc_filename):
+                format = 'fasta'
             elif re.search("\.obj$",lc_filename):
                 format = 'obj'
             elif re.search("\.mtl$",lc_filename):
                 format = 'mtl'
             elif re.search("\.wrl$",lc_filename):
                 format = 'wrl'
+            elif re.search("\.idtf$",lc_filename):
+                format = 'idtf'
             else:
                 format = str(format)
         if format=='unknown':
@@ -434,6 +518,17 @@ SEE ALSO
                     print " Save: wrote \""+filename+"\"."
             else:
                 r = DEFAULT_ERROR
+        elif format=='fasta':
+            st = _self.get_fastastr(selection)
+            if st != None:
+                r = DEFAULT_SUCCESS
+                f=open(filename,"w")
+                f.write(st)
+                f.close()
+                if not quiet:
+                    print " Save: wrote \""+filename+"\"."
+            else:
+                r = DEFAULT_ERROR
         elif format=='pqr': # PQR (modified PDB file)
             f=open(filename,"w")
             if f:
@@ -464,6 +559,8 @@ SEE ALSO
             _self.set("session_file",filename,quiet=1)
             if '(' in input_selection: # ignore selections 
                 input_selection=''
+            if not quiet:
+                print " Save: Please wait -- writing session file..."
             io.pkl.toFile(_self.get_session(str(input_selection),int(partial),int(quiet)),filename)
             r = DEFAULT_SUCCESS
             if not quiet:
@@ -496,6 +593,7 @@ SEE ALSO
                 print " Save: wrote \""+filename+"\"."
         elif format=='png':
             r = _self.png(filename,quiet=quiet)
+        # refactor below to lift repeated code
         elif format=='pov':
             tup = _self.get_povray()
             f=open(filename,"w")
@@ -529,6 +627,20 @@ SEE ALSO
             if not quiet:
                 print " Save: wrote \""+filename+"\"."
             r = DEFAULT_SUCCESS
+        elif format=='idtf':
+            tup = _self.get_idtf()
+            f=open(filename,"w")
+            f.write(tup[0]);
+            f.write(tup[1]);
+            f.flush()
+            f.close()
+            if not quiet:
+                fov = float(cmd.get("field_of_view"))
+                dist = cmd.get_view()[11]
+                print " 3Daac=%3.1f, 3Droll=0, 3Dc2c=0 0 1, 3Droo=%1.2f, 3Dcoo=0 0 %1.2f"%(fov,-dist,dist)
+                print " Save: wrote \""+filename+"\"."
+            r = DEFAULT_SUCCESS
+            
         if _self._raising(r,_self): raise QuietException
         return r
 
