@@ -25,7 +25,7 @@ if __name__=='pymol.fitting':
           DEFAULT_ERROR, DEFAULT_SUCCESS, _raising, is_ok, is_error
 
     def super(mobile, target, cutoff=2.0, cycles=5,
-              gap=-1.5, extend=-0.7, max_gap=50, object=None,                            
+              gap=-1.5, extend=-0.7, max_gap=50, object=None,
               matrix="BLOSUM62", mobile_state=0, target_state=0, 
               quiet=1, max_skip=0, transform=1, reset=0,
               seq=0.0, radius=12.0, scale=17.0, base=0.65,
@@ -126,7 +126,7 @@ EXAMPLE
 
 SEE ALSO
 
-    super, pair_fit, fit, rms, rms_cur, intra_rms, intra_rms_cur, super
+    super, pair_fit, fit, rms, rms_cur, intra_rms, intra_rms_cur
         '''
         r = DEFAULT_ERROR
         mobile = selector.process(mobile)
@@ -336,7 +336,7 @@ SEE ALSO
         b = selector.process(b)
         #
         if object==None: object=''
-        if matchmaker==0:
+        if int(matchmaker)==0:
             sele1 = "((%s) in (%s))" % (str(a),str(b))
             sele2 = "((%s) in (%s))" % (str(b),str(a))
         else:
@@ -381,7 +381,7 @@ SEE ALSO
         b = selector.process(b)
         #
         if object==None: object=''      
-        if matchmaker==0:
+        if int(matchmaker)==0:
             sele1 = "((%s) in (%s))" % (str(a),str(b))
             sele2 = "((%s) in (%s))" % (str(b),str(a))
         else:
@@ -424,7 +424,7 @@ SEE ALSO
         b = selector.process(b)
         #
         if object==None: object=''            
-        if matchmaker==0:
+        if int(matchmaker)==0:
             sele1 = "((%s) in (%s))" % (str(a),str(b))
             sele2 = "((%s) in (%s))" % (str(b),str(a))
         else:
