@@ -20,7 +20,7 @@ if __name__=='pymol.importing':
     import cmd
     from cmd import _cmd,lock,unlock,Shortcut, \
           _feedback,fb_module,fb_mask, \
-          file_ext_re,safe_oname_re, \
+          file_ext_re,gz_ext_re,safe_oname_re, \
           DEFAULT_ERROR, DEFAULT_SUCCESS, _raising, is_ok, is_error, \
           _load, is_list, space_sc, safe_list_eval, is_string, loadable
     import setting
@@ -136,7 +136,7 @@ PYMOL API
         lst.extend(list(arg))
         return apply(_self.load_object,lst,kw)
 
-    def space(space="", quiet=0, _self=cmd):
+    def space(space="", gamma=1.0, quiet=0, _self=cmd):
         '''
 DESCRIPTION
 
@@ -144,12 +144,14 @@ DESCRIPTION
     
 USAGE
 
-    space space
+    space space [, gamma]
 
 ARGUMENTS
 
     space = rgb, cmyk, or pymol: {default: rgb}
 
+    gamma = floating point gamma transformation
+    
 EXAMPLES
 
     space rgb
@@ -180,7 +182,7 @@ NOTES
 
 PYMOL API
 
-    cmd.space(string space)
+    cmd.space(string space, float gamma)
     
 SEE ALSO
 
@@ -189,11 +191,10 @@ SEE ALSO
     '''
         r = DEFAULT_ERROR
         
-        
         tables = { 'cmyk' : "$PYMOL_PATH/data/pymol/cmyk.png",
-                      'pymol' : 'pymol',
-                      'rgb' : 'rgb' }
-
+                   'pymol' : 'pymol',
+                   'rgb' : 'rgb' }
+        
         space_auto = space_sc.interpret(space)
         if (space_auto != None) and not is_list(space_auto):
             space = space_auto
@@ -207,9 +208,10 @@ SEE ALSO
                 filename = None
         if filename!=None:
             try:
-                filename = _self.exp_path(filename)
+                if filename!="":
+                    filename = _self.exp_path(filename)
                 _self.lock(_self)
-                r = _cmd.load_color_table(_self._COb,str(filename),int(quiet))
+                r = _cmd.load_color_table(_self._COb,str(filename),float(gamma),int(quiet))
             finally:
                 _self.unlock(r,_self)
         if _self._raising(r,_self): raise pymol.CmdException
@@ -347,6 +349,9 @@ SEE ALSO
                 elif re.search("\.trr$",filename,re.I):
                     ftype = loadable.trr
                     if plugin=="": plugin = "trr"
+                elif re.search("\.dtr$",filename,re.I):
+                    ftype = loadable.dtr
+                    if plugin=="": plugin = "dtr"
                 elif re.search("\.gro$",filename,re.I):
                     ftype = loadable.gro
                     if plugin=="": plugin = "gro"
@@ -374,6 +379,7 @@ SEE ALSO
     # get object name
             if len(str(object))==0:
                 oname = re.sub(r".*\/|.*\\","",filename) # strip path
+                oname = gz_ext_re.sub("",oname) # strip gz
                 oname = file_ext_re.sub("",oname) # strip extension
                 oname = safe_oname_re.sub("_",oname)
                 if not len(oname): # safety
@@ -398,8 +404,8 @@ SEE ALSO
             rec = cif.read()
             if not rec: break
             if len(rec.model.atom):
-                r = cmd.load_model(rec.model,oname,state,quiet=quiet,
-                                   _self=_self,discrete=discrete)
+                r = _self.load_model(rec.model,oname,state,quiet=quiet,
+                                     discrete=discrete)
         del cif
 #        _cmd.finish_object(_self._COb,str(oname))
 #        if _cmd.get_setting(_self._COb,"auto_zoom")==1.0:
@@ -417,10 +423,143 @@ SEE ALSO
         _cmd.finish_object(_self._COb,str(oname))
         if _cmd.get_setting(_self._COb,"auto_zoom")==1.0:
             _self._do("zoom (%s)"%oname)
+
+    def _processALN(fname,quiet=1,_self=cmd):
+        legal_dict = {}
+        seq_dict = {}
+        seq_order = []
+        header_seen = 0
+        for line in open(fname).readlines():
+            if not header_seen:
+                if line[0:7]=='CLUSTAL':
+                    header_seen = 1
+            else:
+                key = line[0:16].strip()
+                if key!='':
+                    legal_key = _self.get_legal_name(key)
+                    if not legal_dict.has_key(key):
+                        seq_order.append(legal_key)
+                    legal_dict[key] = legal_key
+                    key = legal_key
+                    seq = line[16:].strip()
+                    if seq != '':
+                        seq_dict[key] = seq_dict.get(key,'') + seq
+        for key in seq_order:
+            raw_seq = seq_dict[key].replace('-','')
+            _self.fab(raw_seq, key, quiet=quiet)
+
+    def _processFASTA(fname,quiet=1,_self=cmd):
+        legal_dict = {}
+        seq_dict = {}
+        seq_order = []
+        for line in open(fname).readlines():
+            line = line.strip()
+            if len(line):
+                if line[0:1] == '>':
+                    key = line[1:].strip()
+                    legal_key = _self.get_legal_name(key)
+                    if not legal_dict.has_key(key):
+                        seq_order.append(legal_key)
+                    legal_dict[key] = legal_key
+                    key = legal_key
+                elif key:
+                    seq = line
+                    seq_dict[key] = seq_dict.get(key,'') + seq
+        for key in seq_order:
+            raw_seq = seq_dict[key].replace('-','')
+            _self.fab(raw_seq, key, quiet=quiet)
+        
+    def _processPWG(fname,_self=cmd):
+        r = DEFAULT_ERROR
+        try:
+            from consortia.web.pymolhttpd import PymolHttpd
+            browser_flag = 0
+            launch_flag = 0
+            report_url = None
+            logging = 1
+            root = None
+            port = 0
+            if (string.find(fname,":")>1):
+                import urllib
+                lines = urllib.urlopen(fname).readlines()
+            else:
+                lines = open(fname).readlines()
+            for line in lines:
+                line = line.strip()
+                if len(line) and line[0:1] != '#':
+                    input = line.split(None,1)
+                    if len(input) and input[0]!='#':
+                        keyword = input[0].lower()
+                        if keyword == 'port': # will be assigned dynamically if not specified
+                            if len(input)>1:
+                                port = int(input[1].strip())
+                                launch_flag = 1
+                        elif keyword == 'logging': 
+                            if len(input)>1:
+                                logging = int(input[1].strip())
+                        elif keyword == 'root': # must encode a valid filesystem path to local content
+                            if len(input)>1:
+                                root = input[1].strip()
+                                root = _self.exp_path(root) # allow for env var substitution
+                                if os.path.exists(root):
+                                    launch_flag = 1
+                                else:
+                                    print "Error: requested path '%s' does not exist."%root
+                            else:
+                                print "Error: missing path to root content"
+                        elif keyword == 'browser':
+                            # could perhaps interpret a browser name here
+                            browser_flag = 1
+                        elif keyword == 'launch': # launch the module named in the file (must exist!)
+                            if len(input)>1:
+                                mod_name = input[1]
+                                try:
+                                    __builtin__.__import__(mod_name)
+                                    mod = sys.modules[mod_name]
+                                    if hasattr(mod,'__launch__'):
+                                        mod.__launch__(_self)
+                                        r = DEFAULT_SUCCESS
+                                except:
+                                    traceback.print_exc()
+                                    print "Error: unable to launch web application'%s'."%mode_name
+                        elif keyword == 'report':
+                            if len(input)>1:
+                                report_url = input[1]
+                        elif keyword == 'delete':
+                            os.unlink(fname)
+                        elif keyword == 'options':
+                            os.unlink(fname)
+                        else:
+                            print "Error: unrecognized input:  %s"%str(input)
+            if launch_flag:
+                server = PymolHttpd(port,root,logging)
+                if port == 0:
+                    port = server.port # get the dynamically assigned port number
+                server.start()
+                if browser_flag: # fire up a local browser
+                    import webbrowser
+                    webbrowser.open("http://localhost:%d"%port,new=1)
+                    r = DEFAULT_SUCCESS
+                else:
+                    r = DEFAULT_SUCCESS
+                if report_url != None: # report port back to server url (is this secure?)
+                    import urllib
+                    try:
+                        report_url = report_url + str(port)
+                        print " Reporting back pymol port via: '%s'"%report_url
+                        urllib.urlretrieve(report_url)
+                    except:
+                        print " Report attempt may have failed."
+        except ImportError:
+            traceback.print_exc()
+
+        if is_error(r):
+            print "Error: unable to handle PWG file"
+        return r
     
     def load(filename, object='', state=0, format='', finish=1,
              discrete=-1, quiet=1, multiplex=None, zoom=-1, partial=0,
-             _self=cmd):
+             mimic=1,_self=cmd):
         '''
 DESCRIPTION
 
@@ -500,84 +639,96 @@ SEE ALSO
                 multiplex=-2
             fname = _self.exp_path(filename)
             go_to_first_scene = 0
-            
             if not len(str(type)):
+                fname_no_gz = gz_ext_re.sub("",filename) # strip gz
                 # determine file type if possible
-                if re.search("\.pdb$|\.pdb1$|\.ent$|\.p5m",filename,re.I):
+                if re.search("\.pdb$|\.pdb1$|\.ent$|\.p5m",fname_no_gz,re.I):
                     ftype = loadable.pdb
-                elif re.search("\.mol$",filename,re.I):
+                elif re.search("\.mol$",fname_no_gz,re.I):
                     ftype = loadable.mol
-                elif re.search("\.mmod$|\.mmd$|\.dat$|\.out$",filename,re.I):
+                elif re.search("\.mmod$|\.mmd$|\.dat$|\.out$",fname_no_gz,re.I):
                     ftype = loadable.mmod
-                elif re.search("\.xplor$",filename,re.I):
+                elif re.search("\.xplor$",fname_no_gz,re.I):
                     ftype = loadable.xplor
-                elif re.search("\.ccp4$",filename,re.I):
+                elif re.search("\.ccp4$",fname_no_gz,re.I):
                     ftype = loadable.ccp4
-                elif re.search("\.pkl$",filename,re.I):
+                elif re.search("\.pkl$",fname_no_gz,re.I):
                     ftype = loadable.model
-                elif re.search("\.r3d$",filename,re.I):
+                elif re.search("\.r3d$",fname_no_gz,re.I):
                     ftype = loadable.r3d
-                elif re.search("\.xyz$",filename,re.I):
+                elif re.search("\.xyz$",fname_no_gz,re.I):
                     ftype = loadable.xyz
-                elif re.search("\.cc1$|\.cc2$",filename,re.I):
+                elif re.search("\.cc1$|\.cc2$",fname_no_gz,re.I):
                     ftype = loadable.cc1
-                elif re.search("\.xyz_[0-9]*$",filename,re.I):
+                elif re.search("\.xyz_[0-9]*$",fname_no_gz,re.I):
                     ftype = loadable.xyz
-                elif re.search("\.sdf$|\.sd$",filename,re.I): 
+                elif re.search("\.sdf$|\.sd$",fname_no_gz,re.I): 
                     ftype = loadable.sdf2 # now using the C-based SDF reader by default...
-                elif re.search("\.cex$",filename,re.I):
+                elif re.search("\.cex$",fname_no_gz,re.I):
                     ftype = loadable.cex
-                elif re.search("\.pmo$",filename,re.I):
+                elif re.search("\.pmo$",fname_no_gz,re.I):
                     ftype = loadable.pmo
-                elif re.search("\.top$",filename,re.I):
+                elif re.search("\.top$",fname_no_gz,re.I):
                     ftype = loadable.top
-                elif re.search("\.trj$",filename,re.I):
+                elif re.search("\.trj$",fname_no_gz,re.I):
                     ftype = loadable.trj
-                elif re.search("\.trr$",filename,re.I):
+                elif re.search("\.trr$",fname_no_gz,re.I):
                     ftype = loadable.trr
-                elif re.search("\.xtc$",filename,re.I):
+                elif re.search("\.dtr$",fname_no_gz,re.I):
+                    ftype = loadable.dtr
+                elif re.search("\.xtc$",fname_no_gz,re.I):
                     ftype = loadable.xtc
-                elif re.search("\.gro$",filename,re.I):
+                elif re.search("\.gro$",fname_no_gz,re.I):
                     ftype = loadable.gro
-                elif re.search("\.g96$",filename,re.I):
+                elif re.search("\.g96$",fname_no_gz,re.I):
                     ftype = loadable.g96
-                elif re.search("\.dcd$",filename,re.I):
+                elif re.search("\.dcd$",fname_no_gz,re.I):
                     ftype = loadable.dcd
-                elif re.search("\.crd$",filename,re.I):
+                elif re.search("\.crd$",fname_no_gz,re.I):
                     ftype = loadable.crd
-                elif re.search("\.rst$",filename,re.I):
+                elif re.search("\.rst$",fname_no_gz,re.I):
                     ftype = loadable.crd
-                elif re.search("\.pse$",filename,re.I):
+                elif re.search("\.pse$",fname_no_gz,re.I):
                     ftype = loadable.pse
-                elif re.search("\.psw$",filename,re.I):
+                elif re.search("\.psw$",fname_no_gz,re.I):
                     ftype = loadable.psw
-                elif re.search("\.phi$",filename,re.I):
+                elif re.search("\.phi$",fname_no_gz,re.I):
                     ftype = loadable.phi
-                elif re.search("\.mol2$",filename,re.I):
+                elif re.search("\.mol2$",fname_no_gz,re.I):
                     ftype = loadable.mol2
-                elif re.search("\.dx$",filename,re.I):
+                elif re.search("\.dx$",fname_no_gz,re.I):
                     ftype = loadable.dx
-                elif re.search("\.fld$",filename,re.I):
+                elif re.search("\.fld$",fname_no_gz,re.I):
                     ftype = loadable.fld
-                elif re.search("\.pqr$",filename,re.I):
+                elif re.search("\.pqr$",fname_no_gz,re.I):
                     ftype = loadable.pqr
-                elif re.search("\.o$|\.dsn6$|\.brix$|\.omap$",filename,re.I):
+                elif re.search("\.o$|\.dsn6$|\.brix$|\.omap$",fname_no_gz,re.I):
                     ftype = loadable.brix
-                elif re.search("\.grd$",filename,re.I):
+                elif re.search("\.grd$",fname_no_gz,re.I):
                     ftype = loadable.grd
-                elif re.search("\.p1m$",filename,re.I):
+                elif re.search("\.acnt$",fname_no_gz,re.I):
+                    ftype = loadable.acnt
+                elif re.search("\.p1m$",fname_no_gz,re.I):
                     ftype = loadable.p1m
-                elif re.search("\.png$",filename,re.I):
+                elif re.search("\.png$",fname_no_gz,re.I):
                     ftype = loadable.png
-                elif re.search("\.moe$",filename,re.I):
+                elif re.search("\.moe$",fname_no_gz,re.I):
                     ftype = loadable.moe
-                elif re.search("\.mae$",filename,re.I):
+                elif re.search("\.mae$",fname_no_gz,re.I):
                     ftype = loadable.mae
-                elif re.search("\.cube$",filename,re.I):
+                elif re.search("\.cube$",fname_no_gz,re.I):
                     ftype = loadable.cube
-                elif re.search("\.cif$",filename,re.I):
+                elif re.search("\.cif$",fname_no_gz,re.I):
                     ftype = loadable.cif1
-                elif re.search("\.map$",filename,re.I):
+                elif re.search("\.pim$",fname_no_gz,re.I):
+                    ftype = loadable.pim
+                elif re.search("\.pwg$",fname_no_gz,re.I):
+                    ftype = loadable.pwg
+                elif re.search("\.aln$",fname_no_gz,re.I):
+                    ftype = loadable.aln
+                elif re.search("\.fasta$",fname_no_gz,re.I):
+                    ftype = loadable.fasta
+                elif re.search("\.map$",fname_no_gz,re.I):
                     r = DEFAULT_ERROR
                     print 'Error: .map is ambiguous.  Please add format or use another extension:'
                     print 'Error: For example, "load fofc.map, format=ccp4" or "load 2fofc.xplor".'
@@ -615,6 +766,7 @@ SEE ALSO
     # get object name
             if len(str(object))==0:
                 oname = re.sub(r".*\/|.*\\","",filename) # strip path
+                oname = gz_ext_re.sub("",oname) # strip gz                
                 oname = file_ext_re.sub("",oname) # strip extension
                 oname = safe_oname_re.sub("_",oname)
                 if not len(oname): # safety
@@ -644,13 +796,38 @@ SEE ALSO
                 r = _self.load_png(str(fname),quiet=quiet)
                 ftype = -1
 
-    # p1m embedded data script files
+    # p1m embedded data script files (more secure)
     
             if ftype == loadable.p1m:
                 _self._do("_ @"+fname)
                 ftype = -1
                 r = DEFAULT_SUCCESS
-                
+
+    # pim import files (unrestricted scripting -- insecure)
+    
+            if ftype == loadable.pim:
+                _self._do("_ @"+fname)
+                ftype = -1
+                r = DEFAULT_SUCCESS
+
+    # pwg launch (PyMOL Web GUI / http server launch)
+    
+            if ftype == loadable.pwg:
+                ftype = -1
+                r = _processPWG(fname)
+
+    # aln CLUSTAL
+    
+            if ftype == loadable.aln:
+                ftype = -1
+                r = _processALN(fname,quiet=quiet)
+
+    # fasta
+    
+            if ftype == loadable.fasta:
+                ftype = -1
+                r = _processFASTA(fname,quiet=quiet)
+
     # special handling for trj failes (autodetect AMBER versus GROMACS)
             if ftype == loadable.trj:
                 try: # autodetect gromacs TRJ
@@ -687,12 +864,14 @@ SEE ALSO
     # standard file handling
             if ftype>=0:
                 r = _load(oname,fname,state,ftype,finish,
-                          discrete,quiet,multiplex,zoom,_self=_self)
+                          discrete,quiet,multiplex,zoom,mimic,_self=_self)
         finally:
             _self.unlock(r,_self)
         if go_to_first_scene:
             if int(_self.get_setting_legacy("presentation_auto_start"))!=0:
-                _self.scene("auto","start",animate=0)
+                if(_self.get_movie_length()): # rewind movie
+                    _self.rewind()
+                _self.scene("auto","start",animate=0) # go to first scene
         if _self._raising(r,_self): raise pymol.CmdException
         return r
 
@@ -766,7 +945,7 @@ NOTES
                         discrete = -1
                     r = mae.read_maestr(string.join(data,''),
                                         name,state,finish,discrete,
-                                        quiet,zoom,multiplex)
+                                        quiet,zoom,multiplex,mimic)
                     # END PROPRIETARY CODE SEGMENT
                 except ImportError:
                     print "Error: .MAE format not supported by this PyMOL build."
@@ -817,7 +996,7 @@ NOTES
         return r
         
     def read_sdfstr(sdfstr,name,state=0,finish=1,discrete=1,quiet=1,
-                         zoom=-1,multiplex=-2,_self=cmd):
+                    zoom=-1,multiplex=-2,_self=cmd):
         '''
 DESCRIPTION
 
@@ -1079,7 +1258,7 @@ PYMOL API
         if fname and not fobj:
             if os.path.exists(fname):
                 return _self.load(fname,name,state,'pdb',finish,discrete,quiet,
-                                multiplex,zoom)
+                                  multiplex,zoom)
         tries = 0
         r = DEFAULT_ERROR
         done = 0
@@ -1120,8 +1299,8 @@ PYMOL API
                                     fobj.flush()
                                     if auto_close_file:
                                         fobj.close()
-                                r = _self.read_pdbstr(pdb_str,name,state,finish,discrete,quiet,
-                                                      zoom,multiplex)
+                                r = _self.read_pdbstr(pdb_str,name,state,finish,
+                                                      discrete,quiet,zoom,multiplex)
                                 done = 1
                             except IOError:
 #                                print traceback.print_exc()
@@ -1207,11 +1386,11 @@ NOTES
             async = not quiet
         if not int(async):
             try:
-                _self.block_flush()
+                _self.block_flush(_self)
                 r = _multifetch(code,name,state,finish,
                                 discrete,multiplex,zoom,type,path,file,quiet,_self)
             except:
-                _self.unblock_flush()
+                _self.unblock_flush(_self)
         else:
             t = threading.Thread(target=_multifetch,
                                  args=(code,name,state,finish,
