@@ -32,6 +32,7 @@ def get_command_keywords(self_cmd=cmd):
         'cd'            : [ self_cmd.cd                , 0 , 0 , ''  , parsing.STRICT ],
         'center'        : [ self_cmd.center            , 0 , 0 , ''  , parsing.STRICT ],     
         'check'         : [ self_cmd.check             , 0 , 0 , ''  , parsing.STRICT ],
+        'clean'         : [ self_cmd.clean             , 0 , 0 , ''  , parsing.STRICT ],
         'class'         : [ self_cmd.python_help       , 0 , 0 , ''  , parsing.PYTHON ], 
         'clip'          : [ self_cmd.clip              , 0 , 0 , ''  , parsing.STRICT ],
         'cls'           : [ self_cmd.cls               , 0 , 0 , ''  , parsing.STRICT ],
@@ -73,6 +74,7 @@ def get_command_keywords(self_cmd=cmd):
         'exec'          : [ self_cmd.python_help       , 0 , 0 , ''  , parsing.PYTHON ],   
         'export_dots'   : [ self_cmd.export_dots       , 0 , 0 , ''  , parsing.STRICT ],
         'extend'        : [ self_cmd.extend            , 0 , 0 , ''  , parsing.STRICT ],
+        'fab'           : [ self_cmd.fab               , 0 , 0 , ''  , parsing.STRICT ],
         'fast_minimize' : [ self_cmd.fast_minimize     , 1,  4 , ',' , parsing.SIMPLE ], # TO REMOVE
         'feedback'      : [ self_cmd.feedback          , 0,  0 , ''  , parsing.STRICT ],
         'fetch'         : [ self_cmd.fetch             , 0,  0 , ''  , parsing.STRICT ],
@@ -146,8 +148,12 @@ def get_command_keywords(self_cmd=cmd):
         'matrix_reset'  : [ self_cmd.matrix_reset      , 0 , 0 , ''  , parsing.STRICT ],         
         'matrix_copy'   : [ self_cmd.matrix_copy       , 0 , 0 , ''  , parsing.STRICT ],
         'matrix_transfer': [ self_cmd.matrix_copy       , 0 , 0 , ''  , parsing.STRICT ], # LEGACY
+        'mcopy'         : [ self_cmd.mcopy             , 0 , 0 , ''  , parsing.STRICT ],                
+        'mdelete'       : [ self_cmd.mdelete           , 0 , 0 , ''  , parsing.STRICT ],
         'mem'           : [ self_cmd.mem               , 0 , 0 , ''  , parsing.STRICT ],
         'meter_reset'   : [ self_cmd.meter_reset       , 0 , 0 , ''  , parsing.STRICT ],
+        'minsert'       : [ self_cmd.minsert           , 0 , 0 , ''  , parsing.STRICT ],
+        'mmove'         : [ self_cmd.mmove             , 0 , 0 , ''  , parsing.STRICT ],        
         'move'          : [ self_cmd.move              , 0 , 0 , ''  , parsing.STRICT ],
         'mset'          : [ self_cmd.mset              , 0 , 0 , ''  , parsing.STRICT ],
         'mdo'           : [ self_cmd.mdo               , 2 , 2 , ':' , parsing.MOVIE  ],
@@ -164,6 +170,7 @@ def get_command_keywords(self_cmd=cmd):
         'mouse'         : [ self_cmd.mouse             , 0 , 0 , ''  , parsing.STRICT ],
         'multisave'     : [ self_cmd.multisave         , 0 , 0 , ''  , parsing.STRICT ],
         'mview'         : [ self_cmd.mview             , 0 , 0 , ''  , parsing.STRICT ],
+        'order'         : [ self_cmd.order             , 0 , 0 , ''  , parsing.STRICT ],
         'origin'        : [ self_cmd.origin            , 0 , 0 , ''  , parsing.STRICT ],
         'orient'        : [ self_cmd.orient            , 0 , 0 , ''  , parsing.STRICT ],
         'overlap'       : [ self_cmd.overlap           , 0 , 0 , ''  , parsing.STRICT ],
@@ -183,13 +190,13 @@ def get_command_keywords(self_cmd=cmd):
         'rebuild'       : [ self_cmd.rebuild           , 0 , 0 , ''  , parsing.STRICT ],
         'recolor'       : [ self_cmd.recolor           , 0 , 0 , ''  , parsing.STRICT ],   
         'redo'          : [ self_cmd.redo              , 0 , 0 , ''  , parsing.STRICT ],
+        'reference'     : [ self_cmd.reference         , 0 , 0 , ''  , parsing.STRICT ],
         'reinitialize'  : [ self_cmd.reinitialize      , 0 , 0 , ''  , parsing.STRICT ],      
         'refresh'       : [ self_cmd.refresh           , 0 , 0 , ''  , parsing.STRICT ],
         'refresh_wizard': [ self_cmd.refresh_wizard    , 0 , 0 , ''  , parsing.STRICT ],
         'remove'        : [ self_cmd.remove            , 0 , 0 , ''  , parsing.STRICT ],
         'remove_picked' : [ self_cmd.remove_picked     , 0 , 0 , ''  , parsing.STRICT ],
         'rename'        : [ self_cmd.rename            , 0 , 0 , ''  , parsing.STRICT ],
-        'order'         : [ self_cmd.order             , 0 , 0 , ''  , parsing.STRICT ],
         'replace'       : [ self_cmd.replace           , 0 , 0 , ''  , parsing.STRICT ],
         'replace_wizard': [ self_cmd.replace_wizard    , 0 , 0 , ''  , parsing.STRICT ],
         'reset'         : [ self_cmd.reset             , 0 , 0 , ''  , parsing.STRICT ],
@@ -281,15 +288,16 @@ def get_command_keywords(self_cmd=cmd):
         'util.ss'       : [ self_cmd.util.ss           , 0 , 0 , ''  , parsing.STRICT ],# secondary structure
         'util.rainbow'  : [ self_cmd.util.rainbow      , 0 , 0 , ''  , parsing.STRICT ],
         # movie programs
+        'movie.load'    : [ self_cmd.movie.load        , 0 , 0 , ''  , parsing.STRICT ],
+        'movie.nutate'  : [ self_cmd.movie.nutate      , 0 , 0 , ''  , parsing.STRICT ],
+        'movie.pause'   : [ self_cmd.movie.pause       , 0 , 0 , ''  , parsing.STRICT ],
+        'movie.produce' : [ self_cmd.movie.produce     , 0 , 0 , ''  , parsing.STRICT ],
         'movie.rock'    : [ self_cmd.movie.rock        , 0 , 0 , ''  , parsing.STRICT ],
         'movie.roll'    : [ self_cmd.movie.roll        , 0 , 0 , ''  , parsing.STRICT ],
-        'movie.load'    : [ self_cmd.movie.load        , 0 , 0 , ''  , parsing.STRICT ],
-        'movie.zoom'    : [ self_cmd.movie.zoom        , 0 , 0 , ''  , parsing.STRICT ],
         'movie.screw'   : [ self_cmd.movie.screw       , 0 , 0 , ''  , parsing.STRICT ],
         'movie.sweep'   : [ self_cmd.movie.sweep       , 0 , 0 , ''  , parsing.STRICT ],
-        'movie.pause'   : [ self_cmd.movie.pause       , 0 , 0 , ''  , parsing.STRICT ],               
-        'movie.nutate'  : [ self_cmd.movie.nutate      , 0 , 0 , ''  , parsing.STRICT ],
         'movie.tdroll'  : [ self_cmd.movie.tdroll      , 0 , 0 , ''  , parsing.STRICT ],
+        'movie.zoom'    : [ self_cmd.movie.zoom        , 0 , 0 , ''  , parsing.STRICT ],
         # activate metaphorics extensions
         #   'metaphorics'   : [ self_cmd.metaphorics       , 0 , 0 , ''  , parsing.STRICT ],
         }
@@ -351,7 +359,8 @@ def get_help_only_keywords(self_cmd=cmd):
         'python_help'           : [ self_cmd.python_help   ],        
         'povray'                : [ self_cmd.helping.povray  ],
         'read_molstr'           : [ self_cmd.read_molstr ],
-        'read_pdbstr'           : [ self_cmd.read_pdbstr ],      
+        'read_pdbstr'           : [ self_cmd.read_pdbstr ],
+        'read_sdfstr'           : [ self_cmd.read_sdfstr ],              
         'release'               : [ self_cmd.helping.release ],   
         'selections'            : [ self_cmd.helping.selections ],
         'skip'                  : [ self_cmd.helping.skip  ],                
