@@ -21,22 +21,93 @@ def extract(self_cmd, sele):
             [ 1, 'byres extend 1', 'cmd.create(None,"byres (('+sele+') extend 1)",extract="'+sele+'",zoom=0)' ],            
             ]
 
-def all_motion(self_cmd, sele):
-    return [[ 2, 'Camera Motions:'     , ''                       ],     
-            [ 1, 'store'         , 'cmd.mview("store")'      ],
-            [ 1, 'clear'       ,   'cmd.mview("clear")'      ],
+def camera_store_with_scene(self_cmd,frame):
+    list = self_cmd.get_scene_list()[0:40] # keep this practical
+    result = [[ 2, 'Scene:', '']]
+    for a in list:
+        result.append([1,a,'cmd.mview("store",scene="'+a+'",first=%s)'%frame])
+    return result
+
+
+def store_with_state(self_cmd,obj='',frame=0):
+    list = self_cmd.get_scene_list()[0:40] # keep this practical
+    n_state = self_cmd.count_states()
+    result = [[ 2, 'State:', ''],
+              [ 1, 'current','cmd.mview("store",object="'+obj+'",state=-1,first=%s)'%(frame)],
+              [ 0, ''               ,''                   ],
+              [ 1, '1', 'cmd.mview("store",object="'+obj+'",state=1,first=%s)'%(frame)   ],
+              ]
+    if (n_state>1):
+        result.extend([
+              [ 1, str(n_state),'cmd.mview("store",object="'+obj+'",state=%d,first=%s)'%(n_state,frame)],
+              [ 0, ''               ,''                   ],
+              [ 1, str(1+n_state/4), 'cmd.mview("store",object="'+obj+'",state=%d,first=%s)'%(1+n_state/4,frame) ],
+              [ 1, str(1+n_state/3), 'cmd.mview("store",object="'+obj+'",state=%d,first=%s)'%(1+n_state/3,frame) ],
+              [ 1, str(n_state/2), 'cmd.mview("store",object="'+obj+'",state=%d,first=%s)'%(n_state/2,frame) ],
+              [ 1, str(1+n_state/2), 'cmd.mview("store",object="'+obj+'",state=%d,first=%s)'%(1+n_state/2,frame) ],
+              [ 1, str((2*n_state)/3), 'cmd.mview("store",object="'+obj+'",state=%d,first=%s)'%((2*n_state)/3,frame) ],
+              [ 1, str((3*n_state)/4), 'cmd.mview("store",object="'+obj+'",state=%d,first=%s)'%((3*n_state)/4,frame) ],
+              ])
+
+    return result
+
+def mouse_config(self_cmd):
+    result = [[ 1, '3-Button Motions',
+                'cmd.config_mouse("three_button_motions")' ],
+              [ 1, '3-Button Editing',
+                'cmd.config_mouse("three_button_editing")' ],
+              [ 1, '3-Button Viewing',
+                'cmd.mouse("three_button_viewing")' ],
+              [ 1, '3-Button All Modes',
+                'cmd.config_mouse("three_button_all_modes")' ],
+              [ 0, '', ''],
+              [ 1, '2-Button Editing',
+                'cmd.config_mouse("two_button_editing")' ],
+              [ 1, '2-Button Viewing',
+                'cmd.config_mouse("two_button_viewing")' ],
+              ]
+    return result
+
+def smooth(self_cmd,extra=''):
+    return [[ 1, 'a little'  ,   'cmd.mview("smooth"%s)'%extra            ],
+            [ 1, 'more'     ,   'cmd.mview("smooth",window=15%s)'%extra ],
+            [ 1, 'a lot'   ,   'cmd.mview("smooth",window=30%s)'%extra ]]
+              
+def camera_motion(self_cmd, frame="0"):
+    return [[ 2, 'Camera Motion:'     , ''                       ],     
+            [ 1, 'store'         , 'cmd.mview("store",first='+frame+')'      ],
+            [ 1, 'store with scene' , camera_store_with_scene(self_cmd,frame) ],
+            [ 1, 'store with state' , store_with_state(self_cmd,'',frame) ],
+            [ 1, 'clear'       ,   'cmd.mview("clear",first='+frame+')'      ],
+            [ 0, ''               ,''                             ],
+            [ 1, 'reset camera motions'   , 'cmd.mview("reset")'   ],
+            [ 0, ''               ,''                             ],
+            [ 1, 'purge entire movie'   , 'cmd.mset()'   ],            
+            [ 0, ''               ,''                             ],
+            [ 1, 'smooth key frames'  ,   smooth(self_cmd)     ],
             [ 0, ''               ,''                             ],
             [ 1, 'interpolate'   , 'cmd.mview("interpolate")'   ],
             [ 1, 'reinterpolate'   , 'cmd.mview("reinterpolate")'   ],            
+            [ 1, 'uninterpolate'   , 'cmd.mview("uninterpolate")'   ],            
             ]
 
-def mol_motion(self_cmd, sele):
-    return [[ 2, 'Object Motions:'     , ''                       ],     
-            [ 1, 'store'         , 'cmd.mview("store",object="'+sele+'")'      ],
-            [ 1, 'clear'       ,   'cmd.mview("clear",object="'+sele+'")'    ],
+def obj_motion(self_cmd, obj, frame="0"):
+    return [[ 2, 'Object "'+obj+'" Motion:'     , ''                       ],     
+            [ 1, 'drag'       ,   'cmd.drag("'+obj+'")'    ],
             [ 0, ''               ,''                             ],
-            [ 1, 'interpolate'   ,   'cmd.mview("interpolate",object="'+sele+'")'    ],
-            [ 1, 'reinterpolate'   ,   'cmd.mview("reinterpolate",object="'+sele+'")'    ],
+            [ 1, 'store'         , 'cmd.mview("store",object="'+obj+'",first='+frame+')'      ],
+            [ 1, 'store with state' , store_with_state(self_cmd,obj,frame) ],            
+            [ 1, 'reset'       ,   ';cmd.reset(object="'+obj+'");'    ],
+            [ 1, 'clear'       ,   'cmd.mview("clear",object="'+obj+'",first='+frame+')'    ],
+            [ 0, ''               ,''                             ],
+            [ 1, 'reset object motions'       ,   'cmd.mview("reset",object="'+obj+'")'    ],
+            [ 1, 'purge object motions'       ,   'cmd.mview("purge",object="'+obj+'")'    ],
+            [ 0, ''               ,''                             ],
+            [ 1, 'smooth key frames' , smooth(self_cmd,',object="'+obj+'"') ],
+            [ 0, ''               ,''                             ],
+            [ 1, 'interpolate'   ,   'cmd.mview("interpolate",object="'+obj+'")'    ],
+            [ 1, 'reinterpolate'   ,   'cmd.mview("reinterpolate",object="'+obj+'")'    ],
+            [ 1, 'uninterpolate'   ,   'cmd.mview("uninterpolate",object="'+obj+'")'    ],
             ]
 
 def rep_action(self_cmd, sele, action) :
@@ -91,7 +162,8 @@ def mol_show(self_cmd, sele):
             ") & r. CYS+CYX & n. SG) & bound_to (("+sele+") & r. CYS+CYX & n. SG))) & n. CA+CB+SG") ]
          ])
 
-    self_cmd.show("lines","(byres (("+sele+" & r. CYS+CYX & n. SG) & bound_to ("+sele+" & r. CYS+CYX & n. SG))) & n. CA+CB+SG")
+    self_cmd.show("lines","(byres ((" + sele + " & r. CYS+CYX & n. SG) & bound_to ("
+                  + sele + " & r. CYS+CYX & n. SG))) & n. CA+CB+SG")
 
 def hide_hydro(self_cmd, sele):
     return ( [[ 2, 'Hide:'     , ''                                ],
@@ -860,7 +932,7 @@ def modify_sele(self_cmd, sele):
 
               
 def sele_action(self_cmd, sele):
-    return [[ 2, 'Actions:'       ,''                        ],     
+    return [[ 2, 'Action:'       ,''                        ],     
               [ 1, 'delete selection', 'cmd.delete("'+sele+'")'          ],
               [ 1, 'rename selection', 'cmd.wizard("renaming","'+sele+'")'          ],
               [ 0, ''               ,''                             ],
@@ -869,7 +941,8 @@ def sele_action(self_cmd, sele):
               [ 1, 'center'         ,'cmd.center("'+sele+'",animate=-1)'            ],           
               [ 1, 'origin'         ,'cmd.origin("'+sele+'")'          ],
               [ 0, ''               ,''                             ],
-              [ 1, 'drag'       , 'cmd.drag("'+sele+'")'    ],                        
+              [ 1, 'drag coordinates'     , 'cmd.drag("'+sele+'")'    ],
+              [ 1, 'clean'       , 'cmd.clean("'+sele+'")'    ],                                    
               [ 0, ''               ,''                             ],
               [ 1, 'modify', modify_sele(self_cmd, sele) ],
               [ 1, 'preset'         ,presets(self_cmd, sele)         ],
@@ -889,7 +962,7 @@ def sele_action(self_cmd, sele):
 
 
 def sele_action2(self_cmd, sele):
-    return [[ 2, 'Actions:'       ,''                        ],     
+    return [[ 2, 'Action:'       ,''                        ],     
               [ 1, 'delete selection', 'cmd.delete("'+sele+'")'          ],
               [ 1, 'rename selection', 'cmd.wizard("renaming","'+sele+'")'          ],
               [ 0, ''               ,''                             ],
@@ -914,30 +987,63 @@ def sele_action2(self_cmd, sele):
               ]
 
 
+def group_action(self_cmd, sele):
+    return [[ 2, 'Action:'     , ''                       ],     
+            [ 1, 'zoom'         , 'cmd.zoom("'+sele+'",animate=-1)'      ],
+            [ 1, 'orient'       , 'cmd.orient("'+sele+'",animate=-1)'    ],
+            [ 1, 'center'         ,'cmd.center("'+sele+'",animate=-1)'            ],
+            [ 1, 'origin'       , 'cmd.origin("'+sele+'")'    ],
+            [ 0, ''               ,''                             ],
+            [ 1, 'drag' , 'cmd.drag("'+sele+'")' ],
+            [ 1, 'reset' , 'cmd.reset(object="'+sele+'")' ],
+            [ 0, ''               ,''                             ],            
+            [ 1, 'preset'  ,   presets(self_cmd, sele)       ],
+            [ 1, 'find',     find(self_cmd, sele) ],
+            [ 1, 'align',     mol_align(self_cmd, sele) ],                      
+            [ 1, 'generate'  ,   mol_generate(self_cmd, sele)       ],           
+            [ 0, ''               ,''                             ],
+            [ 1, 'assign sec. struc.'  ,'cmd.dss("'+sele+'")'        ],
+            [ 0, ''             , ''                       ],
+            [ 1, 'rename group', 'cmd.wizard("renaming","'+sele+'")'          ],
+            [ 1, 'delete group'       , 'cmd.delete("'+sele+'")'    ],
+            [ 0, ''          ,''                                              ],
+            [ 1, 'hydrogens' , hydrogens(self_cmd, sele)    ],           
+            [ 1, 'remove waters'  ,'cmd.remove("(solvent and ('+sele+'))")'     ],
+            [ 0, ''          ,''                                              ],
+            [ 1, 'state'          , state(self_cmd, sele)         ],                      
+            [ 1, 'masking'        , masking(self_cmd, sele)         ],
+            [ 1, 'sequence'       , sequence(self_cmd, sele)         ],                      
+            [ 1, 'movement'       , movement(self_cmd, sele)         ],           
+            [ 1, 'compute'        , compute(self_cmd, sele)         ],
+            ]
     
 def mol_action(self_cmd, sele):
-    return [[ 2, 'Actions:'     , ''                       ],     
-              [ 1, 'zoom'         , 'cmd.zoom("'+sele+'",animate=-1)'      ],
-              [ 1, 'orient'       , 'cmd.orient("'+sele+'",animate=-1)'    ],
-              [ 1, 'center'         ,'cmd.center("'+sele+'",animate=-1)'            ],
-              [ 1, 'origin'       , 'cmd.origin("'+sele+'")'    ],
-              [ 0, ''               ,''                             ],
-              [ 1, 'drag'       , 'cmd.drag("'+sele+'")'    ],            
-              [ 0, ''          ,''                                              ],
-              [ 1, 'preset'  ,   presets(self_cmd, sele)       ],
-              [ 1, 'find',     find(self_cmd, sele) ],
-              [ 1, 'align',     mol_align(self_cmd, sele) ],                      
-              [ 1, 'generate'  ,   mol_generate(self_cmd, sele)       ],           
-              [ 0, ''               ,''                             ],
-              [ 1, 'assign sec. struc.'  ,'cmd.dss("'+sele+'")'        ],
-              [ 0, ''             , ''                       ],
-              [ 1, 'rename object', 'cmd.wizard("renaming","'+sele+'")'          ],
-              [ 1, 'duplicate object'    ,'cmd.create(None,"'+sele+'")'     ],           
-              [ 1, 'delete object'       , 'cmd.delete("'+sele+'")'    ],
-              [ 0, ''          ,''                                              ],
-              [ 1, 'hydrogens' , hydrogens(self_cmd, sele)    ],           
-              [ 1, 'remove waters'  ,'cmd.remove("(solvent and ('+sele+'))")'     ],
-              [ 0, ''          ,''                                              ],
+    return [[ 2, 'Action:'     , ''                       ],     
+            [ 1, 'zoom'         , 'cmd.zoom("'+sele+'",animate=-1)'      ],
+            [ 1, 'orient'       , 'cmd.orient("'+sele+'",animate=-1)'    ],
+            [ 1, 'center'         ,'cmd.center("'+sele+'",animate=-1)'            ],
+            [ 1, 'origin'       , 'cmd.origin("'+sele+'")'    ],
+            [ 0, ''               ,''                             ],
+            [ 1, 'drag matrix' , 'cmd.drag("'+sele+'")' ],
+            [ 1, 'reset matrix' , 'cmd.reset(object="'+sele+'")' ],
+            [ 0, ''               ,''                             ],            
+            [ 1, 'drag coordinates' , 'cmd.drag("('+sele+')")' ],
+            [ 1, 'clean'       , 'cmd.clean("'+sele+'")'    ],
+            [ 0, ''          ,''                                              ],
+            [ 1, 'preset'  ,   presets(self_cmd, sele)       ],
+            [ 1, 'find',     find(self_cmd, sele) ],
+            [ 1, 'align',     mol_align(self_cmd, sele) ],                      
+            [ 1, 'generate'  ,   mol_generate(self_cmd, sele)       ],           
+            [ 0, ''               ,''                             ],
+            [ 1, 'assign sec. struc.'  ,'cmd.dss("'+sele+'")'        ],
+            [ 0, ''             , ''                       ],
+            [ 1, 'rename object', 'cmd.wizard("renaming","'+sele+'")'          ],
+            [ 1, 'duplicate object'    ,'cmd.create(None,"'+sele+'")'     ],           
+            [ 1, 'delete object'       , 'cmd.delete("'+sele+'")'    ],
+            [ 0, ''          ,''                                              ],
+            [ 1, 'hydrogens' , hydrogens(self_cmd, sele)    ],           
+            [ 1, 'remove waters'  ,'cmd.remove("(solvent and ('+sele+'))")'     ],
+            [ 0, ''          ,''                                              ],
               [ 1, 'state'          , state(self_cmd, sele)         ],                      
               [ 1, 'masking'        , masking(self_cmd, sele)         ],
               [ 1, 'sequence'       , sequence(self_cmd, sele)         ],                      
@@ -946,7 +1052,7 @@ def mol_action(self_cmd, sele):
               ]
 
 def slice_action(self_cmd, sele):
-    return [[ 2, 'Actions:'     , ''                       ],
+    return [[ 2, 'Action:'     , ''                       ],
               [ 1, 'zoom'         , 'cmd.zoom("'+sele+'",animate=-1)'      ],
               [ 1, 'center'       , 'cmd.center("'+sele+'",animate=-1)'    ],           
               [ 1, 'origin'       , 'cmd.origin("'+sele+'")'    ],         
@@ -966,14 +1072,18 @@ def slice_action(self_cmd, sele):
               ]
 
 def simple_action(self_cmd, sele):
-    return [[ 2, 'Actions:'     , ''                       ],
-              [ 1, 'zoom'         , 'cmd.zoom("'+sele+'",animate=-1)'      ],
-              [ 1, 'center'       , 'cmd.center("'+sele+'",animate=-1)'    ],           
-              [ 1, 'origin'       , 'cmd.origin("'+sele+'")'    ],
-              [ 0, ''             , ''                       ],
-              [ 1, 'rename'       , 'cmd.wizard("renaming","'+sele+'")'          ],           
-              [ 0, ''             , ''                       ],
-              [ 1, 'delete'       , 'cmd.delete("'+sele+'")'    ],
+    return [[ 2, 'Action:'     , ''                       ],
+            [ 1, 'zoom'         , 'cmd.zoom("'+sele+'",animate=-1)'      ],
+            [ 1, 'center'       , 'cmd.center("'+sele+'",animate=-1)'    ],           
+            [ 1, 'origin'       , 'cmd.origin("'+sele+'")'    ],
+            
+            [ 0, ''             , ''                       ],
+            [ 1, 'drag'       , 'cmd.drag("'+sele+'")'          ],
+            [ 1, 'reset'       , 'cmd.reset(object="'+sele+'")'          ],           
+            [ 0, ''             , ''                       ],
+            [ 1, 'rename'       , 'cmd.wizard("renaming","'+sele+'")'          ],           
+            [ 0, ''             , ''                       ],
+            [ 1, 'delete'       , 'cmd.delete("'+sele+'")'    ],
               ]
 
 def map_mesh(self_cmd, sele):
@@ -984,8 +1094,8 @@ def map_mesh(self_cmd, sele):
             [ 1, '@ level 3.0'         , 'cmd.isomesh("'+sele+'_mesh","'+sele+'",3.0)'      ],            
             [ 0, ''             , ''                       ],            
             [ 1, '@ level 0.0'         , 'cmd.isomesh("'+sele+'_mesh","'+sele+'",0.0)'      ],
-            [ 1, '@ level -1.0'         , 'cmd.isomesh("'+sele+'_mesh","'+sele+'",1.0)'      ],
-            [ 1, '@ level -2.0'         , 'cmd.isomesh("'+sele+'_mesh","'+sele+'",2.0)'      ],
+            [ 1, '@ level -1.0'         , 'cmd.isomesh("'+sele+'_mesh","'+sele+'",-1.0)'      ],
+            [ 1, '@ level -2.0'         , 'cmd.isomesh("'+sele+'_mesh","'+sele+'",-2.0)'      ],
             [ 1, '@ level -3.0'         , 'cmd.isomesh("'+sele+'_mesh","'+sele+'",-3.0)'      ],
             ]
 
@@ -1017,20 +1127,23 @@ def map_slice(self_cmd, sele):
             ]
 
 def map_action(self_cmd, sele):
-    return [[ 2, 'Actions:'     , ''                       ],
-              [ 1, 'mesh'         , map_mesh(self_cmd, sele)  ],
-              [ 1, 'surface'      , map_surface(self_cmd, sele)  ],
-              [ 1, 'slice'        , map_slice(self_cmd, sele)  ],
-              [ 1, 'gradient'     , map_gradient(self_cmd, sele)  ],                                    
-              [ 0, ''             , ''                       ],
-              [ 1, 'zoom'         , 'cmd.zoom("'+sele+'",animate=-1)'      ],
-              [ 1, 'center'       , 'cmd.center("'+sele+'",animate=-1)'    ],           
-              [ 1, 'origin'       , 'cmd.origin("'+sele+'")'    ],
-              [ 0, ''             , ''                       ],
-              [ 1, 'rename'       , 'cmd.wizard("renaming","'+sele+'")'          ],           
-              [ 0, ''             , ''                       ],
-              [ 1, 'delete'       , 'cmd.delete("'+sele+'")'    ],
-              ]
+    return [[ 2, 'Action:'     , ''                       ],
+            [ 1, 'mesh'         , map_mesh(self_cmd, sele)  ],
+            [ 1, 'surface'      , map_surface(self_cmd, sele)  ],
+            [ 1, 'slice'        , map_slice(self_cmd, sele)  ],
+            [ 1, 'gradient'     , map_gradient(self_cmd, sele)  ],                                    
+            [ 0, ''             , ''                       ],
+            [ 1, 'zoom'         , 'cmd.zoom("'+sele+'",animate=-1)'      ],
+            [ 1, 'center'       , 'cmd.center("'+sele+'",animate=-1)'    ],           
+            [ 1, 'origin'       , 'cmd.origin("'+sele+'")'    ],
+            [ 0, ''             , ''                       ],
+            [ 1, 'drag' , 'cmd.drag("'+sele+'")' ],
+            [ 1, 'reset'       , 'cmd.reset(object="'+sele+'")'          ],                       
+            [ 0, ''             , ''                       ],
+            [ 1, 'rename'       , 'cmd.wizard("renaming","'+sele+'")'          ],           
+            [ 0, ''             , ''                       ],
+            [ 1, 'delete'       , 'cmd.delete("'+sele+'")'    ],
+            ]
 
 def level(self_cmd, sele):
     return [[ 2, 'Level',  '' ],
@@ -1052,33 +1165,39 @@ def level(self_cmd, sele):
             ]
 
 def surface_action(self_cmd, sele):
-    return [[ 2, 'Actions:'     , ''                       ],
-              [ 1, 'level'         , level(self_cmd, sele)  ],
-              [ 0, ''             , ''                       ],
-              [ 1, 'zoom'         , 'cmd.zoom("'+sele+'",animate=-1)'      ],
-              [ 1, 'center'       , 'cmd.center("'+sele+'",animate=-1)'    ],           
-              [ 1, 'origin'       , 'cmd.origin("'+sele+'")'    ],
-              [ 0, ''             , ''                       ],
-              [ 1, 'rename'       , 'cmd.wizard("renaming","'+sele+'")'          ],           
-              [ 0, ''             , ''                       ],
-              [ 1, 'delete'       , 'cmd.delete("'+sele+'")'    ],
-              ]
+    return [[ 2, 'Action:'     , ''                       ],
+            [ 1, 'level'         , level(self_cmd, sele)  ],
+            [ 0, ''             , ''                       ],
+            [ 1, 'zoom'         , 'cmd.zoom("'+sele+'",animate=-1)'      ],
+            [ 1, 'center'       , 'cmd.center("'+sele+'",animate=-1)'    ],           
+            [ 1, 'origin'       , 'cmd.origin("'+sele+'")'    ],
+            [ 0, ''             , ''                       ],
+            [ 1, 'drag' , 'cmd.drag("'+sele+'")' ],
+            [ 1, 'reset'       , 'cmd.reset(object="'+sele+'")'          ],                       
+            [ 0, ''             , ''                       ],
+            [ 1, 'rename'       , 'cmd.wizard("renaming","'+sele+'")'          ],           
+            [ 0, ''             , ''                       ],
+            [ 1, 'delete'       , 'cmd.delete("'+sele+'")'    ],
+            ]
 
 def mesh_action(self_cmd, sele):
-    return [[ 2, 'Actions:'     , ''                       ],
-              [ 1, 'level'         , level(self_cmd, sele)  ],
-              [ 0, ''             , ''                       ],
-              [ 1, 'zoom'         , 'cmd.zoom("'+sele+'",animate=-1)'      ],
-              [ 1, 'center'       , 'cmd.center("'+sele+'",animate=-1)'    ],           
-              [ 1, 'origin'       , 'cmd.origin("'+sele+'")'    ],
-              [ 0, ''             , ''                       ],
-              [ 1, 'rename'       , 'cmd.wizard("renaming","'+sele+'")'          ],           
-              [ 0, ''             , ''                       ],
-              [ 1, 'delete'       , 'cmd.delete("'+sele+'")'    ],
-              ]
+    return [[ 2, 'Action:'     , ''                       ],
+            [ 1, 'level'         , level(self_cmd, sele)  ],
+            [ 0, ''             , ''                       ],
+            [ 1, 'zoom'         , 'cmd.zoom("'+sele+'",animate=-1)'      ],
+            [ 1, 'center'       , 'cmd.center("'+sele+'",animate=-1)'    ],           
+            [ 1, 'origin'       , 'cmd.origin("'+sele+'")'    ],
+            [ 0, ''             , ''                       ],
+            [ 1, 'drag' , 'cmd.drag("'+sele+'")' ],
+            [ 1, 'reset'       , 'cmd.reset(object="'+sele+'")'          ],                       
+            [ 0, ''             , ''                       ],
+            [ 1, 'rename'       , 'cmd.wizard("renaming","'+sele+'")'          ],           
+            [ 0, ''             , ''                       ],
+            [ 1, 'delete'       , 'cmd.delete("'+sele+'")'    ],
+            ]
 
 def ramp_action(self_cmd, sele):
-    return [[ 2, 'Actions:'     , ''                       ],
+    return [[ 2, 'Action:'     , ''                       ],
               [ 1, 'delete'       , 'cmd.delete("'+sele+'")'    ],
               ]
 
@@ -1097,7 +1216,7 @@ def test2(self_cmd, sele):
               ]
 
 def all_action(self_cmd, sele):
-    return [[ 2, 'Actions:'     , ''                      ],     
+    return [[ 2, 'Action:'     , ''                      ],     
               [ 1, 'zoom'         , 'cmd.zoom("all",animate=-1)'     ],
               [ 1, 'center'   , 'cmd.center("all",animate=-1)'   ],           
               [ 1, 'origin'   , 'cmd.origin("all")'   ],
@@ -1213,14 +1332,70 @@ def enable_disable(self_cmd, enable):
         
     return result
 
-def main_menu(self_cmd):
+def scene_buttons(self_cmd):
+    return [[ 2, 'Buttons', '' ],
+            [ 1, 'on', 'cmd.set("scene_buttons")'],
+            [ 1, 'off', 'cmd.unset("scene_buttons")']]
+
+def scene_main(self_cmd):
+    list = self_cmd.get_scene_list()
+    recall_list = [ [2, 'Scenes' , ''] ]
+    for entry in list:
+        recall_list.append([1,entry,'cmd.scene("""'+entry+'""")'])
+    return [
+        [ 2, 'Scene', '' ],
+        [ 1, 'next' , 'cmd.scene()' ],
+        [ 0, ''             , ''                      ],
+        [ 1, 'append' , 'cmd.scene("new","append",quiet=0)' ],                
+        [ 1, 'update' , 'cmd.scene("auto","update",quiet=0)' ],
+        [ 0, ''             , ''                      ],
+        [ 1, 'recall' , recall_list ],
+        [ 0, ''             , ''                      ],        
+        [ 1, 'buttons', scene_buttons(self_cmd)] ]
+
+def main_pseudoatom_sub(self_cmd,pos):
+    return [
+        [ 2, 'Pseudoatom' ,'' ],
+        [ 1, 'label' ,'cmd.wizard("pseudoatom","label",pos=[%1.7f,%1.7f,%1.7f])'%pos ],
+        [ 0, ''             , ''                      ],
+        [ 1, 'single ', 'cmd.pseudoatom(pos=[%1.7f,%1.7f,%1.7f])'%pos ],
+        ]
+
+def main_pseudoatom(self_cmd,pos):
+    return [
+        [ 2, 'New'  , '' ],
+        [ 1, 'pseudoatom' , main_pseudoatom_sub(self_cmd,pos) ],
+        ]
+
+def movie_panel(self_cmd):
+    return [[ 2, 'Panel', '' ],
+            [ 1, 'on', 'cmd.set("movie_panel")'],
+            [ 1, 'off', 'cmd.unset("movie_panel")']]
+
+def movie_main(self_cmd):
+    return [
+        [ 2, 'Movie', ''],
+        [ 1, 'play', 'cmd.mplay()'],
+        [ 1, 'stop', 'cmd.mstop()'],
+        [ 0, '', '' ],
+        [ 1, 'rewind', 'cmd.rewind()'],
+        [ 0, '', '' ],
+        [ 1, 'panel', movie_panel(self_cmd) ]
+        ]
+
+def main_menu(self_cmd,pos):
     return [
         [ 2, 'Main Pop-Up'  , '' ],
+        [ 1, 'new'             , main_pseudoatom(self_cmd,pos) ],        
+        [ 0, ''             , ''                      ],
         [ 1, 'zoom (vis)'           ,'cmd.zoom("visible",animate=-1)'            ],
         [ 1, 'orient (vis)'           ,'cmd.orient("visible",animate=-1)'            ],
         [ 1, 'center (vis)'           ,'cmd.center("visible",animate=-1)'            ],      
         [ 1, 'reset'           ,'cmd.reset()'            ],
         [ 0, ''             , ''                      ],
+        [ 1, 'movie'           , movie_main(self_cmd) ],
+        [ 1, 'scene'           , scene_main(self_cmd) ],
+        [ 0, ''             , ''                      ],
         [ 1, 'enable', enable_disable(self_cmd, 1) ],
         [ 1, 'disable', enable_disable(self_cmd,0) ],   
         [ 0, ''             , ''                      ],           
@@ -1265,12 +1440,18 @@ def pick_sele(self_cmd, sele, title):
         [ 1, 'origin'           ,'cmd.origin("'+sele+'")'            ],
         [ 0, ''               ,''                             ],        
         [ 1, 'drag'             ,'cmd.drag("'+sele+'")'            ],
+        [ 1, 'clean'             ,'cmd.clean("'+sele+'")'            ],        
         [ 0, ''               ,''                             ],        
         [ 1, 'remove'             ,'cmd.remove("'+sele+'")'            ],
         ]
     return result
     
 def pick_option(self_cmd, sele, title, object=0):
+    if object:
+        save_sele = sele
+        sele = "(byobj ("+sele+"))"
+    else:
+        save_sele = sele
     result = [
         [ 2, title, '' ],
         [ 1, 'color'      , mol_color(self_cmd, sele) ],
@@ -1284,11 +1465,19 @@ def pick_option(self_cmd, sele, title, object=0):
         [ 1, 'center'           ,'cmd.center("'+sele+'",animate=-1)'            ],
         [ 1, 'origin'           ,'cmd.origin("'+sele+'")'            ],
         [ 1, 'select'        ,'cmd.select("'+sele+'",enable=1,merge=2)'            ],
-        [ 0, ''               ,''                             ],        
-        [ 1, 'drag'             ,'cmd.drag("'+sele+'")'            ],
+        [ 0, ''               ,''                             ]]
+
+    if object:
+        result.append([ 1, 'drag'             ,   [[ 1, 'coordinates', 'cmd.drag("'+sele+'")'],
+                                     [ 1, 'matrix', 'cmd.drag("'+save_sele+'",mode=1)']]])
+    else:
+        result.append([ 1, 'drag'   ,  'cmd.drag("'+sele+'")'])
+        
+    result.extend([
+        [ 1, 'clean'             ,'cmd.clean("'+sele+'")'            ],        
         [ 1, 'masking'        , masking(self_cmd, sele)         ],
         [ 1, 'movement'       , movement(self_cmd, sele)         ],
-        ]
+        ])
   
     if object:
         result.extend([
@@ -1316,19 +1505,22 @@ def pick_menu(self_cmd, sele1, sele2):
     else:
         title = sele1
     return [[ 2, title     , '' ],
+            [ 1, 'drag object matrix'      ,'cmd.drag("(byobj ('+sele2+'))",mode=1)'            ],
+            [ 1, 'drag object coords'      ,'cmd.drag("(byobj ('+sele2+'))")'            ],
+            [ 0, ''             , ''                      ],
             [ 1, 'atom'    , pick_option(self_cmd, sele2, "Atom") ],
             [ 1, 'residue' , pick_option(self_cmd, "(byres ("+sele2+"))", "Residue") ],
             [ 1, 'chain'   , pick_option(self_cmd, "(bychain ("+sele2+"))", "Chain") ],
             [ 1, 'segment' , pick_option(self_cmd, "(byseg ("+sele2+"))", "Segment") ],
-            [ 1, 'object'  , pick_option(self_cmd, "(byobject ("+sele2+"))", "Object",1) ],
+            [ 1, 'object'  , pick_option(self_cmd, sele2, "Object",1) ],
             [ 0, ''             , ''                      ],
             [ 1, 'molecule', pick_option(self_cmd, "(bymol ("+sele2+"))", "Molecule") ],
             [ 0, ''             , ''                      ],
             [ 1, 'fragment', pick_option(self_cmd, "(byfrag ("+sele2+"))", "Fragment") ],
             [ 1, 'fragment+joint(s)', pick_option(self_cmd, "((byfrag ("+sele2+")) extend 1)", "Fragment") ],
-              ]
+            ]
         
-def seq_menu(sele2,sele3):
+def seq_menu(sele2,sele3): # obsolete/unused?
     
     return [[ 2, 'Sequence'    , '' ],
               [ 1, 'selection', pick_option(self_cmd, sele3, '('+sele3+')') ],
@@ -1365,6 +1557,7 @@ def seq_option(self_cmd, sele, title, object=0):
         [ 1, 'select'    ,'cmd.select("'+sele+'",enable=1,merge=2)'            ],
         [ 0, ''               ,''                             ],        
         [ 1, 'drag'      ,'cmd.drag("'+sele+'")'            ],
+        [ 1, 'clean'      ,'cmd.clean("'+sele+'")'            ],        
         ]
     
     if object:
@@ -1384,3 +1577,13 @@ def seq_option(self_cmd, sele, title, object=0):
             ])
     return result
     
+def scene_menu(self_cmd, name):
+    safe_name = name.replace('"','\\"') # just in case
+    return [[ 2, 'Scene '+name    , '' ],
+            [ 1, 'rename', 'cmd.wizard("renaming","'+name+'",mode="scene")'          ],
+            [ 0, ''             , ''                      ],
+            [ 1, 'update', 'cmd.scene("'+safe_name+'","update")'],
+            [ 0, ''             , ''                      ],
+            [ 1, 'delete', 'cmd.scene("'+safe_name+'","delete")'],
+            ]
+   
