@@ -16,6 +16,10 @@ import cmd
 import glob
 import math
 import string
+import os
+import glob
+import threading
+import time
 
 def sweep(pause=0,cycles=1,_self=cmd):
     pause = int(pause)
@@ -254,75 +258,126 @@ def timed_roll(period=12.0,cycles=1,axis='y',_self=cmd):
     for cycle in range(cycles):
         for cnt in range(frames_per_cycle):
             _self.turn(axis,deg)
-            _self.mview('store',frame)
+            _self.mview('store',frame,freeze=1)
             frame = frame + 1
-    
-# new matrix-based camera interpolation routines
 
-def add_roll(duration=12.0,loop=1,axis='y',_self=cmd):
+# blank frames to be specified by the user
+
+def add_blank(duration=12.0,start=0,_self=cmd):
     cmd = _self
-    start_frame = cmd.get_movie_length()+1
+    if not start:
+        start = cmd.get_movie_length()+1
     duration = float(duration)
     fps = float(cmd.get('movie_fps'))
     n_frame = int(round(fps * duration))
     if n_frame > 0:
-        cmd.madd("1 x%d"%n_frame)
-        cmd.frame(start_frame)
-        cmd.mview("store")
-        cmd.frame(start_frame+n_frame/3)
+        cmd.mset("1 x%d"%n_frame,start)
+        cmd.frame(start)
+
+# new matrix-based camera interpolation routines
+
+def add_roll(duration=12.0,loop=1,axis='y',start=0,_self=cmd):
+    cmd = _self
+    if not start:
+        start = cmd.get_movie_length()+1
+    duration = float(duration)
+    fps = float(cmd.get('movie_fps'))
+    n_frame = int(round(fps * duration))
+    if n_frame > 0:
+        cmd.mset("1 x%d"%n_frame,start,freeze=1)
+        cmd.mview("store",start,power=1,freeze=1)
         cmd.turn(axis,120)
-        cmd.mview("store")
-        cmd.frame(start_frame+(2*n_frame)/3)
+        cmd.mview("store",start+n_frame/3,power=1,freeze=1)
         cmd.turn(axis,120)
-        cmd.mview("store")
+        cmd.mview("store",start+(2*n_frame)/3,power=1,freeze=1)
         if loop:
-            if (start_frame == 1):
-                cmd.mview("interpolate",power=1,wrap=1)
-                cmd.frame(start_frame+n_frame-1)
-                cmd.mview("store")
+            if (start == 1):
+                cmd.mview("interpolate",wrap=1)
+                cmd.turn(axis,120)                
+                cmd.mview("store",start+n_frame-1,power=1,freeze=1)
                 cmd.turn(axis,120)
             else:
                 adjustment = 360.0/n_frame
-                cmd.frame(start_frame+n_frame-1)
                 cmd.turn(axis,120 - adjustment)
-                cmd.mview("store")
-                cmd.mview("interpolate",power=1)
+                cmd.mview("store",start+n_frame-1,power=1,freeze=1)
+                cmd.mview("interpolate")
                 cmd.turn(axis,adjustment) 
         else:
-            cmd.frame(start_frame+n_frame-1)
             cmd.turn(axis,120)
-            cmd.mview("store")
-            cmd.mview("interpolate",power=1)
-        cmd.frame(start_frame)
+            cmd.mview("store",start+n_frame-1,power=1,freeze=1)
+            cmd.mview("interpolate")
+        cmd.frame(start)
         
-def add_rock(duration=8.0,angle=30.0,loop=1,axis='y',_self=cmd):
+def add_rock(duration=8.0,angle=30.0,loop=1,axis='y',start=0,_self=cmd):
     cmd = _self
-    start_frame = cmd.get_movie_length()+1
+    if not start:
+        start = cmd.get_movie_length()+1
     duration = float(duration)
     angle=float(angle)
     loop=int(loop)
     fps = float(cmd.get('movie_fps'))
     n_frame = int(round(fps * duration))
     if n_frame > 0:
-        cmd.madd("1 x%d"%n_frame)
-        cmd.frame(start_frame+n_frame/4)
+        cmd.mset("1 x%d"%n_frame,start,freeze=1)
         cmd.turn(axis,angle/2.0)
-        cmd.mview("store")
-        cmd.frame(start_frame+(3*n_frame)/4)
+        cmd.mview("store",start+n_frame/4,power=-1,freeze=1)
         cmd.turn(axis,-angle)
-        cmd.mview("store")
-        cmd.turn(axis,angle/2.0)
-        if loop and (start_frame == 1):
-            cmd.mview("interpolate",power=-1,wrap=1)
+        cmd.mview("store",start+(3*n_frame)/4,power=-1,freeze=1)
+        if loop and (start == 1):
+            cmd.mview("interpolate",wrap=1)
         else:
-            cmd.mview("interpolate",power=-1)
-        cmd.frame(start_frame)
+            cmd.mview("interpolate")
+        cmd.frame(start)
+
+def add_state_sweep(factor=1,pause=2.0,first=-1,last=-1,loop=1,start=0,_self=cmd):
+    cmd = _self
+    if not start:
+        start = cmd.get_movie_length() + 1
+    loop = int(loop)
+    fps = float(cmd.get('movie_fps'))
+    n_state = cmd.count_states()
+    duration = (2 * pause) + (2 * factor * n_state) / fps
+    n_frame = int(round(fps * duration))
+    if n_frame > 0:
+        cmd.mset("1 x%d"%n_frame, start, freeze=1)
+        cmd.mview("store",start, state=1, freeze=1)
+        cmd.mview("store",start + (n_frame * pause) / duration, state=1, freeze=1)
+        cmd.mview("store",start + n_state * factor + (n_frame * pause) / duration - 1, state=n_state, freeze=1)
+        cmd.mview("store",start + n_state * factor + (2 * n_frame * pause) / duration, state=n_state, freeze=1)
+        cmd.mview("store",start + n_frame-1, state=1, freeze=1)
+        if loop and (start == 1):
+            cmd.mview("interpolate",wrap=1)
+        else:
+            cmd.mview("interpolate")
+        cmd.frame(start)
+
+def add_state_loop(factor=1,pause=2.0,first=-1,last=-1,loop=1,start=0,_self=cmd):
+    cmd = _self
+    if not start:
+        start = cmd.get_movie_length() + 1
+    loop = int(loop)
+    fps = float(cmd.get('movie_fps'))
+    n_state = cmd.count_states()
+    duration = (pause) + (factor * n_state) / fps
+    n_frame = int(round(fps * duration))
+    if n_frame > 0:
+        cmd.mset("1 x%d"%n_frame, start, freeze=1)
+        cmd.mview("store",start, state=1, freeze=1)
+        cmd.mview("store",start + (n_frame * pause * 0.5) / duration, state=1, freeze=1)
+        cmd.mview("store",start + n_state * factor + (n_frame * pause * 0.5) / duration, state=n_state, freeze=1)
+        cmd.mview("store",start + n_frame-1, state=n_state, freeze=1)
+        if loop and (start == 1):
+            cmd.mview("interpolate",wrap=1)
+        else:
+            cmd.mview("interpolate")
+        cmd.frame(start)
 
 def add_nutate(duration=8.0, angle=30.0, spiral=0, loop=1, 
-               offset=0, phase=0, shift=math.pi/2.0,
+               offset=0, phase=0, shift=math.pi/2.0, start=0,
                _self=cmd):
     cmd = _self
-    start_frame = cmd.get_movie_length()+1
+    if not start:
+        start = cmd.get_movie_length()+1
     duration = float(duration)
     angle = float(angle)
     spiral = int(spiral)
@@ -330,7 +385,7 @@ def add_nutate(duration=8.0, angle=30.0, spiral=0, loop=1,
     fps = float(cmd.get('movie_fps'))
     n_frame = int(round(fps * duration))
     if n_frame > 0:
-        cmd.madd("1 x%d"%n_frame)
+        cmd.mset("1 x%d"%n_frame,start,freeze=1)
         for index in range(0,n_frame):
             if spiral>0:
                 sp_angle = angle*float(index+1)/n_frame
@@ -341,17 +396,15 @@ def add_nutate(duration=8.0, angle=30.0, spiral=0, loop=1,
             ang_cur = math.pi*phase/180.0 + (2*math.pi*index)/n_frame
             x_rot = sp_angle * math.sin(ang_cur)/2
             y_rot = sp_angle * math.sin(ang_cur+shift)/2      
-            cmd.frame(start_frame+index)
             cmd.turn('x',x_rot)
             cmd.turn('y',y_rot)
-            cmd.mview('store')
+            cmd.mview('store',start+index,freeze=1)
             cmd.turn('y',-y_rot)
             cmd.turn('x',-x_rot)
     
-def _rock_y(mode,first,last,period,pause,_self=cmd):
+def _rock(mode,axis,first,last,period,pause,_self=cmd):
     cmd = _self
     n_frame = last - first + 1
-    axis = 'y'
     angle = 10
     if (period * 1.5) < pause:
         n_cyc = int(round(pause / period))
@@ -365,21 +418,16 @@ def _rock_y(mode,first,last,period,pause,_self=cmd):
         direction = 0
         for frame in frame_list:
             if not direction:
-                cmd.frame(frame)
                 cmd.turn(axis,angle/2.0)
-                cmd.mview("store")
+                cmd.mview("store",frame,power=-1,freeze=1)
                 direction = -1
             else:
-                cmd.frame(frame)
                 cmd.turn(axis, direction * angle)
-                cmd.mview("store")
+                cmd.mview("store",frame,power=-1,freeze=1)
                 direction = -direction
-
-        cmd.frame(last)
         cmd.turn(axis,direction * angle/2.0)
-        cmd.mview("store")
-
-        cmd.mview("interpolate",first,last,power=-1)
+        cmd.mview("store",last,power=-1,freeze=1)
+        cmd.mview("interpolate",first,last)
 
 def _nutate_sub(start_frame, stop_frame, angle=15.0, spiral=0, loop=1, 
                 offset=0, phase=0, shift=math.pi/2.0, _self=cmd):
@@ -401,10 +449,9 @@ def _nutate_sub(start_frame, stop_frame, angle=15.0, spiral=0, loop=1,
             ang_cur = math.pi*phase/180.0 + (2*math.pi*index)/n_frame
             x_rot = sp_angle * math.sin(ang_cur)/2
             y_rot = sp_angle * math.sin(ang_cur+shift)/2      
-            cmd.frame(start_frame+index)
             cmd.turn('x',x_rot)
             cmd.turn('y',y_rot)
-            cmd.mview('store')
+            cmd.mview('store',start_frame+index,freeze=1)
             cmd.turn('y',-y_rot)
             cmd.turn('x',-x_rot)
     
@@ -428,8 +475,11 @@ def _nutate(mode,first,last,period,pause,_self=cmd):
         spiral = 0
         
 def add_scenes(names=None, pause=8.0, cut=0.0, loop=1,
-               rock=-1, period=8.0, animate=-1, _self=cmd):
+               rock=-1, period=8.0, animate=-1, start=0,
+               _self=cmd):
     cmd = _self
+    if not start:
+        start = cmd.get_movie_length()+1
     animate = float(animate)
     pause = float(pause)
     period = float(period)
@@ -443,7 +493,6 @@ def add_scenes(names=None, pause=8.0, cut=0.0, loop=1,
     elif cmd.is_str(names):
         names = cmd.safe_alpha_list_eval(names)
     n_scene = len(names)
-    start_frame = cmd.get_movie_length()+1
     duration = n_scene*(pause+animate)
     fps = float(cmd.get('movie_fps'))
     n_frame = int(round(fps * duration))
@@ -459,33 +508,210 @@ def add_scenes(names=None, pause=8.0, cut=0.0, loop=1,
     else:
         sweep_mode = 0
     if n_frame > 0:
-        cmd.madd("1 x%d"%act_n_frame)
+        cmd.mset("1 x%d"%act_n_frame,start,freeze=1)
         cnt = 0
         for scene in names:
-            frame = start_frame+int((cnt*n_frame)/n_scene)
-            cmd.frame(frame)
-            cmd.mview("store",scene=scene)
+            frame = start+int((cnt*n_frame)/n_scene)
+            cmd.mview("store",frame,scene=scene,freeze=1)
             if rock:
                 cmd.mview("interpolate",cut=cut,wrap=0)
                 sweep_first = frame + 1
-                sweep_last = start_frame + int(pause*fps+(cnt*n_frame)/n_scene) - 1
+                sweep_last = start + int(pause*fps+(cnt*n_frame)/n_scene) - 1
                 if sweep_last > act_n_frame:
                     sweep_last = act_n_frame
                 n_sweep_frame = sweep_last - sweep_first + 1
                 if n_sweep_frame > 0:
-                    if sweep_mode<3: # y-axis rock
-                        _rock_y(sweep_mode, sweep_first, sweep_last,
+                    if sweep_mode==1: # x-axis rock
+                        _rock(sweep_mode, 'x', sweep_first, sweep_last,
+                                period, pause, _self=_self)
+                    elif sweep_mode<3: # y-axis rock                        
+                        _rock(sweep_mode, 'y', sweep_first, sweep_last,
                                 period, pause, _self=_self)
                     elif sweep_mode == 3:
                         _nutate(sweep_mode, sweep_first, sweep_last,
                                 period, pause, _self=_self)
-            frame = start_frame+int(pause*fps+(cnt*n_frame)/n_scene)
+            frame = start+int(pause*fps+(cnt*n_frame)/n_scene)
             if frame <= act_n_frame:
                 if sweep_mode!=3:
-                    cmd.frame(frame)
-                    cmd.mview("store",scene=scene)
+                    cmd.mview("store",frame,scene=scene,freeze=1)
             cnt = cnt + 1
         cmd.mview("interpolate",cut=cut,wrap=loop)
         if rock:
             cmd.mview("smooth")
-        cmd.frame(start_frame)
+        cmd.frame(start)
+
+_prefix = "mov"
+
+def _watch(filename,done_event):
+    tries = 5
+    size = 0
+    import time,os
+    while not os.path.exists(filename):
+        if done_event.isSet():
+            break
+        tries = tries - 1
+        if tries < 0:
+            break
+        time.sleep(1) 
+    if os.path.exists(filename):
+        tries = 5
+    while os.path.exists(filename):
+        stat = os.stat(filename)
+        if size != stat[6]:
+            tries = 5
+            size = stat[6]
+            if done_event.isSet():
+                break
+            print " produce: %d bytes written..."%size
+        else:
+            tries = tries - 1
+            if tries < 0:
+                break
+        time.sleep(2)
+        if done_event.isSet():
+            break
+            
+def _encode(filename,mode,first,last,preserve,
+            encoder,tmp_path,prefix,quality,quiet,_self=cmd):
+    import os
+    tries = 10
+    while 1: # loop until all of the files have been created...
+        done = 1
+        # check for the required output files
+        for index in range(first,last+1):
+            path = os.path.join(tmp_path,prefix+"%04d.ppm"%index)
+            if not os.path.exists(path):
+                done = 0
+                break;
+        if done:
+            break
+        elif _self.get_modal_draw(): # keep looping so long as we're rendering...
+            tries = 10
+        else: 
+            tries = tries - 1
+            if tries < 0:
+                done = 0
+                break
+        time.sleep(0.25)
+    _self.sync()
+    ok = 1
+    if done and ok and (encoder == 'mpeg_encode'):
+        try:
+            from freemol import mpeg_encode
+        except:
+            ok = 0
+            print "produce-error: Unable to import module freemol.mpeg_encode."
+        if ok:
+            if not mpeg_encode.validate():
+                ok = 0
+                print "produce-error: Unable to validate freemol.mpeg_encode."
+        if not ok:
+            print "produce-error: Unable to create mpeg file."            
+        else:
+            mpeg_quality = 1+int(((100-quality)*29)/100) # 1 to 30
+            input = mpeg_encode.input(filename,tmp_path,
+                                      prefix,first,last,mpeg_quality);
+            if not quiet:
+                print " produce: creating '%s' (in background)..."%(filename)
+
+            done_event = None
+            if not quiet:
+                done_event = threading.Event()
+                t = threading.Thread(target=_watch,
+                                     args=(filename,done_event))
+                t.setDaemon(1)
+                t.start()
+
+            try:
+                result = mpeg_encode.run(input)
+            finally:
+                if done_event != None:
+                    done_event.set()
+            if not quiet:
+                if not os.path.exists(filename):
+                    if result != None:
+                        print input, result[0], result[1]
+                    print " produce: compression failed"
+                else:
+                    print " produce: finished."
+    _self.unset("keep_alive")
+    if preserve<1:
+        if os.path.isdir(tmp_path):
+            for fil in glob.glob(os.path.join(tmp_path,prefix+"*")):
+                os.unlink(fil)
+            os.rmdir(tmp_path)
+    
+produce_mode_dict = {
+    'normal'  : 0,
+    'draw'    : 1,
+    'ray'     : 2,
+    }
+
+produce_mode_sc = cmd.Shortcut(produce_mode_dict.keys())
+
+
+def produce(filename, mode='', first=0, last=0, preserve=0,
+            encoder='mpeg_encode', quality=60, quiet=1, _self=cmd):
+    prefix = _prefix
+
+    if _self.is_string(mode):
+        if mode == '':
+            if int(cmd.get_setting_legacy('ray_trace_frames')):
+                mode = 'ray'
+            elif cmd._pymol.invocation.options.no_gui:
+                mode = 'ray'
+            else:
+                mode = 'draw'
+        mode = produce_mode_sc.auto_err(mode,"mode")
+        mode = produce_mode_dict[mode]
+    else:
+        mode = int(mode)
+    first = int(first)
+    last = int(last)
+    quiet = int(quiet)
+    preserve = int(preserve)
+    quality = int(quality)
+    if quality<0:
+        quality = 0
+    if quality>100:
+        quality = 100
+    ok = 1
+    splitext = os.path.splitext(filename)
+    tmp_path = splitext[0]+".tmp"
+    if splitext[1]=='':
+        splitext=(splitext[0],'.mpg')
+    filename = splitext[0]+splitext[1]
+    if os.path.exists(filename):
+        os.unlink(filename)
+    if not os.path.exists(tmp_path):
+        os.mkdir(tmp_path)
+    elif preserve==0:
+        # get rid of existing frames (if they exist)
+        for fil in glob.glob(os.path.join(tmp_path,prefix+"*")):
+            os.unlink(fil)
+    if preserve<0:
+        preserve = 0
+    if os.path.isdir(tmp_path):
+        if first <= 0:
+            first = 1
+        if last <= 0:
+            last = _self.count_frames()
+        if last <= 1:
+            last = 1
+        _self.set("keep_alive")
+        _self.mpng(os.path.join(tmp_path,prefix+".ppm"),first,last,
+                   preserve,mode=mode,modal=1,quiet=quiet) 
+        # this may run asynchronously
+    else:
+        ok = 0
+    if ok:
+        t = threading.Thread(target=_encode,
+                             args=(filename,mode,first,last,preserve,
+                                   encoder,tmp_path,prefix,quality,quiet,_self))
+        t.setDaemon(1)
+        t.start()
+    if ok:
+        return _self.DEFAULT_SUCCESS
+    else:
+        return _self.DEFAULT_ERROR
+    
