@@ -19,7 +19,7 @@ if __name__=='pymol.moving':
 
     import selector
     import pymol
-
+    import re
     import cmd
     from cmd import _cmd,Shortcut, \
           toggle_dict,toggle_sc, \
@@ -115,7 +115,8 @@ DESCRIPTION
             _self.unlock(r,_self)
         if _self._raising(r,_self): raise pymol.CmdException
         return r
-    
+
+
     def mstop(_self=cmd):
         '''
 DESCRIPTION
@@ -147,14 +148,19 @@ SEE ALSO
         'reinterpolate' : 3,
         'smooth'   : 4,
         'reset'    : 5,
+        'uninterpolate' : 6,
+        'toggle'    : 7,
+        'toggle_interp' : 8, 
+        'purge'      : 9
         }
 
     mview_action_sc = Shortcut(mview_action_dict.keys())
 
-    def mview(action='store', first=0, last=0, power=1.4,
-              bias=1.0, simple=0, linear=0.0, object='',
-              wrap=-1, hand=1, window=5, cycles=1, scene='',
-              cut=0.5, quiet=1, _self=cmd):
+    def mview(action='store', first=0, last=0, power=0.0,
+              bias=-1.0, simple=-1, linear=0.0, object='',
+              wrap=-1, hand=0, window=5, cycles=1, scene='',
+              cut=0.5, quiet=1, auto=-1, state=0, freeze=0,
+              _self=cmd):
 
         '''
 DESCRIPTION
@@ -180,6 +186,8 @@ SEE ALSO
         r = DEFAULT_ERROR
         first = int(first)
         last = int(last)
+        auto = int(auto)
+        freeze = int(freeze)
         if first<0:
             first = _self.count_frames() + first + 1
             if last == 0:
@@ -187,7 +195,7 @@ SEE ALSO
         if last<0:
             last = _self.count_frames() + last + 1
         action = mview_action_dict[mview_action_sc.auto_err(action,'action')]
-        if scene==None:
+        if (scene==None) or (scene=='auto'):
             scene = _self.get("scene_current_name")
         scene = str(scene)
         if (scene!=''):
@@ -198,7 +206,16 @@ SEE ALSO
                            float(power),float(bias),
                            int(simple), float(linear),str(object),
                            int(wrap),int(hand),int(window),int(cycles),
-                           str(scene),float(cut),int(quiet))
+                           str(scene),float(cut),int(quiet),int(state)-1,0)
+            if (not freeze and 
+                ((auto>0) or ((auto<0) and 
+                              (_self.get_setting_int("movie_auto_interpolate")>0)))):
+                if action in [0,1,7]: # reinterpolate after store, clear, or toggle
+                    _cmd.mview(_self._COb,3,-1,-1,
+                               float(power),float(bias),
+                               int(simple), float(linear),str(object),
+                               int(wrap),int(hand),int(window),int(cycles),
+                               str(scene),float(cut),int(quiet),-1,1)                    
         finally:
             _self.unlock(r,_self)
         if _self._raising(r,_self): raise pymol.CmdException
@@ -338,7 +355,8 @@ SEE ALSO
         if _self._raising(r,_self): raise pymol.CmdException
         return r
 
-    def mpng(prefix,first=0,last=0,preserve=0,modal=0,_self=cmd):
+    def mpng(prefix,first=0,last=0,preserve=0,modal=0,
+             mode=-1,quiet=1,_self=cmd):
         '''
 DESCRIPTION
 
@@ -386,13 +404,17 @@ SEE ALSO
         r = DEFAULT_ERROR
         if thread.get_ident() ==pymol.glutThread:
             r = _self._mpng(prefix,int(first)-1,int(last)-1,
-                            int(preserve),int(modal))
+                            int(preserve),int(modal),-1,int(mode),int(quiet))
         else:
-            r = _self.do('cmd._mpng("'+prefix+'","'+
-                       str(int(first)-1)+'","'+
-                       str(int(last)-1)+'","'+
-                       str(int(preserve))+'","'+
-                       str(int(modal))+'",_self=cmd)',0)
+            r = _self.do('cmd._mpng("""'+prefix+'""","'+
+                         str(int(first)-1)+'","'+
+                         str(int(last)-1)+'","'+
+                         str(int(preserve))+'","'+
+                         str(int(modal))+'","'+
+                         str(int(-1))+'","'+
+                         str(int(mode))+'","'+
+                         str(int(quiet))+
+                         '",_self=cmd)',0)
         if _self._raising(r,_self): raise pymol.CmdException
         return r
 
@@ -420,7 +442,7 @@ PYMOL API
         return r
 
 
-    def frame(frame,_self=cmd):
+    def frame(frame,trigger=-1,scene=0,_self=cmd):
         '''
 DESCRIPTION
 
@@ -453,13 +475,168 @@ SEE ALSO
         r = DEFAULT_ERROR
         try:
             _self.lock(_self)   
-            r = _cmd.frame(_self._COb,int(frame))
+            r = _cmd.frame(_self._COb,int(frame),int(trigger),int(scene))
         finally:
             _self.unlock(r,_self)
         if _self._raising(r,_self): raise pymol.CmdException
         return r
 
-    def madd(specification=""):
+    def mmove(target,source=0,count=-1,freeze=0,object='',quiet=1,_self=cmd):
+        '''
+DESCRIPTION
+
+    "mmove" moves key frames and movie commands
+
+SEE ALSO
+
+    mdelete, minsert
+
+    '''
+        r = DEFAULT_ERROR
+        count = int(count)
+        source = int(source)
+        target = int(target)
+        freeze = int(freeze)
+        object = str(object)
+        quiet = int(quiet)
+        cur_len = _self.count_frames()
+        if not source: # 0 means use current frame
+            source = _self.get_frame() - 1
+        elif source<0:
+            source = _self.count_sources() + 1 + source
+            if (count>0) and (source + count) > cur_len:
+                source = cur_len - count
+        else:
+            source -= 1
+        if not target: # 0 means use current frame
+            target = _self.get_frame() - 1
+        elif target<0:
+            target = _self.count_targets() + 1 + target
+            if (count>0) and (target + count) > cur_len:
+                target = cur_len - count
+        else:
+            target -= 1
+        try:
+            _self.lock(_self)
+            r = _cmd.mmodify(_self._COb,2,source,count,
+                             target,object,freeze,quiet)
+        finally:
+            _self.unlock(r,_self)
+        if _self._raising(r,_self): raise pymol.CmdException
+        return r
+
+    def mcopy(target,source=0,count=-1,freeze=0,object='',quiet=1,_self=cmd):
+        '''
+DESCRIPTION
+
+    "mmove" copies key frames and movie commands
+
+SEE ALSO
+
+    mdelete, minsert
+
+    '''
+        r = DEFAULT_ERROR
+        count = int(count)
+        source = int(source)
+        target = int(target)
+        freeze = int(freeze)
+        object = str(object)
+        quiet = int(quiet)
+        cur_len = _self.count_frames()
+        if not source: # 0 means use current frame
+            source = _self.get_frame() - 1
+        elif source<0:
+            source = _self.count_sources() + 1 + source
+            if (count>0) and (source + count) > cur_len:
+                source = cur_len - count
+        else:
+            source -= 1
+        if not target: # 0 means use current frame
+            target = _self.get_frame() - 1
+        elif target<0:
+            target = _self.count_targets() + 1 + target
+            if (count>0) and (target + count) > cur_len:
+                target = cur_len - count
+        else:
+            target -= 1
+        try:
+            _self.lock(_self)
+            r = _cmd.mmodify(_self._COb,3,source,count,
+                             target,object,freeze,quiet)
+        finally:
+            _self.unlock(r,_self)
+        if _self._raising(r,_self): raise pymol.CmdException
+        return r
+
+    def mdelete(count=-1,frame=0,freeze=0,object='',quiet=1,_self=cmd):
+        '''
+DESCRIPTION
+
+    "mdelete" removes frames from camera view and object motions.
+
+SEE ALSO
+
+    minsert, mmove
+
+    '''
+        r = DEFAULT_ERROR
+        count = int(count)
+        frame = int(frame)
+        freeze = int(freeze)
+        object = str(object)
+        quiet = int(quiet)
+        cur_len = _self.count_frames()
+        if not frame: # 0 means use current frame
+            frame = _self.get_frame() - 1
+        elif frame<0:
+            frame = _self.count_frames() + 1 + frame
+            if (count>0) and (frame + count) > cur_len:
+                frame = cur_len - count
+        else:
+            frame -= 1
+        if count < 0: # negative count means delete to end
+            count = 1 + cur_len - frame
+        try:
+            _self.lock(_self)
+            r = _cmd.mmodify(_self._COb,-1,frame,count,
+                             0,object,freeze,quiet)
+        finally:
+            _self.unlock(r,_self)
+        if _self._raising(r,_self): raise pymol.CmdException
+        return r
+
+    def minsert(count,frame=0,freeze=0,object='',quiet=1,_self=cmd):
+        '''
+DESCRIPTION
+
+    "minsert" adds frames into camera view and object motions.
+
+SEE ALSO
+
+    mdelete, mmove
+
+    '''
+        r = DEFAULT_ERROR
+        frame = int(frame)
+        count = int(count)
+        freeze = int(freeze)
+        object = str(object)
+        quiet = int(quiet)        
+        if not frame: # 0 means use current frame
+            frame = _self.get_frame() - 1
+        else:
+            frame -= 1
+        try:
+            _self.lock(_self)
+            r = _cmd.mmodify(_self._COb,1,frame,count,
+                             0,object,freeze,quiet)
+        finally:
+            _self.unlock(r,_self)
+        if _self._raising(r,_self): raise pymol.CmdException
+        return r
+
+    def madd(specification="",frame=0,freeze=0,_self=cmd):
         '''
 DESCRIPTION
 
@@ -471,9 +648,9 @@ SEE ALSO
     mset, mdo, mplay, mclear
 
     '''
-        mset(specification,0)
+        mset(specification,frame,freeze,_self=_self)
         
-    def mset(specification="",frame=1,_self=cmd):
+    def mset(specification="",frame=1,freeze=0,_self=cmd):
         '''
 DESCRIPTION
 
@@ -511,11 +688,17 @@ SEE ALSO
     mdo, mplay, mclear
         '''
         r = DEFAULT_ERROR
-        cur_state = _self.get_state()-1 # use the current state 
+        cur_state = _self.get_state()-1 # use the current state
+        specification = str(specification)
         try:
             _self.lock(_self)
             output=[]
-            input = string.split(string.strip(specification))
+            input = re.sub("\s"," ",specification)
+            input = input.replace("x"," x");
+            input = input.replace("-"," -");
+            input = input.replace("x ","x");
+            input = input.replace("- ","-");
+            input = string.split(string.strip(input))
             last = -1
             for x in input:
                 if x[0]>"9" or x[0]<"0":
@@ -541,7 +724,7 @@ SEE ALSO
                     val = int(x) - 1
                     output.append(str(val))
                     last=val
-            r = _cmd.mset(_self._COb,string.join(output," "),int(frame)-1)
+            r = _cmd.mset(_self._COb,string.join(output," "),int(frame)-1,int(freeze))
         finally:
             _self.unlock(r,_self)
         if _self._raising(r,_self): raise pymol.CmdException
@@ -616,7 +799,7 @@ SEE ALSO
         r = DEFAULT_ERROR
         try:
             _self.lock(_self)   
-            r = _cmd.setframe(_self._COb,5,1)
+            r = _cmd.set_frame(_self._COb,5,1)
         finally:
             _self.unlock(r,_self)
         if _self._raising(r,_self): raise pymol.CmdException
@@ -643,7 +826,7 @@ SEE ALSO
         r = DEFAULT_ERROR
         try:
             _self.lock(_self)   
-            r = _cmd.setframe(_self._COb,5,-1)
+            r = _cmd.set_frame(_self._COb,5,-1)
         finally:
             _self.unlock(r,_self)
         if _self._raising(r,_self): raise pymol.CmdException
@@ -667,7 +850,21 @@ PYMOL API
         r = DEFAULT_ERROR
         try:
             _self.lock(_self)   
-            r = _cmd.setframe(_self._COb,4,0)
+            r = _cmd.set_frame(_self._COb,4,0)
+        finally:
+            _self.unlock(r,_self)
+        if _self._raising(r,_self): raise pymol.CmdException
+        return r
+
+
+    def set_frame(frame=1, mode=0, _self=cmd):
+        '''
+internal
+        '''
+        r = DEFAULT_ERROR      
+        try:
+            _self.lock(_self)   
+            r=_cmd.set_frame(_self._COb, int(mode), int(frame)-1)
         finally:
             _self.unlock(r,_self)
         if _self._raising(r,_self): raise pymol.CmdException
@@ -690,7 +887,7 @@ PYMOL API
         r = DEFAULT_ERROR      
         try:
             _self.lock(_self)   
-            r=_cmd.setframe(_self._COb,6,0)
+            r=_cmd.set_frame(_self._COb,6,0)
         finally:
             _self.unlock(r,_self)
         if _self._raising(r,_self): raise pymol.CmdException
@@ -713,7 +910,7 @@ PYMOL API
         r = DEFAULT_ERROR
         try:
             _self.lock(_self)   
-            r = _cmd.setframe(_self._COb,3,0)
+            r = _cmd.set_frame(_self._COb,3,0)
         finally:
             _self.unlock(r,_self)
         if _self._raising(r,_self): raise pymol.CmdException
