@@ -34,6 +34,45 @@ if __name__=='pymol.querying':
                     _self.distance()
         _self.unpick()   
 
+    def get_unused_name(prefix="tmp",alwaysnumber=1,_self=cmd):
+        r = DEFAULT_ERROR        
+        # should replace this with a C function
+        try:
+            _self.lock(_self)  
+            avoid_dict = {}
+            for name in _self.get_names('all'):
+                avoid_dict[name] = None
+            if alwaysnumber or avoid_dict.has_key(prefix):
+                counter = 1
+                while 1:
+                    r = prefix + "%02d"%counter
+                    if not avoid_dict.has_key(r):
+                        break
+                    counter = counter + 1
+            else:
+                r=prefix
+        finally:
+            _self.unlock(r,_self)
+        return r
+    
+    def get_modal_draw(_self=cmd,quiet=1):
+        r = DEFAULT_ERROR
+        try:
+            _self.lock(_self)   
+            r = _cmd.get_modal_draw(_self._COb)
+        finally:
+            _self.unlock(r,_self)
+        return r
+
+    def get_drag_object_name(_self=cmd):
+        r = DEFAULT_ERROR
+        try:
+            _self.lock(_self)   
+            r = _cmd.get_drag_object_name(_self._COb)
+        finally:
+            _self.unlock(r,_self)
+        return r
+
     def get_object_matrix(object,state=1,_self=cmd):
         '''
 DESCRIPTION
@@ -462,6 +501,27 @@ PYMOL API
         if _raising(r,_self): raise pymol.CmdException
         return r
 
+    def get_idtf(_self=cmd):
+        '''
+DESCRIPTION
+
+    "get_idft" is under development, but should eventually return an
+    idtf file containing multiple objects and scenes.
+
+PYMOL API
+
+    cmd.idtf()
+
+        '''
+        r = DEFAULT_ERROR
+        try:
+            _self.lock(_self)   
+            r = _cmd.get_idtf(_self._COb)
+        finally:
+            _self.unlock(r,_self)
+        if _raising(r,_self): raise pymol.CmdException
+        return r
+
     def get_mtl_obj(_self=cmd):
         '''
 DESCRIPTION
@@ -512,7 +572,7 @@ PYMOL API
                     print " version: %s (%8.6f) %d"%r
         return r
     
-    def get_vrml(_self=cmd): 
+    def get_vrml(version=2,_self=cmd): 
         '''
 DESCRIPTION
 
@@ -527,7 +587,7 @@ PYMOL API
         r = DEFAULT_ERROR
         try:
             _self.lock(_self)   
-            r = _cmd.get_vrml(_self._COb)
+            r = _cmd.get_vrml(_self._COb,int(version))
         finally:
             _self.unlock(r,_self)
         if _raising(r,_self): raise pymol.CmdException
@@ -1011,6 +1071,7 @@ SEE ALSO
         '''
         selection = selector.process(selection)
         r = DEFAULT_ERROR
+        # this needs to be replaced with a flag & masking scheme...
         mode = 1
         if type=='objects':
             mode = 1
@@ -1024,6 +1085,17 @@ SEE ALSO
             mode = 4
         elif type=='public_selections':
             mode = 5
+        elif type=='public_nongroup_objects':
+            mode = 6
+        elif type=='public_group_objects':
+            mode = 7
+        elif type=='nongroup_objects':
+            mode = 8
+        elif type=='group_objects':
+            mode = 9
+        else:
+            print "Error: unknown type: '%s'"%str(type)
+            if _raising(-1,_self): raise pymol.CmdException            
         try:
             _self.lock(_self)
             r = _cmd.get_names(_self._COb,int(mode),int(enabled_only),str(selection))
@@ -1032,6 +1104,16 @@ SEE ALSO
         if _raising(r,_self): raise pymol.CmdException
         return r
 
+    def get_legal_name(name,_self=cmd):
+        r = DEFAULT_ERROR
+        try:
+            _self.lock(_self)
+            r = _cmd.get_legal_name(_self._COb,str(name))
+        finally:
+            _self.unlock(r,_self)
+        if _raising(r,_self): raise pymol.CmdException
+        return r
+
     def get_type(name,quiet=1,_self=cmd):
         '''
 DESCRIPTION
@@ -1260,7 +1342,7 @@ USAGE
         return r
 
 
-    def count_atoms(selection="(all)",quiet=1,state=0,_self=cmd):
+    def count_atoms(selection="(all)",quiet=1,state=0,domain='',_self=cmd):
         '''
 DESCRIPTION
 
@@ -1272,7 +1354,7 @@ USAGE
 
 PYMOL API
 
-    cmd.count(string selection)
+    cmd.count_atoms(string selection)
 
         '''
         r = DEFAULT_ERROR
@@ -1281,7 +1363,7 @@ PYMOL API
         #
         try:
             _self.lock(_self)   
-            r = _cmd.select(_self._COb,"_count_tmp","("+str(selection)+")",1,int(state)-1,'')
+            r = _cmd.select(_self._COb,"_count_tmp","("+str(selection)+")",1,int(state)-1,str(domain))
             _cmd.delete(_self._COb,"_count_tmp")
         finally:
             _self.unlock(r,_self)
