@@ -632,7 +632,43 @@ if __name__=='pymol.setting':
         mesh_clear_cutoff                  = 594
         mesh_grid_max                      = 595
         session_cache_optimize             = 596
-        
+        sdof_drag_scale                    = 597
+        scene_buttons_mode                 = 598
+        scene_buttons                      = 599
+        map_auto_expand_sym                = 600
+        image_copy_always                  = 601
+        max_ups                            = 602
+        auto_overlay                       = 603
+        stick_ball_color                   = 604
+        stick_h_scale                      = 605
+        sculpt_pyra_inv_weight             = 606
+        keep_alive                         = 607
+        fit_kabsch                         = 608
+        stereo_dynamic_strength            = 609
+        dynamic_width                      = 610
+        dynamic_width_factor               = 611
+        dynamic_width_min                  = 612
+        dynamic_width_max                  = 613
+        draw_mode                          = 614
+        clean_electro_mode                 = 615
+        valence_mode                       = 616
+        show_frame_rate                    = 617
+        movie_panel                        = 618
+        mouse_z_scale                      = 619
+        movie_auto_store                   = 620
+        movie_auto_interpolate             = 621
+        movie_panel_row_height             = 622
+        scene_frame_mode                   = 623
+        surface_cavity_mode                = 624
+        surface_cavity_radius              = 625
+        surface_cavity_cutoff              = 626
+        motion_power                       = 627
+        motion_bias                        = 628
+        motion_simple                      = 629
+        motion_linear                      = 630
+        motion_hand                        = 631
+        pdb_ignore_conect                  = 632
+        editor_bond_cycle_mode             = 633
         
     setting_sc = Shortcut(SettingIndex.__dict__.keys())
     
