@@ -356,7 +356,6 @@ def performance(mode,_self=cmd):
         cmd.set('stick_ball',0.0)
         cmd.do("rebuild")         
     
-    
 def label_chains(sele="all",_self=cmd):
     pymol=_self._pymol
     cmd=_self
@@ -421,7 +420,6 @@ def hide_sele(_self=cmd):
 #            "((%s) and ((%s) around %4.2f) and elem N,O)"%(b,a,cutoff),
 #            cutoff)
 
-
 def cbc(selection='(all)',first_color=7,quiet=1,legacy=0,_self=cmd):
     pymol=_self._pymol
     cmd=_self 
@@ -464,7 +462,7 @@ def color_objs(selection='(all)',quiet=1,_self=cmd):
     Color all chains a different color
     '''
     c = 0
-    for a in cmd.get_names(selection=selection):
+    for a in cmd.get_names('public_nongroup_objects',selection=selection):
 	if (selection!='all') and (selection!='(all)'):
             cmd.color(_color_cycle[c],"(?%s and (%s))"%(a,selection),quiet=quiet)
         else:
@@ -1221,5 +1219,5 @@ def colors(scheme="",_self=cmd):
         cmd.set_color("sulfur",[1.000,1.000,0.189])
         cmd.color("carbon","elem c")
         cmd.recolor()
-        
-                          
+
+
