@@ -118,7 +118,7 @@ SEE ALSO
         try:
             _self.lock(_self)   
             r = _cmd.zoom(_self._COb,str(selection),float(buffer),
-                              int(state)-1,int(complete),int(animate))
+                              int(state)-1,int(complete),float(animate))
         finally:
             _self.unlock(r,_self)
         if _self._raising(r,_self): raise QuietException
@@ -168,7 +168,7 @@ SEE ALSO
         #
         try:
             _self.lock(_self)   
-            r = _cmd.center(_self._COb,str(selection),int(state)-1,int(origin),int(animate))
+            r = _cmd.center(_self._COb,str(selection),int(state)-1,int(origin),float(animate))
         finally:
             _self.unlock(r,_self)
         if _self._raising(r,_self): raise QuietException
@@ -764,18 +764,23 @@ ARGUMENTS
 NOTES
 
     Contents of the view matrix:
+    
+    * 0  -  8: column-major 3x3 matrix which rotates model space to camera space
 
-    * 0  -  8: column-major 3x3 matrix which rotates model axes to camera axes
+    * 9  - 11: origin of rotation relative to camera (in camera space)
 
-    * 9  - 11: origin or rotation relative to the camera in camera space
-
-    * 12 - 14:  origin of rotation in model space
+    * 12 - 14: origin of rotation (in model space)
 
     * 15: front plane distance from the camera
 
     * 16: rear plane distance from the camera
 
-    * 17: orthoscopic flag 
+    * 17: orthoscopic flag (+/-) and field of view (if abs(value) > 1)
+
+    The camera always looks down -Z with its +X left and its +Y down.
+
+    Therefore, in the default view, model +X is to the observer\'s
+    right, +Y is upward, and +Z points toward the observer.
 
 PYMOL API
 
@@ -798,12 +803,18 @@ SEE ALSO
                     if not quiet:
                         print " get_view: matrix written to log file."
                     _self.log("_ set_view (\\\n","cmd.set_view((\\\n")
-                    _self.log("_  %14.9f, %14.9f, %14.9f,\\\n"%r[0:3]  , "  %14.9f, %14.9f, %14.9f,\\\n"%r[0:3])
-                    _self.log("_  %14.9f, %14.9f, %14.9f,\\\n"%r[4:7]  , "  %14.9f, %14.9f, %14.9f,\\\n"%r[4:7])
-                    _self.log("_  %14.9f, %14.9f, %14.9f,\\\n"%r[8:11] , "  %14.9f, %14.9f, %14.9f,\\\n"%r[8:11])
-                    _self.log("_  %14.9f, %14.9f, %14.9f,\\\n"%r[16:19], "  %14.9f, %14.9f, %14.9f,\\\n"%r[16:19])
-                    _self.log("_  %14.9f, %14.9f, %14.9f,\\\n"%r[19:22], "  %14.9f, %14.9f, %14.9f,\\\n"%r[19:22]) 
-                    _self.log("_  %14.9f, %14.9f, %14.9f )\n"%r[22:25] , "  %14.9f, %14.9f, %14.9f ))\n"%r[22:25])
+                    _self.log("_  %14.9f, %14.9f, %14.9f,\\\n"%r[0:3]  ,
+                              "  %14.9f, %14.9f, %14.9f,\\\n"%r[0:3])
+                    _self.log("_  %14.9f, %14.9f, %14.9f,\\\n"%r[4:7]  ,
+                              "  %14.9f, %14.9f, %14.9f,\\\n"%r[4:7])
+                    _self.log("_  %14.9f, %14.9f, %14.9f,\\\n"%r[8:11] ,
+                              "  %14.9f, %14.9f, %14.9f,\\\n"%r[8:11])
+                    _self.log("_  %14.9f, %14.9f, %14.9f,\\\n"%r[16:19],
+                              "  %14.9f, %14.9f, %14.9f,\\\n"%r[16:19])
+                    _self.log("_  %14.9f, %14.9f, %14.9f,\\\n"%r[19:22],
+                              "  %14.9f, %14.9f, %14.9f,\\\n"%r[19:22]) 
+                    _self.log("_  %14.9f, %14.9f, %14.9f )\n"%r[22:25] ,
+                              "  %14.9f, %14.9f, %14.9f ))\n"%r[22:25])
                     if output<2: # suppress if we have a log file open
                         output=0
                 if output and (not quiet) and (output<3):
@@ -947,7 +958,7 @@ SEE ALSO
                 pymol._view_dict_sc.append(key)
                 pymol._view_dict[key]=_self.get_view(0)
                 if _feedback(fb_module.scene,fb_mask.actions,_self):
-                    print " view: view stored as \"%s\"."%key
+                    print " view: view "+action+"d as \"%s\"."%key
             elif action=='clear':
                 key = pymol._view_dict_sc.auto_err(key,'view')
                 if pymol._view_dict.has_key(key):
@@ -1066,10 +1077,12 @@ SEE ALSO
         pymol=_self._pymol
         new_list = []
         new_dict = {}
+        
         for a in pymol._scene_order:
             if pymol._scene_dict.has_key(a) and not new_dict.has_key(a):
                 new_list.append(a)
                 new_dict[a] = 1
+
         lst = map(lambda x:(scene_sort_dict.get(x,x),x), pymol._scene_dict.keys())
         lst.sort()
         lst = map(lambda x:x[1],lst)
@@ -1077,6 +1090,9 @@ SEE ALSO
             if not new_dict.has_key(a):
                 new_list.append(a)
         pymol._scene_order = new_list
+        # update shortcuts
+        pymol._scene_dict_sc.rebuild( pymol._scene_dict.keys() )
+        # update PyMOL internally
         r = DEFAULT_ERROR
         try:
             _self.lock(_self)
@@ -1181,7 +1197,7 @@ SEE ALSO
                     new_list = names
                     for name in old_list:
                         if not name_dict.has_key(name):
-                            new_list.append(names)
+                            new_list.append(name)
                     pymol._scene_order = new_list
                 elif location == 0: # current
                     start = old_list.index(names[0])
@@ -1204,6 +1220,7 @@ SEE ALSO
                     pymol._scene_order = new_list
         if _self._raising(r,_self):
             raise pymol.CmdException
+        _scene_validate_list(_self) # force scene buttons to be updated
         if not quiet and not is_error(r):
             _self.scene('*')
         return r
@@ -1211,7 +1228,6 @@ SEE ALSO
     def scene(key='auto', action='recall', message=None, view=1,
               color=1, active=1, rep=1, frame=1, animate=-1,
               new_key=None, hand=1, quiet=1, _self=cmd):
-
         '''
 DESCRIPTION
 
@@ -1308,7 +1324,6 @@ SEE ALSO
                         name = "_scene_"+key+"_*"
                         _self.delete(name)
                     pymol._scene_dict = {}
-                    pymol._scene_dict_sc = Shortcut(pymol._scene_dict.keys())
                     pymol._scene_order = []
                     _scene_validate_list(_self)
                 elif action in ['sort']:
@@ -1355,8 +1370,9 @@ SEE ALSO
                         if len(list)>3:
                             _self.set_colorection_name(list[3],key,new_key)
                         print" scene: '%s' renamed to '%s'."%(key,new_key)
-                        pymol._scene_dict_sc = Shortcut(pymol._scene_dict.keys())
+                        pymol._scene_dict_sc.rebuild( pymol._scene_dict.keys())
                         _self.set("session_changed",1,quiet=1)
+                        _scene_validate_list(_self) # force update of scene buttons                        
                 elif action=='insert_after':
                     key = _scene_get_unique_key(_self=_self)            
                     cur_scene = setting.get("scene_current_name",_self=_self)
@@ -1382,7 +1398,9 @@ SEE ALSO
                         if list[2]!=None:
                             if not _self.get_movie_playing(): # don't set frame when movie is already playing
                                 if _self.get_frame()!=list[2]: # only set the frame when it isn't already correct
-                                    _self.frame(list[2])
+                                    _self.frame(list[2],scene=1) # let frame know that it is being set by a scene
+                            else:
+                                _self.set_frame(1,10) # seek scene
                     if (ll>3) and (color):
                         if list[3]!=None:
                             _self.set_colorection(list[3],key)
@@ -1485,7 +1503,7 @@ SEE ALSO
                     entry.append(message)
                     pymol._scene_dict[key]=entry
                     if _feedback(fb_module.scene,fb_mask.actions,_self):
-                        print " scene: scene stored as \"%s\"."%key
+                        print " scene: scene "+action+"d as \"%s\"."%key
                     _scene_validate_list(_self)                        
                     _self.set("scenes_changed",1,quiet=1);
                     _self.set('scene_current_name',key,quiet=1)
@@ -1506,18 +1524,20 @@ SEE ALSO
                             if ix>=0:
                                 setting.set("scene_current_name",lst[ix],quiet=1,_self=_self)
                             else:
-                                setting.set("scene_current_name","",quiet=1,_self=_self)                                
+                                setting.set("scene_current_name","",quiet=1,_self=_self) 
                         _self.set("scenes_changed",1,quiet=1);               
                         del pymol._scene_dict[key]
                         name = "_scene_"+key+"_*"
                         _self.delete(name)
-                        pymol._scene_dict_sc = Shortcut(pymol._scene_dict.keys())
                         _scene_validate_list(_self)
                         if _feedback(fb_module.scene,fb_mask.actions,_self):
                             print " scene: '%s' deleted."%key
-                    _self.set("session_changed",1,quiet=1)                                                                    
+                    _self.set("session_changed",1,quiet=1)
                 elif action=='next':
                     lst = _scene_validate_list(_self)
+                    if (len(lst)==0) and cmd.get_movie_length()>0:
+                        _self.do("mtoggle") # alternate SPACEBAR behavior if no scenes defined...
+                        return
                     cur_scene = setting.get('scene_current_name',quiet=1,_self=_self)
                     if cur_scene in lst:
                         ix = lst.index(cur_scene) + 1
@@ -1547,7 +1567,8 @@ SEE ALSO
                         if not chained: # and len(lst):
                             _self.disable() # just hide everything
                             _self.wizard()
-                            
+                            _self.mstop() # and stop movie from playing...
+
                 elif action=='previous':
                     lst = _scene_validate_list(_self)            
                     cur_scene = setting.get('scene_current_name',quiet=1,_self=_self)
@@ -1560,6 +1581,9 @@ SEE ALSO
                              (setting.get("presentation",_self=_self)=="on") and 
                              (setting.get("presentation_auto_quit",_self=_self)=="on")):
                             _self.quit()
+                        elif setting.get("presentation",_self=_self)=="on":
+                            if _self.get_movie_length()>0:
+                                _self.mplay() # restart movie
                     if ix>=0:
                         scene_name = lst[ix]
                         scene(scene_name,'recall',animate=animate,hand=-1,_self=_self)
@@ -1597,7 +1621,7 @@ SEE ALSO
         pymol=_self._pymol
         if session.has_key('view_dict'):
             pymol._view_dict=copy.deepcopy(session['view_dict'])
-            pymol._view_dict_sc = Shortcut(pymol._view_dict.keys())
+            pymol._view_dict_sc.rebuild(pymol._view_dict.keys())
         return 1
 
 
@@ -1611,11 +1635,12 @@ SEE ALSO
         pymol=_self._pymol        
         if session.has_key('scene_dict'):
             pymol._scene_dict = copy.deepcopy(session['scene_dict'])
-            pymol._scene_dict_sc = Shortcut(pymol._scene_dict.keys())
+            pymol._scene_dict_sc.rebuild(pymol._scene_dict.keys())
         if session.has_key('scene_order'):
             pymol._scene_order = copy.deepcopy(session['scene_order'])
         else:
             pymol._scene_order = []
+        _scene_validate_list(_self=_self)         
         return 1
 
 
@@ -1652,17 +1677,8 @@ PYMOL API
         r = DEFAULT_ERROR      
         try:
             _self.lock(_self)
-            if toggle>1:
-                if toggle==2: # cross-eye
-                    _self.set("stereo_mode","2",quiet=quiet)
-                elif toggle==3: # quad
-                    _self.set("stereo_mode","1",quiet=quiet)
-                elif toggle==4: # wall-eye
-                    _self.set("stereo_mode","3",quiet=quiet)
-                elif toggle==5: # geowall
-                    _self.set("stereo_mode","4",quiet=quiet)
-                elif toggle==6:
-                    _self.set("stereo_mode","5",quiet=quiet)
+            if(toggle>0) : # stereo mode code 
+                _self.set("stereo_mode",str(toggle),quiet=quiet)
                 toggle=1
             r = _cmd.stereo(_self._COb,toggle)
             if is_error(r):
@@ -1826,6 +1842,22 @@ NOTES
         if _self._raising(r,_self): raise QuietException
         return r
 
+    def label2(selection="(all)", expression="", quiet=1,_self=cmd):
+        # preprocess selection
+        selection = selector.process(selection)
+        #
+        r = DEFAULT_ERROR      
+        try:
+            _self.lock(_self)
+            if len(str(expression))==0:
+                r= _cmd.label2(_self._COb,"("+str(selection)+")",'',quiet)
+            else:
+                r = _cmd.label2(_self._COb,"("+str(selection)+")",str(expression),quiet)
+        finally:
+            _self.unlock(r,_self)   
+        if _self._raising(r,_self): raise QuietException
+        return r
+
     def window(action='show', x=0, y=0, width=0, height=0, _self=cmd):
         '''
 DESCRIPTION
