@@ -32,7 +32,9 @@ class Cmd:
         self.fb_action = global_cmd.fb_action
         self.fb_mask = global_cmd.fb_mask
         self.fb_module = global_cmd.fb_module
+        self.fb_debug = global_cmd.fb_debug # this cannot be right...
         self.file_ext_re = global_cmd.file_ext_re
+        self.gz_ext_re = global_cmd.gz_ext_re
         self.loadable = global_cmd.loadable
         self.nt_hidden_path_re = global_cmd.nt_hidden_path_re
         self.palette_dict = global_cmd.palette_dict
@@ -73,16 +75,16 @@ class Cmd:
             # use own locks (for performance)
             self.lock_api = _pymol.lock_api
             self.lock_api_c = _pymol.lock_api_c
-            self.lock_api_status = _pymol.lock_api_status
-            self.lock_api_glut = _pymol.lock_api_glut
             self.lock_api_data = _pymol.lock_api_data            
+            self.lock_api_glut = _pymol.lock_api_glut
+            self.lock_api_status = _pymol.lock_api_status
         else:
             # use global locks (for debugging)
             self.lock_api = global_cmd._pymol.lock_api
             self.lock_api_c = global_cmd._pymol.lock_api_c
-            self.lock_api_status = global_cmd._pymol.lock_api_status
-            self.lock_api_glut = global_cmd._pymol.lock_api_glut
             self.lock_api_data = global_cmd._pymol.lock_api_data            
+            self.lock_api_glut = global_cmd._pymol.lock_api_glut
+            self.lock_api_status = global_cmd._pymol.lock_api_status
 
         self.lock_api_allow_flush = 1
 
@@ -102,16 +104,19 @@ class Cmd:
         self.is_glut_thread = global_cmd.is_glut_thread
         self.setup_global_locks = global_cmd.setup_global_locks
         self.interrupt = global_cmd.interrupt
-
+        self.block_flush = global_cmd.block_flush
+        self.unblock_flush = global_cmd.unblock_flush        
+        
         # pymol/checking.py
 
         self._raising = global_cmd._raising
-        self.is_string = global_cmd.is_string
-        self.is_list = global_cmd.is_list
-        self.is_tuple = global_cmd.is_tuple
-        self.is_sequence = global_cmd.is_sequence
+        self.is_dict = global_cmd.is_dict
         self.is_error = global_cmd.is_error
+        self.is_list = global_cmd.is_list
         self.is_ok = global_cmd.is_ok
+        self.is_sequence = global_cmd.is_sequence
+        self.is_string = global_cmd.is_string
+        self.is_tuple = global_cmd.is_tuple
 
         # from pymol/feedingback.py
 
@@ -209,6 +214,14 @@ class Cmd:
 # ========= WARNING WARNING WARNING WARNING ===========
 # ========= AUTOGENERATED BEYOND THIS POINT ===========
 
+    def _alt(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd._alt, a, k)
+    
+    def _ctrl(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd._ctrl, a, k)
+    
     def _feedback(self, *a, **k):
         k['_self']=self
         return apply(global_cmd._feedback, a, k)
@@ -217,13 +230,9 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd._special, a, k)
     
-    def _ctrl(self, *a, **k):
+    def abort(self, *a, **k):
         k['_self']=self
-        return apply(global_cmd._ctrl, a, k)
-    
-    def _alt(self, *a, **k):
-        k['_self']=self
-        return apply(global_cmd._alt, a, k)
+        return apply(global_cmd.abort, a, k)
     
     def accept(self, *a, **k):
         k['_self']=self
@@ -253,10 +262,6 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.angle, a, k)
     
-    def as(self, *a, **k):
-        k['_self']=self
-        return apply(global_cmd.as, a, k)
-    
     def attach(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.attach, a, k)
@@ -273,6 +278,10 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.bg_color, a, k)
     
+    def bg_colour(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.bg_colour, a, k)
+    
     def bond(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.bond, a, k)
@@ -285,14 +294,14 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.cache, a, k)
     
-    def cartoon(self, *a, **k):
-        k['_self']=self
-        return apply(global_cmd.cartoon, a, k)
-    
     def capture(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.capture, a, k)
     
+    def cartoon(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.cartoon, a, k)
+    
     def cd(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.cd, a, k)
@@ -305,6 +314,10 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.check, a, k)
     
+    def clean(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.clean, a, k)
+    
     def clip(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.clip, a, k)
@@ -317,6 +330,10 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.color, a, k)
     
+    def colour(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.colour, a, k)
+    
     def commands(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.commands, a, k)
@@ -357,14 +374,14 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.decline, a, k)
     
-    def delete(self, *a, **k):
-        k['_self']=self
-        return apply(global_cmd.delete, a, k)
-    
     def del_colorection(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.del_colorection, a, k)
     
+    def delete(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.delete, a, k)
+    
     def deprotect(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.deprotect, a, k)
@@ -385,18 +402,22 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.dirty, a, k)
     
+    def dirty_wizard(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.dirty_wizard, a, k)
+    
     def disable(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.disable, a, k)
     
-    def distance(self, *a, **k):
-        k['_self']=self
-        return apply(global_cmd.distance, a, k)
-    
     def dist(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.dist, a, k)
     
+    def distance(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.distance, a, k)
+    
     def do(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.do, a, k)
@@ -437,6 +458,10 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.ending, a, k)
     
+    def export_coords(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.export_coords, a, k)
+    
     def export_dots(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.export_dots, a, k)
@@ -449,6 +474,10 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.extract, a, k)
     
+    def fab(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.fab, a, k)
+    
     def feedback(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.feedback, a, k)
@@ -457,6 +486,10 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.fetch, a, k)
     
+    def find_pairs(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.find_pairs, a, k)
+    
     def finish_object(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.finish_object, a, k)
@@ -529,14 +562,14 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.get_color_indices, a, k)
     
-    def get_colorection(self, *a, **k):
-        k['_self']=self
-        return apply(global_cmd.get_colorection, a, k)
-    
     def get_color_tuple(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.get_color_tuple, a, k)
     
+    def get_colorection(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.get_colorection, a, k)
+    
     def get_dihedral(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.get_dihedral, a, k)
@@ -553,25 +586,41 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.get_extent, a, k)
     
+    def get_fastastr(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.get_fastastr, a, k)
+    
     def get_frame(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.get_frame, a, k)
     
+    def get_idtf(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.get_idtf, a, k)
+    
+    def get_legal_name(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.get_legal_name, a, k)
+    
+    def get_modal_draw(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.get_modal_draw, a, k)
+    
     def get_model(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.get_model, a, k)
     
-    def get_movie_playing(self, *a, **k):
+    def get_movie_length(self, *a, **k):
         k['_self']=self
-        return apply(global_cmd.get_movie_playing, a, k)
+        return apply(global_cmd.get_movie_length, a, k)
     
     def get_movie_locked(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.get_movie_locked, a, k)
     
-    def get_movie_length(self, *a, **k):
+    def get_movie_playing(self, *a, **k):
         k['_self']=self
-        return apply(global_cmd.get_movie_length, a, k)
+        return apply(global_cmd.get_movie_playing, a, k)
     
     def get_mtl_obj(self, *a, **k):
         k['_self']=self
@@ -585,6 +634,10 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.get_names_of_type, a, k)
     
+    def get_object_color_index(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.get_object_color_index, a, k)
+    
     def get_object_list(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.get_object_list, a, k)
@@ -597,6 +650,10 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.get_pdbstr, a, k)
     
+    def get_phipsi(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.get_phipsi, a, k)
+    
     def get_position(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.get_position, a, k)
@@ -609,6 +666,10 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.get_progress, a, k)
     
+    def get_raw_alignment(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.get_raw_alignment, a, k)
+    
     def get_renderer(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.get_renderer, a, k)
@@ -617,6 +678,10 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.get_scene_dict, a, k)
     
+    def get_scene_list(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.get_scene_list, a, k)
+    
     def get_session(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.get_session, a, k)
@@ -625,18 +690,22 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.get_setting_boolean, a, k)
     
-    def get_setting_int(self, *a, **k):
-        k['_self']=self
-        return apply(global_cmd.get_setting_int, a, k)
-    
     def get_setting_float(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.get_setting_float, a, k)
     
+    def get_setting_int(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.get_setting_int, a, k)
+    
     def get_setting_legacy(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.get_setting_legacy, a, k)
     
+    def get_setting_text(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.get_setting_text, a, k)
+    
     def get_setting_tuple(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.get_setting_tuple, a, k)
@@ -645,10 +714,6 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.get_setting_updates, a, k)
     
-    def get_setting_text(self, *a, **k):
-        k['_self']=self
-        return apply(global_cmd.get_setting_text, a, k)
-    
     def get_state(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.get_state, a, k)
@@ -665,13 +730,9 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.get_type, a, k)
     
-    def get_wizard(self, *a, **k):
+    def get_unused_name(self, *a, **k):
         k['_self']=self
-        return apply(global_cmd.get_wizard, a, k)
-    
-    def get_wizard_stack(self, *a, **k):
-        k['_self']=self
-        return apply(global_cmd.get_wizard_stack, a, k)
+        return apply(global_cmd.get_unused_name, a, k)
     
     def get_version(self, *a, **k):
         k['_self']=self
@@ -685,6 +746,18 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.get_vis, a, k)
     
+    def get_vrml(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.get_vrml, a, k)
+    
+    def get_wizard(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.get_wizard, a, k)
+    
+    def get_wizard_stack(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.get_wizard_stack, a, k)
+    
     def gradient(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.gradient, a, k)
@@ -721,6 +794,10 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.identify, a, k)
     
+    def import_coords(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.import_coords, a, k)
+    
     def index(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.index, a, k)
@@ -729,6 +806,10 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.indicate, a, k)
     
+    def interrupt(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.interrupt, a, k)
+    
     def intra_fit(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.intra_fit, a, k)
@@ -773,18 +854,38 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.label, a, k)
     
+    def label2(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.label2, a, k)
+    
     def load(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.load, a, k)
     
+    def load_brick(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.load_brick, a, k)
+    
+    def load_callback(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.load_callback, a, k)
+    
     def load_cgo(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.load_cgo, a, k)
     
+    def load_coords(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.load_coords, a, k)
+    
     def load_embedded(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.load_embedded, a, k)
     
+    def load_map(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.load_map, a, k)
+    
     def load_model(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.load_model, a, k)
@@ -797,6 +898,10 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.load_png, a, k)
     
+    def load_raw(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.load_raw, a, k)
+    
     def load_traj(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.load_traj, a, k)
@@ -869,14 +974,14 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.mclear, a, k)
     
-    def mdump(self, *a, **k):
-        k['_self']=self
-        return apply(global_cmd.mdump, a, k)
-    
     def mdo(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.mdo, a, k)
     
+    def mdump(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.mdump, a, k)
+    
     def mem(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.mem, a, k)
@@ -993,6 +1098,10 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.ray, a, k)
     
+    def read_mmodstr(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.read_mmodstr, a, k)
+    
     def read_molstr(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.read_molstr, a, k)
@@ -1001,6 +1110,14 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.read_pdbstr, a, k)
     
+    def read_sdfstr(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.read_sdfstr, a, k)
+    
+    def read_xplorstr(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.read_xplorstr, a, k)
+    
     def ready(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.ready, a, k)
@@ -1013,10 +1130,18 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.recolor, a, k)
     
+    def recolour(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.recolour, a, k)
+    
     def redo(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.redo, a, k)
     
+    def reference(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.reference, a, k)
+    
     def refresh(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.refresh, a, k)
@@ -1085,6 +1210,10 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.scene, a, k)
     
+    def scene_order(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.scene_order, a, k)
+    
     def sculpt_activate(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.sculpt_activate, a, k)
@@ -1125,6 +1254,18 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.set_colorection, a, k)
     
+    def set_colorection_name(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.set_colorection_name, a, k)
+    
+    def set_colour(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.set_colour, a, k)
+    
+    def set_colour(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.set_colour, a, k)
+    
     def set_dihedral(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.set_dihedral, a, k)
@@ -1141,6 +1282,18 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.set_name, a, k)
     
+    def set_object_color(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.set_object_color, a, k)
+    
+    def set_object_color(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.set_object_color, a, k)
+    
+    def set_object_ttt(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.set_object_ttt, a, k)
+    
     def set_session(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.set_session, a, k)
@@ -1153,14 +1306,6 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.set_title, a, k)
     
-    def set_wizard(self, *a, **k):
-        k['_self']=self
-        return apply(global_cmd.set_wizard, a, k)
-    
-    def set_wizard_stack(self, *a, **k):
-        k['_self']=self
-        return apply(global_cmd.set_wizard_stack, a, k)
-    
     def set_view(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.set_view, a, k)
@@ -1169,6 +1314,14 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.set_vis, a, k)
     
+    def set_wizard(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.set_wizard, a, k)
+    
+    def set_wizard_stack(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.set_wizard_stack, a, k)
+    
     def show(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.show, a, k)
@@ -1177,6 +1330,10 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.show_as, a, k)
     
+    def show_help(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.show_help, a, k)
+    
     def slice_new(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.slice_new, a, k)
@@ -1213,6 +1370,10 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.stereo, a, k)
     
+    def super(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.super, a, k)
+    
     def symexp(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.symexp, a, k)
@@ -1237,10 +1398,22 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.torsion, a, k)
     
+    def transform_object(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.transform_object, a, k)
+    
+    def transform_selection(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.transform_selection, a, k)
+    
     def translate(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.translate, a, k)
     
+    def translate_atom(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.translate_atom, a, k)
+    
     def turn(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.turn, a, k)
@@ -1308,4 +1481,4 @@ class Cmd:
     def zoom(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.zoom, a, k)
-    
\ No newline at end of file
+    
