@@ -2,6 +2,7 @@
 #define _H_OVHeapArray
 
 #ifdef OV_JENARIX
+
 /* NEW Jenarix-based OVHeapArray wrapper */
 #define _OVHeapArray Ov_HeapVLA
 
@@ -11,7 +12,6 @@
 #define _OVHeapArray_Alloc(h,u,s,z) ov_heap_VlaAllocRaw(u,s,z)
 #endif
 
-
 #define _OVHeapArray_Check ov_heap_VlaAddIndexRaw
 #define _OVHeapArray_Free ov_heap_VlaFreeRaw
 #define _OVHeapArray_SetSize ov_heap_VlaSetSizeRaw
@@ -19,6 +19,7 @@
 
 #else
 
+
 /* OLD proven OVHeapArray */
 
 #include "OVHeap.h"
@@ -29,43 +30,39 @@ typedef struct {
   ov_boolean auto_zero;
 } _OVHeapArray;
 
-
-void *_OVHeapArray_Alloc(OVHeap *heap,ov_size unit_size,
-                         ov_size size,int zero
+void *_OVHeapArray_Alloc(OVHeap * heap, ov_size unit_size, ov_size size, int zero
 #ifdef OVHeap_TRACKING
-                         ,const char *file,int line
+                         , const char *file, int line
 #endif
-                         );
+  );
 
-
-void *_OVHeapArray_Check(void *ptr,ov_size index
+void *_OVHeapArray_Check(void *ptr, ov_size index
 #ifdef OVHeap_TRACKING
-                         ,const char *file,int line
+                         , const char *file, int line
 #endif
-                         );
+  );
 
-
-void  _OVHeapArray_Free(void *ptr
+void _OVHeapArray_Free(void *ptr
 #ifdef OVHeap_TRACKING
-                        ,const char *file,int line
+                       , const char *file, int line
 #endif
-                        );
-
+  );
 
 void *_OVHeapArray_SetSize(void *ptr, ov_size new_size
 #ifdef OVHeap_TRACKING
-                        ,const char *file,int line
+                           , const char *file, int line
 #endif
-                        );
+  );
 
 ov_size OVHeapArray_GetSize(void *ptr
 #ifdef OVHeap_TRACKING
-                        ,const char *file,int line
+                            , const char *file, int line
 #endif
-);
+  );
 
 #endif
 
+
 /* OLD & NEW shared implementation */
 
 #ifndef OVHeap_TRACKING
@@ -89,7 +86,6 @@ ov_size OVHeapArray_GetSize(void *ptr
 
 #define OVHeapArray_FREE(ptr) _OVHeapArray_Free((void*)(ptr))
 
-
 #else
 
 #define OVHeapArray_MALLOC(heap,type,size)  (type*)_OVHeapArray_Alloc(heap,sizeof(type),\
@@ -111,7 +107,6 @@ ov_size OVHeapArray_GetSize(void *ptr
 
 #define OVHeapArray_GET_SIZE(ptr) OVHeapArray_GetSize((void*)ptr,__FILE__,__LINE__)
 
-
 #define OVHeapArray_FREE(ptr) _OVHeapArray_Free((void*)(ptr),__FILE__,__LINE__)
 
 #endif
